Ова страна садржи преглед тренутних услова за ваше укључење у листу слања 
<a href="%(adminurl)s"><em>%(listname)s</em></a>.
Прво, пронаћи ћете листу са чекајућим захтјевима за укључење и искључење, заједно са порукама које су задржане за пуштање.

<p>За сваки административни посао изаберите одговарајућу опцију, те 
промјене потврдите кликом на одговарајући тастер (обично при врху стране) када начините све промјене. 
<a href="%(detailsurl)s">Детаљнија упутства</a> су доступна.

<p>Можете такође погледати  <a href="%(viewallurl)s">детаље</a> свих задржаних порука.
