<html>
<head>
    <link rel="SHORTCUT ICON" href="<mm-favicon>">
    <title><MM-Presentable-User> Configuraci&oacute;n miembros pa <MM-List-Name>
    </title>
</head>
<BODY BGCOLOR="#ffffff">
    <TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="5">
    <TR><TD WIDTH="100%" BGCOLOR="#99CCFF"><B>
        <FONT COLOR="#000000" SIZE=+1>
        <MM-List-Name> Configuraci&oacute;n del usuariu pa les
        <MM-Presentable-User>
        </FONT></B></TD></TR>
    </TABLE>
<p>
<table width="100%" border="0" cellspacing="5" cellpadding="5">
    <tr><td>
        <b></b> Opciones de soscripci&oacute;n  de <b><MM-Presentable-User></b> na llista de distribuci&oacute;n <MM-List-Name>.
</td><td><MM-Form-Start><mm-logout-button><MM-Form-End></td>
    </tr><tr>
        <td colspan="2">
        <MM-Case-Preserved-User>

        <MM-Disabled-Notice>

        <p><mm-results>
        </td>
    </tr>
</table>

<MM-Form-Start>
<p>
<TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="5">
    <TR><TD WIDTH="100%" BGCOLOR="#FFF0D0" colspan="2">
        <FONT COLOR="#000000">
        <B>Pa camudar la informaci&oacute;n cola que tas soscritu a <MM-List-Name></b>
	</font></td></tr>
    <tr><td colspan="2"> Puedes camudar la direici&oacute;n cola que tas soscritu a la llista de distribuci&oacute;n, introduciendo una direici&oacute;n nueva nel campo qu'apaez m&aacute;s abaxo. Unviar&aacute;sete un mensax de confirmaci&oacute;n a la direici&oacute;n qu'indiques, darr&eacute;u que los cambeos nun fadr&aacute;n efeutu fasta que lo confirmes.

        <p>Les confirmaciones caduquen dempu&eacute;s de <mm-pending-days>.
 
        <p>Opcionalmente, puedes poner o camudar el to nome y apell&iacute;os (por exemplu <em>Xurde Prendes</em>).

        <p>Si quies aplicar les modificaciones de soscripci&oacute;n a toles llistes nes que tas soscritu en <mm-host>, habilita la caxella de verificaci&oacute;n <em>Camudar globalmente</em>.

 
        </td></tr>
    <tr><td><center>
        <table border="0" cellspacing="2" cellpadding="2" width="80%" cols="2">
        <tr><td bgcolor="#dddddd"><div align="right">Direici&oacute;n nueva:</div></td>
            <td><mm-new-address-box></td>
            </tr>
        <tr><td bgcolor="#dddddd"><div align="right">Confirmar otra vuelta:</div></td> 
            <td><mm-confirm-address-box></td>
            </tr>
        </tr></table></center>
        </td>
        <td><center>
        <table border="0" cellspacing="2" cellpadding="2" width="80%" cols="2">
            <tr><td bgcolor="#dddddd"><div align="right">El to nome
             (opcional):</div></td>
            <td><mm-fullname-box></td>
            </tr>
        </table></center>
        </td>
        </tr>
    <tr><td colspan="2"><center><mm-change-address-button>
        <p><mm-global-change-of-address>Camudar globalmente</center></td>
    </tr>
</table>

<p>
<TABLE WIDTH="100%" BORDER="0" CELLSPACING="5" CELLPADDING="5">
    <TR><TD WIDTH="50%" BGCOLOR="#FFF0D0"><FONT COLOR="#000000">
        <B>P'anular la soscripci&oacute;n a <MM-List-Name></b></td>

	<td bgcolor="#fff0d0" width="50%"><font color="#000000">
        <b>El restu de les soscripciones que tienes en <MM-Host></b>
	</font></td></tr>

    <tr><td>
        Esbilla la caxella de confirmaci&oacute;n y calca esti bot&oacute;n p'anular la to soscripci&oacute;n d'esta llista de distribuci&oacute;n. <strong>Avisu:</strong> &iexcl;Esta aici&oacute;n nun tien efeutu nel intre!
        <p>
        <center><MM-Unsubscribe-Button></center></td>
    <td>
        Puedes ver un informe del restu de les llistes de distribuci&oacute;n de <mm-host>nes que tas soscritu. Usa esta parte si quies aplicar cambeos globales al restu de les tos soscripciones.

        <p>
        <center><MM-Other-Subscriptions-Submit></center>
        </TD></TR>
</table>

<TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="5">
    <TR><TD COLSPAN=2 WIDTH="100%" BGCOLOR="#FFF0D0"><FONT COLOR="#000000">
        <B>La to clave pa <MM-List-Name></B>
        </FONT></TD></TR>

    <tr valign="TOP"><td WIDTH="50%">
        <a name=reminder>
        <center>
        <h3>&iquest;Escaecisti la clave?</h3>
        </center>Calca nesti bot&oacute;n pa facer que t'unvien un corr&eacute;u-e a la direici&oacute;n cola que tas soscritu.
        <p><MM-Umbrella-Notice>
        <center>
        <MM-Email-My-Pw>
        </center>
        </td>

    <td WIDTH="50%">
        <a name=changepw>
        <center>
        <h3>Pa camudar la clave</h3>
        <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2" WIDTH="70%" COLS=2>
            <TR><TD BGCOLOR="#dddddd"><div align="right">Clave
                nueva:</div></TD>
                <TD><MM-New-Pass-Box></TD>
                </TR>
            <TR>
                <TD BGCOLOR="#dddddd"><div align="right">Confirmar otra vuelta:</div></TD>
                <TD><MM-Confirm-Pass-Box></TD>
            </TR>
        </table>

        <MM-Change-Pass-Button>
        <p><center><mm-global-pw-changes-button>Camudar globalmente.
        </center>
</TABLE>

<p>
<TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="5">
    <TR><TD WIDTH="100%" BGCOLOR="#FFF0D0"><FONT COLOR="#000000">
        <B>Les tos opciones de soscripci&oacute;n pa la llista<MM-List-Name></B>
        </FONT></TD></TR>
</table>

<p>
<i><strong>Comprob&aacute;ronse los valores actuales.</strong></i>

<p>Dec&aacute;tate que dalguna de les opciones tienen una caxella seleicionable
<em>Aplicar globalmente</em>.
Activando esti campu, fadr&aacute;s que los cambeos s'apliquen a cada una de les llistas de distribuci&oacute;n de <mm-host>nes que tas soscritu. Calca col mur en <em>Llistar el restu de les mios soscripciones</em> m&aacute;s arriba pa ver cu&aacute;les son.
<p>
<TABLE BORDER="0" CELLSPACING="3" CELLPADDING="4" WIDTH="100%">
    <tr><TD BGCOLOR="#cccccc">
        <a name="disable">
        <strong>Entrega de corr&eacute;u</strong></a><p>
        Si esbilles <em>Habilitada</em> recibir&aacute;s los mensaxes que s'unvien a esta llista de distribuci&oacute;n. Si esbilles
        <em>Inhabilitada</em>
indiques el deseyu de nun recibir el corr&eacute;u unvi&aacute;u a la llista de distribuci&oacute;n durante un tiempu (por exemplo, si vas de vacaciones). Si inhabilites la receici&oacute;n de los mensaxes de corr&eacute;u, nun escaezas volver a habilitar la receici&oacute;n cuandu proceda. 
	</td><td bgcolor="#cccccc">
        <mm-delivery-enable-button>Habilit&aacute;u<br>
        <mm-delivery-disable-button>Inhabilit&aacute;u<p>
        <mm-global-deliver-button><i>Aplicar globalmente</i>
    </td></tr>

<!--Start-Digests-Delete-->
    <tr><td bgcolor="#cccccc">
        <strong>Activar mou Digest</strong><p>
        Si habilites el mou digest, recibir&aacute;s diariamente los mensaxes unviados a la llista recopilaos n&uacute;n &uacute;nicu mensax,
        n'arr&oacute;u de recibilos a mid&iacute;a que s'unv&iacute;en. Si camudes el mou digest de Activar a Desactivar, puede que recibas un caberu
        digest.
     </td><td bgcolor="#cccccc">
        <MM-Undigest-Radio-Button>Desactivar<br>
        <MM-Digest-Radio-Button>Activar
     </td></tr>
        
    <tr><td bgcolor="#cccccc">
        <strong>&iquest;Recibir los recopilatorios en testu planu o con codificaci&oacute;n MIME?</strong><p>&nbsp;
        El to llector de corr&eacute;u puede que nun sofite recopilaciones (digests) MIME.
        En xeneral prefi&eacute;rense les recopilaciones MIME, pero si tienes problemes a la hora de lleeles, esbilla les recopilaciones en testu planu.
        </td><td bgcolor="#cccccc">
        <MM-Mime-Digests-Button>MIME<br>
        <MM-Plain-Digests-Button>Texto plano<p>
        <mm-global-mime-button><i>Aplicar globalmente</i>
        </td></tr>
<!--End-Digests-Delete-->
        
    <tr><td bgcolor="#cccccc">
        <strong>&iquest;Quies recibir los mensaxes que t&uacute; mesmu unv&iacute;es a esta llista?</strong><p>
        Normalmente, recibir&aacute; una copia de cada mensaje que env&iacute; a la lista. Si no quiere recibir dicha copia, ponga esta opci&oacute;n a
        <em>No</em>.
        </td><td bgcolor="#cccccc">
        <mm-dont-receive-own-mail-button>Non<br>
        <mm-receive-own-mail-button>Si<br>

        </td></tr>

    <tr><td bgcolor="#cccccc">
        <strong>&iquest;Quies recibir una confirmaci&oacute;n cuando unv&iacute;es corr&eacute;u a esta llista?</strong><p>
        </td><td bgcolor="#cccccc">
        <mm-dont-ack-posts-button>Non<br>
        <mm-ack-posts-button>Si
        </td></tr>

    <tr><td bgcolor="#cccccc">
        <strong>&iquest;Quies recibir los recordatorios d'esta llista?</strong><p>
        Mensualmente, recibir&aacute;s un mensax de corr&eacute;u cola clave de cada una de les llistes nes que tas soscritu. Puedes inhabilitar esti comportamientu per llista, nam&aacute;i con seleicionar <em>Non</em> nesta opci&oacute;n. Si decides inhabilitar el recordatoriu
        de les claves en toles llistes a les que tas soscritu, nun se te mandar&aacute; deng&uacute;n mensaxe.
        </td><td bgcolor="#cccccc">
        <mm-dont-get-password-reminder-button>Non<br>
        <mm-get-password-reminder-button>Si<p>
        <mm-global-remind-button><i>Aplicar globalmente</i>
        </td></tr>

    <tr><td bgcolor="#cccccc">
        <strong>&iquest;Quies anubrite na llista de soscriptores?</strong><p>
        Cuando daqui&eacute;n vea la llista de soscriptores, ver&aacute; que davezu la to direici&oacute;n de corr&eacute;u-e saldr&aacute; llistada 
        (d'una forma escura pa enga&ntilde;ifar a los escaneadores spam). Si nun quies que la to direici&oacute;n salga a rellucir, seleicione <em>Si</em>.
        </td><td bgcolor="#cccccc">
        <MM-Public-Subscription-Button>Non<br>
        <MM-Hide-Subscription-Button>Si
        </td></tr>

    <tr><td bgcolor="#cccccc">
        <strong>&iquest;En qu&eacute; llingua quies ver los mensaxes de la llista?</strong><p>
        </td><td bgcolor="#cccccc">
        <MM-list-langs>
         <br>
</td></tr>
 
     <tr><td bgcolor="#cccccc">
         <strong>&iquest;A qu&eacute; triba de temes prestar&iacute;ate soscribite?  </strong><p>
Al seleicionar &uacute;n o m&aacute;s temes, puedes pe&ntilde;erar el tr&aacute;ficu de la llista de distribuci&oacute;n, de mou que nam&aacute;i recibir&aacute;s un soconxuntu de los mensaxes. Nam&aacute;i t'arribar&aacute;n los mensaxes que concasen con dalg&uacute;n de los temes esbillaos. <p>Si un mensax nun concasa col tema, la regla que decide si s'entrega'l mensax depende de la configuraci&oacute;n de la opci&oacute;n d'abaxo. Si nun seleiciones deng&uacute;n tema d'inter&eacute;s, recibir&aacute;s tolos mensaxes dirix&iacute;os a la llista.
         </td><td bgcolor="#cccccc">
         <mm-topics>
         <br>
</td></tr>
 
     <tr><td bgcolor="#cccccc">
         <strong>&iquest;Quies recibir los mensaxes que nun concasen con deng&uacute;n tema?</strong><p>
Esta opci&oacute;n nam&aacute;i fai efeutu si tas soscritu a dalg&uacute;n tema de los d'arriba. Esta opci&oacute;n describe cual va ser la regla d'entrega por defeutu pa los mensaxes que nun concasen con deng&uacute;n tema. Si esbilles que <em>Non</em> conse&ntilde;es el to deseyu de nun recibir los mensaxes que concasen con deng&uacute;n tema, mentantu que si esbilles que <em>Si</em> significa que recibir&aacute;s tolos mensaxes que nun concasen con deng&uacute;n tema.

		  <p>Si nun se seleiciona deng&uacute;n tema d'inter&eacute;s na estaya d'arriba, ent&oacute;s recibir&aacute;s tolos mensaxes que s'unv&iacute;en a la llista.
         </td><td bgcolor="#cccccc">
         <mm-suppress-nonmatching-topics>Non<br>
         <mm-receive-nonmatching-topics>Si
        </td></tr>

    <tr><td bgcolor="#cccccc">
        <strong>&iquest;Quies evitar copies duplicaes de los tos propios mensaxes?</strong><p>
		Cuando tea incluy&iacute;o espl&iacute;citamente nes testeres <tt>To:</tt> o <tt>Cc:</tt> d'un mensax dirix&iacute;u a
		la llista, puedes optar por non recibir otra copia de la llista de distribuci&oacute;n. Seleiciona <em>Si</em> pa
		evitar recibir copies de la llista de distribuci&oacute;n o <em>Non</em> pa recibiles.

		<p>Si la llista tien soscriptores colos mensaxes personalizaos activaos, y escoyisti recibir copies,
		cada copia tendr&aacute; una testera <tt>X-Mailman-Copy:
		yes</tt>.

        </td><td bgcolor="#cccccc">
        <mm-receive-duplicates-button>Non<br>
        <mm-dont-receive-duplicates-button>Si<p>
        <mm-global-nodupes-button><i>Aplicar globalmente</i>
        </td></tr>

    <tr><TD colspan="2">
        <center><MM-options-Submit-button></center>
        </td></tr>

</table>
</center>
<p>
<MM-Form-End>

<MM-Mailman-Footer>
</body>
</html>
