<html>
<head>
  <title>Autenticaci&oacute;n de %(who)s de %(listname)s </title>
  <script>function sf(){document.f.adminpw.focus();}</script>
</head>
<body bgcolor="#ffffff" onLoad="sf()">
<FORM METHOD=POST ACTION="%(path)s" name="f">
%(message)s
  <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
    <TR>
      <TD COLSPAN="2" WIDTH="100%%" BGCOLOR="#99CCFF" ALIGN="CENTER">
	<B><FONT COLOR="#000000" SIZE="+1">
	    Autenticaci&oacute;n de %(who)s de %(listname)s</FONT></B>
      </TD>
    </TR>
    <tr>
      <TD><div ALIGN="Right"></Chave de %(who)s da rolda:></div></TD>
      <TD><INPUT TYPE="password" NAME="adminpw" SIZE="30"></TD>
    </tr>
    <tr>
      <td colspan=2 align=middle><INPUT type="SUBMIT"
                                        name="admlogin"
					value="Con permiso...">
      </td>
    </tr>
  </TABLE>
      <p><strong><em>Importante:</em></strong> a partir de agora debe
      ter habilitadas as cookies do seu navegador; caso contrario, os seus
        cambios non ter&aacute;n efecto.

      <p>As sesi&oacute;ns baseadas en cookies &uacute;sanse na interface administrativa
        do Mailman de xeito que non precisa identificarse continuamente
        con cada operaci&oacute;n administrativa que
realizar. A cookie expirar&aacute; automaticamente cando saia do navegador
ou se selecciona a opci&oacute;n <em>Sa&iacute;da</em> que est&aacute; na
secci&oacute;n titulada
 <em> Outras actividades administrativas</em> (que ver&aacute; logo de
 entrar 
con &eacute;xito).
</FORM>
</body>
</html>
