Este texto pode incluir
<a href="https://docs.python.org/2/library/stdtypes.html#string-formatting-operations">strings no formato
do Python</a> que s&atilde;o resolvidos contra atributos da lista. a lista 
de substitui&ccedil;&otilde;es permitidas s&atilde;o:

<ul>
    <li><b>real_name</b> - O nome 'amig&aacute;vel' da lista; normalmente
    o nome da lista com mai&uacute;sculas e min&uacute;sculas. 

    <li><b>list_name</b> - O nome no qual a lista &eacute; 
    identificada nas URLs, onde mai&uacute;sculas/min&uacute;sculas s&atilde;o 
    importantes.

    <li><b>host_name</b> - O nome completo do 
    servidor (FQDN) onde a lista &eacute; executada. 

    <li><b>web_page_url</b> - A URL base do Mailman. Isto
    pode ser adicionado com,
    e.g. <em>listinfo/%(list_name)s</em> para chegar at&eacute; 
    a p&aacute;gina de detalhes sobre a lista de discuss&atilde;o. 

    <li><b>description</b> - uma breve descri&ccedil;&atilde;o da lista
    de discuss&atilde;o. 

    <li><b>info</b> - A descri&ccedil;&atilde;o completa da lista de 
    discuss&atilde;o. 

    <li><b>cgiext</b> - A extens&atilde;o adicionada a 
    scripts CGI. 
</ul>
