Les sol&middot;licituds d'administraci&oacute; es mostren en una de dues maneres possibles: 
en una <a href="%(summaryurl)s">p&agrave;gina de resum</a>, i en una p&agrave;gina de <em>detalls</em>.
La p&agrave;gina de resum cont&eacute; les sol&middot;licituds de subscripci&oacute; i de
cancel&middot;laci&oacute; pendents, i els missatges retinguts que esperen la vostra
aprovaci&oacute;, ordenats segons l'adre&ccedil;a del remitent. La p&agrave;gina de detalls
cont&eacute; una vista m&eacute;s detallada d'aquests missatges retinguts, incloent-ne el t&iacute;tol
sencer i un extracte
del cos.

<p>Les accions seg&uuml;ents estan disponibles a totes les p&agrave;gines:

<ul> <li><b>Ajorna</b> -- ajornament de la decisi&oacute; per m&eacute;s endavant. No es
dur&agrave; a terme cap acci&oacute; per a aquesta sol&middot;licitud d'administraci&oacute;. Pel que fa als missatges retinguts, encara es
podran reenviar o mantenir (vegeu l'acci&oacute; de sota).

<li><b>Aprova</b> -- aprovaci&oacute; del missatge i enviament a la
llista. Si &eacute;s una sol&middot;licitud de subscripci&oacute;, s'aprovar&agrave; el canvi
d'estat de la subscripci&oacute;.

<li><b>Rebutja</b> -- rebuig del missatge, enviament d'una nota de
rebuig al remitent i descart del missatge original. Si &eacute;s una
sol&middot;licitud de subscripci&oacute;, es rebutjar&agrave; el canvi d'estat de la
subscripci&oacute;. En qualsevol cas, &eacute;s recomanable donar un motiu per a tal
decisi&oacute; al quadre de text del costat.

<li><b>Descarta</b> -- supressi&oacute; del missatge original sense enviar
una nota de rebuig. Si &eacute;s una sol&middot;licitud de subscripci&oacute;, es descartar&agrave;
sense enviar cap notificaci&oacute; al remitent. Aquesta &eacute;s la manera d'actuar
davant de l'spam. </ul>

<p>Per als missatges retinguts, activeu l'opci&oacute; <b>Mant&eacute;</b> per a desar 
  una c&ograve;pia del missatge per a l'administrador del lloc. Aix&ograve; &eacute;s 
  molt &uacute;til per a missatges abusius que vulgueu descartar, per&ograve; dels quals en calgui una c&ograve;pia per a inspeccions posteriors.

<p>Activeu l'opci&oacute; <b>Reenvia a</b>, i escriviu l'adre&ccedil;a de
reenviament si voleu reenviar el missatge a alg&uacute; que no sigui a la
llista. Per a modificar un missatge retingut abans d'enviar-lo a la
llista, us l'haureu d'enviar a v&oacute;s mateix (o b&eacute; al propietari de
la llista), i descartar l'original. Un cop l'h&agrave;giu rebut a la b&uacute;stia
d'entrada, haureu de realitzar-hi els canvis pertinents i reenviar-lo a la
llista amb una cap&ccedil;alera <tt>Approved:</tt> que inclogui la vostra contrasenya de la llista com a valor. En aquest 
  casos &eacute;s recomanable una nota en el missatge 
  nou amb una explicaci&oacute; de les modificacions del text original.

<p>Opcionalment, si el remitent del missatge original &eacute;s un membre de la 
  llista en espera de moderaci&oacute;, podeu suprimir-li el senyalador que aix&iacute; ho especifica. Aix&ograve; &eacute;s &uacute;til 
  en el cas que la vostra llista estigui configurada per a posar en per&iacute;ode de prova 
  els membres nous, i ja h&agrave;giu decidit que aquest membre concret 
  &eacute;s fiable i pot enviar missatges a la llista sense necessitat d'aprovaci&oacute;.

<p>En cas que el remitent no sigui un membre de 
  la llista, podeu afegir la seva adre&ccedil;a electr&ograve;nica a un <em>filtre de remitents</em>. 
  Els filtres de remitents es descriuen a la <a href="%(filterurl)s">p&agrave;gina de privacitat del filtre de remitents</a>, 
  i poden ser d'<b>auto-accept</b> (Accepts), d'<b>auto-hold</b> (Holds), d'<b>auto-reject</b> 
  (Rejects), o d'<b>auto-discard</b> (Discards). Aquesta opci&oacute; no estar&agrave; 
  disponible si l'adre&ccedil;a ja apareix en un filtre de remitents.

<p>Un cop h&agrave;giu acabat, feu clic al bot&oacute; <em>Envia totes les dades</em> 
  que es troba a l'inici i al final de la p&agrave;gina. Aquest bot&oacute; 
  enviar&agrave; totes les accions seleccionades de totes les sol&middot;licituds d'administraci&oacute; 
  sobre les quals h&agrave;giu pres una decisi&oacute;.

<p><a href="%(summaryurl)s">Torna a la p&agrave;gina principal</a>. 
