<html>
<head>
    <title>%(realname)s Privatna Arhiva Autentikacija</title>
    <script>function sf(){document.f.username.focus();}</script>
</head>
<body bgcolor="#ffffff" onLoad="sf()">
<FORM METHOD=POST ACTION="%(action)s" name="f">
%(message)s
  <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
    <TR>
      <TD COLSPAN="2" WIDTH="100%%" BGCOLOR="#99CCFF" ALIGN="CENTER">
	<B><FONT COLOR="#000000" SIZE="+1">%(realname)s Privatna Arhiva Autentikacija</FONT></B>
      </TD>
    </TR>
    <tr>
        <TD><div ALIGN="Right">Email adresa:</div></TD>
        <TD><INPUT TYPE="text" NAME="username" SIZE="30"></TD>
    </tr>
    <tr>
      <TD><div ALIGN="Right">Lozinka:</div></TD>
      <TD><INPUT TYPE="password" NAME="password" SIZE="30"></TD>
    </tr>
    <tr>
      <td colspan=2 align="middle"><INPUT type="SUBMIT"
                                          name="submit"
					  value="Pusti me unutra...">
      </td>
    </tr>
  </TABLE>
      <p><strong><em>Važno:</em></strong> Odavde, morate imati 
			omogućene kolačiće (cookies) u svome browseru, jer u suprotnom 
			administrativne promjene neće biti moguće.
			
			<p>Mailmanovo administracijsko sučelje koristi sesijske kolačiće (session cookies) 
			tako da se ne trebate ponovno autenticirati kod svake administrativne operacije. 
			Ovaj kolačić (cookie) će automatski isteći kada izađete iz browsera, ali ga možete i 
			eksplicitno uni&scaron;titi kolačić klikanjem na link <em>Izlaz</em> pod <em>Druge 
      Administracijske Aktivnosti</em> (koji ćete vidjeti onda kad se uspje&scaron;no prijavite).
      <p>
    <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
    <TR>
      <TD COLSPAN="2" WIDTH="100%%" BGCOLOR="#99CCFF" ALIGN="CENTER">
	<B><FONT COLOR="#000000" SIZE="+1">Password Reminder</FONT></B>
      </TD>
    </TR>
    <tr>
      <td>If you don't remember your password, enter your email address
          above and click the <em>Remind</em> button and your
          password will be emailed to you.</td>
    </tr>
    <tr>
      <td><center><INPUT name="login-remind" type="SUBMIT" value="Remind" ></center></td>
    </tr>
  </TABLE>
</FORM>
</body>
</html>
