論壇<em>%(listname)s</em> 中有待決案件需要您的審核。
首先您應到待決案件的網頁查詢相關訊息。

<p>若屬於訂閱的申請，請選擇 <b>Refuse</b> 拒絕，或
<b>Subscribe</b> 接受。
如果您拒絕訂閱的申請，您可以在文字盒中略述拒絕訂閱的理由。

<p>若屬於遭留置的信件，請選擇

<ul>
<li><b>Defer</b> - 暫緩決定。您尚未想處理這些信件。
<li><b>Approve</b> - 放行信件並送上論壇。
<li><b>Reject</b> - 退信並向寄信人簡短說明退信原因，該信件不會送上論壇。
<li><b>Discard</b> - 逕行丟棄，此選項對於垃圾郵件十分有用。
</ul>

<p>如果信件是給壇主，如果您要存一份副本時，將 <b>Preserve</b> 選項打開。
這選項對罵人的信件很有用 。  如果您想將信件轉寄不在此論壇的人士，將 
<b>Forward to</b> 選項打開，並填上轉信地址。

<p>當您完成工作，請按在網頁上方或下方的 <em>Submit All Data</em> 按鈕
以便執行您的決定。如果您不想現在作決定，請勿按此鈕。 稍候您可以再決定。
