<html>
<head><title>Результаты подписки на список рассылки <MM-List-Name></title></head>
<body bgcolor="white">
<h1>Результаты подписки на список рассылки <MM-List-Name></h1>
<MM-Results>
<MM-Mailman-Footer>
</body>
</html>
