Este texto pode inclu&iacute;r 
<a href="https://docs.python.org/2/library/stdtypes.html#string-formatting-operations">
cadeas de formato Python
</a>
que se substituir&aacute;n polos atributos da rolda. A relaci&oacute;n de
substituci&oacute;ns que se permite &eacute; a seguinte:

<ul>
    <li><b>real_name</b>: &eacute; o nome 'present&aacute;bel' da rolda.
    Polo xeral &eacute; o nome da rolda coa primeira letra en mai&uacute;scula.
    

    <li><b>list_name</b>: &eacute; o nome polo que se identifica
      a rolda nos URL e dist&iacute;nguense as mai&uacute;sculas das
      min&uacute;sculas.

    <li><b>host_name</b>: &eacute; o nome can&oacute;nico do servidor que
    hospeda a rolda.

    <li><b>web_page_url</b>: &eacute; o URL de base do Mailman. Por exemplo,
    para indicar a p&aacute;xina de informaci&oacute;n da rolda 
    s&oacute; haber&iacute;a que engadirlle despois:<br>
    <em>listinfo/%(list_name)s</em>
  <li><b>description</b>: &eacute; unha descrici&oacute;n concisa sobre
    a rolda de distribuci&oacute;n.

  <li><b>info</b>: &eacute; a descrici&oacute;n completa sobre a rolda de distribuci&oacute;n.

  <li><b>cgiext</b>: &eacute; a  extensi&oacute;n que se engade ao gui&oacute;ns
    CGI.
</ul>
