Aquesta p&agrave;gina cont&eacute; un subconjunt dels missatges retinguts pendents de
la vostra aprovaci&oacute; de la llista de correu <em>%(listname)s</em>.
Actualment mostra %(description)s.

<p>Seleccioneu l'acci&oacute; a dur a terme per a cada sol&middot;licitud
d'administraci&oacute;. Un cop h&agrave;giu acabat, feu clic al bot&oacute; <b>Envia totes
les dades</b>.  <a href="%(detailsurl)s">Aqu&iacute;</a> tamb&eacute; hi trobareu 
m&eacute;s informaci&oacute;.

<p>Tamb&eacute; podeu <a href="%(summaryurl)s">visualitzar els detalls</a> de
totes les sol&middot;licituds pendents.
