A beavatkoz&aacute;sra v&aacute;r&oacute; teend&#337;k list&aacute;j&aacute;t k&eacute;tf&eacute;lek&eacute;ppen lehet megjelen&iacute;teni,
vagy az <a href="%(summaryurl)s">&ouml;sszes&iacute;t&#337; oldalon</a> vagy a <em>r&eacute;szletes</em>
oldalon. Az &ouml;sszes&iacute;t&#337; oldal a f&uuml;gg&#337;ben l&eacute;v&#337; fel- &eacute;s leiratkoz&aacute;sokat,
valamint az enged&eacute;lyez&eacute;sre v&aacute;r&oacute; leveleket mutatja a bek&uuml;ld&#337;k c&iacute;mei
szerint csoportos&iacute;tva. A r&eacute;szletes oldalon az &ouml;sszes j&oacute;v&aacute;hagy&aacute;sra v&aacute;r&oacute;
lev&eacute;lr&#337;l b&#337;vebb inform&aacute;ci&oacute;t kapunk, megtekinthetj&uuml;k azok fejl&eacute;ceit &eacute;s
r&ouml;vid kivonat&aacute;t.

<p>Mindegyik oldalon a k&ouml;vetkez&#337; lehet&#337;s&eacute;gek k&ouml;z&uuml;l v&aacute;laszthatunk:

<ul>
<li><b>Elhalaszt</b> -- V&aacute;rakoztat&aacute;s a k&eacute;s&#337;bbi d&ouml;nt&eacute;sig. A beavatkoz&aacute;sra v&aacute;r&oacute;
    &uuml;zenet tov&aacute;bbra is f&uuml;gg&#337;ben marad, tov&aacute;bb&iacute;tani vagy meg&#337;rizni lehet a
    levelet (ld. k&eacute;s&#337;bb), annak t&ouml;rl&eacute;se n&eacute;lk&uuml;l.

<li><b>J&oacute;v&aacute;hagy</b> -- A list&aacute;ra k&uuml;ld&ouml;tt lev&eacute;l megjelen&eacute;s&eacute;t enged&eacute;lyezed.
    Listatags&aacute;ghoz kapcsol&oacute;d&oacute; k&eacute;relemn&eacute;l enged&eacute;lyezed a listatags&aacute;g
    megv&aacute;ltoztat&aacute;s&aacute;t.

<li><b>Visszautas&iacute;t</b> -- Levelet visszautas&iacute;tod, a bek&uuml;ld&#337; k&uuml;l&ouml;n &uuml;zenetben
    &eacute;rtes&uuml;l a lev&eacute;l visszautas&iacute;t&aacute;s&aacute;r&oacute;l. Az eredeti lev&eacute;l figyelmen k&iacute;v&uuml;l lesz
    hagyva. Listatags&aacute;gi k&eacute;relemn&eacute;l nem enged&eacute;lyezed a listatags&aacute;g
    megv&aacute;ltoztat&aacute;s&aacute;t.
    Mindk&eacute;t esetben c&eacute;lszer&#369; a visszautas&iacute;t&aacute;s indok&aacute;t a megfelel&#337; sz&ouml;vegmez&#337;ben
    megadni.

<li><b>Elvet</b> -- Az eredeti lev&eacute;l figyelmen k&iacute;v&uuml;l lesz hagyva, de err&#337;l a
    bek&uuml;ld&#337;je &eacute;rtes&iacute;t&eacute;st nem kap. Listatags&aacute;gi k&eacute;relemn&eacute;l a k&eacute;relmez&#337;
    &eacute;rtes&iacute;t&eacute;se n&eacute;lk&uuml;l ker&uuml;l visszautas&iacute;t&aacute;sra a k&eacute;relem. Ez az opci&oacute; f&#337;leg
    spam-ek eset&eacute;n haszn&aacute;latos.
</ul>

<p>A <b>Meg&#337;riz</b> opci&oacute;val a lev&eacute;l egy m&aacute;solat&aacute;t lehet a rendszer
adminisztr&aacute;tor&aacute;nak elk&uuml;ldeni. S&eacute;rteget&#337; levelek eset&eacute;n el&#337;ny&ouml;s a haszn&aacute;lata,
amikor a levelet visszautas&iacute;tod, de k&eacute;s&#337;bb j&oacute;l j&ouml;het a m&aacute;solata.

<p>A <b>Tov&aacute;bb&iacute;t ide</b> opci&oacute;val a megadott c&iacute;mre (pl. aki nincs a list&aacute;n)
lehet a levelet tov&aacute;bbk&uuml;ldeni. Ha a list&aacute;n val&oacute; megjelen&eacute;s el&#337;tt m&oacute;dos&iacute;tani
szeretn&eacute;nk a j&oacute;v&aacute;hagy&aacute;sra v&aacute;r&oacute; lev&eacute;len, akkor k&uuml;ldj&uuml;k tov&aacute;bb magunknak (vagy
lista tulajdonos&aacute;nak), az eredeti lev&eacute;lre az <em>Elvet</em> parancsot 
haszn&aacute;ljuk. Ezek ut&aacute;n m&oacute;dos&iacute;tsuk ig&eacute;ny&uuml;nk szerint a levelet, majd k&uuml;ldj&uuml;k
el a list&aacute;ra &uacute;gy hogy a lev&eacute;lben egy <tt>Approved:</tt> fejl&eacute;cben megadjuk
a lista jelszav&aacute;t (ezzel azonnal enged&eacute;lyezz&uuml;k a lev&eacute;l megjelen&eacute;s&eacute;t a
list&aacute;n). A netetikett szerint ekkor t&uuml;ntess&uuml;k fel a lev&eacute;lben, hogy
az eredeti levelet m&oacute;dos&iacute;tottuk.

<p>Ha a bek&uuml;ld&#337; olyan listatag, akinek a moder&aacute;lt jelz&#337;je be van &aacute;ll&iacute;tva,
akkor az oldalon a tag moder&aacute;l&aacute;si jelz&#337;j&eacute;t is lehet t&ouml;r&ouml;lni. Ez akkor
hasznos, amikor a lista az &uacute;j tagoknak <em>pr&oacute;baid&#337;re</em> automatikusan
be&aacute;ll&iacute;tja a moder&aacute;lt jelz&#337;t &eacute;s &uacute;gy d&ouml;nt&uuml;nk, hogy a tagn&aacute;l m&aacute;r t&ouml;r&ouml;lni
lehet ezt a be&aacute;ll&iacute;t&aacute;st.

<p>Ha bek&uuml;ld&#337; nem listatag, akkor a c&iacute;m&eacute;t felvehetj&uuml;k a <em>felad&oacute;k 
sz&#369;r&eacute;se</em> be&aacute;ll&iacute;t&aacute;sokhoz. Err&#337;l a korl&aacute;toz&aacute;sr&oacute;l a <a href="%(filterurl)s">
felad&oacute;k sz&#369;r&eacute;se oldalon</a> lehet olvasni. A sz&#369;r&eacute;sn&eacute;l az <b>
automatikusan-enged&eacute;lyezett</b> (Enged&eacute;lyezett), <b>automatikusan-f&uuml;gg&#337;</b>
(F&uuml;gg&#337;), <b>automatikusan-visszautas&iacute;tott</b> (Visszautas&iacute;tott), vagy 
<b>automatikusan-elvetett</b> (Elvetett) opci&oacute;k k&ouml;z&uuml;l lehet v&aacute;lasztani.
A kapcsol&oacute; csak akkor jelenik meg, ha a bek&uuml;ld&#337; c&iacute;me egyik sz&#369;r&#337;n&eacute;l sincs 
megadva.

<p>A m&#369;veletek befejez&eacute;s&eacute;hez kattintsunk a lap alj&aacute;n vagy tetej&eacute;n tal&aacute;lhat&oacute;
<em>&Ouml;sszes v&aacute;ltoztat&aacute;s ment&eacute;se</em> gombra. Ekkor az &ouml;sszes be&aacute;ll&iacute;t&aacute;s
v&eacute;grehajt&oacute;dik.  Ha egy vagy t&ouml;bb k&eacute;relemr&#337;l nem akarsz most d&ouml;nteni, akkor
ne adj meg parancsot, ekkor ezek a k&eacute;relmek a meger&#337;s&iacute;t&eacute;s&eacute;re v&aacute;r&oacute;k sor&aacute;ban
maradnak.

<p><a href="%(summaryurl)s">Vissza az &ouml;sszes&iacute;t&#337; oldalra</a>.
