<html>
<head>
  <title>%(listname)s %(who)s inloggen</title>
  <script>function sf(){document.f.adminpw.focus();}</script>
</head>
<body bgcolor="#ffffff" onLoad="sf()">
<FORM METHOD=POST ACTION="%(path)s" name="f">
%(message)s
  <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
    <TR>
      <TD COLSPAN="2" WIDTH="100%%" BGCOLOR="#99CCFF" ALIGN="CENTER">
	<B><FONT COLOR="#000000" SIZE="+1">%(listname)s %(who)s
	    inloggen</FONT></B>
      </TD>
    </TR>
    <tr>
      <TD><div ALIGN="Right">Lijst%(who)s wachtwoord:</div></TD>
      <TD><INPUT TYPE="password" NAME="adminpw" SIZE="30"></TD>
    </tr>
    <tr>
      <td colspan=2 align=middle><INPUT type="SUBMIT"
                                        name="admlogin"
					value="Inloggen">
      </td>
    </tr>
  </TABLE>
      <p><strong><em>Belangrijk:</em></strong><br>
      Vanaf hier moet het gebruik van cookies in uw browser toegelaten zijn, anders kunnen uw
      administratieve handelingen niet geeffectueerd worden!
      <p>'Session cookies' worden gebruikt in Mailman's administratieve interface opdat u zichzelf 
      niet steeds weer dient te identificeren bij elke handeling. Dit cookie zal automatisch verlopen
      als u de browser afsluit, of wanneer u zelf het cookie actief doet verlopen door op 
      de <em>Uitloggen</em> link te klikken in de hierna volgende schermen.
</FORM>
</body>
</html>