<!-- $Revision: 8177 $ -->
<html>
<head>
    <link rel="SHORTCUT ICON" href="<mm-favicon>">
    <title><MM-Presentable-User> Konfigurace konference <MM-List-Name></title>

</head>
<BODY BGCOLOR="#ffffff">
	<TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="5">
	<TR><TD WIDTH="100%" BGCOLOR="#99CCFF"><B>
	<FONT COLOR="#000000" SIZE=+1>
        <MM-List-Name> Nastaven&iacute; pro uživatele: <MM-Presentable-User>
	</FONT></B></TD></TR> </TABLE>
<p>
<table width="100%" border="0" cellspacing="5" cellpadding="5">
    <tr><td>
        <b>Uživatel <MM-Presentable-User></b>, konfigurace
	uživatelsk&eacute;ho &uacute;čtu pro konferenci <MM-List-Name>.
        </td><td><MM-Form-Start><mm-logout-button><MM-Form-End></td>
    </tr><tr>
        <td colspan="2">
        <MM-Case-Preserved-User>

        <MM-Disabled-Notice>

        <p><mm-results>
        </td>
    </tr>
</table>

<MM-Form-Start>
<p>
<TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="5">
    <TR><TD WIDTH="100%" BGCOLOR="#FFF0D0" colspan="2">
        <FONT COLOR="#000000">
        <B>Změna konfigurace pro konferenci <MM-List-Name></B>
	</FONT></TD></TR>
    <tr><td colspan="2">Můžete změnit e-mailovou adresu, na kterou se
    zas&iacute;laj&iacute; př&iacute;spěvky. Zadejte novou adresu do tohoto pole. Na Va&scaron;i
    st&aacute;vaj&iacute;c&iacute; adresu bude zasl&aacute;na ž&aacute;dost o ověřen&iacute; a změna bude
    provedena teprve po potvrzen&iacute;.

        <p>Na potvrzen&iacute; budeme čekat <mm-pending-days> dn&iacute;.

        <p>Můžete si nastavit i sv&eacute; jm&eacute;no, jako např.
        <em>Petr Nov&aacute;k</em>.

        <p>Pokud se maj&iacute; proveden&eacute; změny projevit ve v&scaron;ech
	konferenc&iacute;ch na tomto serveru, mus&iacute;te za&scaron;krtnout volbu
        <em>Změnit glob&aacute;lně</em>.

        </td></tr>
    <tr><td><center>
        <table border="0" cellspacing="2" cellpadding="2" width="80%" cols="2">
        <tr><td bgcolor="#dddddd"><div align="right">Nov&aacute; adresa:</div></td>
            <td><mm-new-address-box></td>
            </tr>
        <tr><td bgcolor="#dddddd"><div align="right">Znovu pro potvrzen&iacute;:
            </div></td> 
            <td><mm-confirm-address-box></td>
            </tr>
        </tr></table></center>
        </td>
        <td><center>
        <table border="0" cellspacing="2" cellpadding="2" width="80%" cols="2">
            <tr><td bgcolor="#dddddd"><div align="right">Cel&eacute; jm&eacute;no
            (nepovinn&eacute;):</div></td>
            <td><mm-fullname-box></td>
            </tr>
        </table></center>
        </td>
        </tr>
    <tr><td colspan="2"><center><mm-change-address-button>
        <p><mm-global-change-of-address>Změnit glob&aacute;lně</center></td>
    </tr>
</table>

<p>
<TABLE WIDTH="100%" BORDER="0" CELLSPACING=5" CELLPADDING="5">
	<TR><TD WIDTH="50%" BGCOLOR="#FFF0D0"><FONT COLOR="#000000">
<B>Odhl&aacute;&scaron;en&iacute; z <MM-List-Name></B>

	<TD WIDTH="50%" BGCOLOR="#FFF0D0"><FONT COLOR="#000000">
<B>Va&scaron;e ostatn&iacute;  přihl&aacute;&scaron;en&eacute; konference na  <MM-Host></B>
	</FONT></TD></TR>

	<tr><td>
         Pro odhl&aacute;&scaron;en&iacute; za&scaron;krtněte pol&iacute;čko a klikněte na tlač&iacute;tko
	 Odhl&aacute;sit. <strong>Pozor:</strong>
	 Změna se projev&iacute; okamžitě.
	 <p>
	 <center><MM-Unsubscribe-Button></center></td>
     <td>
        Můžete si zobrazit seznam v&scaron;ech dal&scaron;&iacute;ch konferenc&iacute; na tomto
	serveru, jejichž jste členy. Pokud zvol&iacute;te tuto volbu,
	prom&iacute;tnou se zde proveden&eacute; změny i do v&scaron;ech ostatn&iacute;ch kont.
        <p>
        <center><MM-Other-Subscriptions-Submit></center>
	</TD></TR>
</table>

<TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="5">
     <TR><TD COLSPAN=2 WIDTH="100%" BGCOLOR="#FFF0D0"><FONT COLOR="#000000">
	<B>Va&scaron;e heslo pro  <MM-List-Name></B>
	</FONT></TD></TR>

    <tr valign="TOP"><td WIDTH="50%">
        <a name=reminder>
        <center>
        <h3>Zapomněli jste heslo?</h3>
        </center>
         Klikněte na toto tlač&iacute;tko a heslo V&aacute;m bude zasl&aacute;no na Va&scaron;&iacute;
         e-mailovou adresu.
	 <p>
	 <MM-Umbrella-Notice>
	 <center>
	 <MM-Email-My-Pw>
	 </center>
	 </td>

     <td WIDTH="50%">
         <a name=changepw>
         <center>
	 <h3>Změna hesla</h3>
      	 <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2" WIDTH="70%" COLS=2>
	    <TR><TD BGCOLOR="#dddddd">Nov&eacute; heslo:</TD>
	<TD><MM-New-Pass-Box></TD>
      </TR>
      <TR> 
	<TD BGCOLOR="#dddddd">A je&scaron;tě jednou nov&eacute; pro kontrolu:</TD>
	<TD><MM-Confirm-Pass-Box></TD>
      </TR>
</table>
           <MM-Change-Pass-Button>
        <p><center><mm-global-pw-changes-button>Změnit glob&aacute;lně.
     </TABLE>

<p>
<TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="5">
	<TR><TD WIDTH="100%" BGCOLOR="#FFF0D0"><FONT COLOR="#000000">
<B>Nastaven&iacute; Va&scaron;eho konta pro konferenci <MM-List-Name> </B>
	</FONT></TD></TR>
</table>

<p>
<i><strong>Aktu&aacute;ln&iacute; hodnoty jsou za&scaron;krtnuty</strong></i><p>

<p>Pozor, u někter&yacute;ch voleb je checkbox <em>Nastavit glob&aacute;lně</em>.
Pokud jej za&scaron;krtnete, provedou se změny ve v&scaron;ech konferenc&iacute;ch, do
kter&yacute;ch jste přihl&aacute;&scaron;eni na tomto serveru. Pokud chcete vědět, kter&eacute; to
jsou, klikněte na <em>Seznam ostatn&iacute;ch konferenc&iacute;</em> nahoře na str&aacute;nce.
<p>
<TABLE BORDER="0" CELLSPACING="3" CELLPADDING="4" WIDTH="100%">
    <tr><TD BGCOLOR="#cccccc">
        <a name="disable">
        <strong>Zak&aacute;zat zas&iacute;l&aacute;n&iacute; př&iacute;spěvků</strong></a><p>
Vyberte tuto volbu, pokud si nepřejete dost&aacute;vat ž&aacute;dn&eacute; př&iacute;spěvky.
</td><td bgcolor="#cccccc">
<mm-delivery-enable-button> Zas&iacute;lat<br>
<mm-delivery-disable-button> Nezas&iacute;lat<br>
        <mm-global-deliver-button><i>Nastavit glob&aacute;lně</i>
        </td></tr>

<!--Start-Digests-Delete-->
    <tr><TD BGCOLOR="#cccccc">
        <strong>Zapnut&iacute; digest režimu</strong><p>
Pokud je zapnut digest režim dostanete v&scaron;echny př&iacute;spěvky v jednom dopise
jednou denně. Pokud digest vypnete, dostanete př&iacute;spěvky z posledn&iacute;ho dne
je&scaron;tě v digest formě.
        </td><td bgcolor="#cccccc">
        <MM-Undigest-Radio-Button>Vypnuto<br>
        <MM-Digest-Radio-Button>Zapnuto
        </td></tr>
        
    <tr><TD BGCOLOR="#cccccc">
        <strong>Přejete si digest dost&aacute;vat jako MIME zpr&aacute;vu nebo čist&yacute;
	text?</strong><p>
Pokud V&aacute;&scaron; po&scaron;tovn&iacute; klient nedok&aacute;že přeč&iacute;st MIME zpr&aacute;vu, nastavte si zde
volbu čist&yacute; text. Tato volba nem&aacute; ž&aacute;dn&yacute; v&yacute;znam, pokud nen&iacute; digest aktivn&iacute;.<br>
        </td><td bgcolor="#cccccc">
        <MM-Mime-Digests-Button>MIME<br>
        <MM-Plain-Digests-Button>Čist&yacute; text<p>
        <mm-global-mime-button><i>Nastavit glob&aacute;lně</i>
        </td></tr>
<!--End-Digests-Delete-->
        
    <tr><TD BGCOLOR="#cccccc">
        <strong>Přejete si dost&aacute;vat př&iacute;spěvky, kter&eacute; jste sami zaslali do
konference?</strong><p>
        </td><td bgcolor="#cccccc">
        <mm-dont-receive-own-mail-button>Ne<br>
        <mm-receive-own-mail-button>Ano
        </td></tr>

    <tr><TD BGCOLOR="#cccccc">
        <strong> Přejete si dost&aacute;vat ozn&aacute;men&iacute; o rozesl&aacute;n&iacute; vlastn&iacute;ch př&iacute;spěvků?</strong><p>
        </td><td bgcolor="#cccccc">
        <mm-dont-ack-posts-button>Ne<br>
        <mm-ack-posts-button>Ano
        </td></tr>

    <tr><td bgcolor="#cccccc">
        <strong>Chcete dost&aacute;vat upozorněn&iacute; na hesla?</strong><p>
	Ve v&yacute;choz&iacute; konfiguraci dost&aacute;v&aacute;te jednou měs&iacute;čně mailem
	zpr&aacute;vu, kde je uveden seznam konferenc&iacute; a k nim př&iacute;slu&scaron;n&aacute;
	hesla, kter&aacute; potřebujete pro různ&eacute; administrativn&iacute; operace.
        Pokud vyberete <em>Ne</em>, nebudete tento mail
	dost&aacute;vat. Př&iacute;padně zapomenut&eacute; heslo si můžete poslat
	z webovsk&eacute;ho rozhran&iacute;.
        </td><td bgcolor="#cccccc">
        <mm-dont-get-password-reminder-button>Ne<br>
        <mm-get-password-reminder-button>Ano<p>
        <mm-global-remind-button><i>Nastavit glob&aacute;lně</i>
        </td></tr>

    <tr><TD BGCOLOR="#cccccc">
        <strong>Přejete si b&yacute;t vidět v seznamu &uacute;častn&iacute;ků?</strong><p>
	Pokud si někdo zobraz&iacute; seznam &uacute;častn&iacute;ků, ve v&yacute;choz&iacute;
	konfiguraci vid&iacute; adresy v&scaron;ech &uacute;častn&iacute;ků. Pokud na tomto
	seznamu nechcete b&yacute;t uvedeni, můžete zde zobrazen&iacute; zak&aacute;zat.
        </td><td bgcolor="#cccccc">
        <MM-Public-Subscription-Button>Zobrazit<br>
        <MM-Hide-Subscription-Button>Skr&yacute;t
        </td></tr>

    <tr><TD BGCOLOR="#cccccc">
        <strong>Jakou řeč preferujete pro komunikaci s listserverem?</strong><p>
        </td><td bgcolor="#cccccc">
        <MM-list-langs>
        </td></tr>

    <tr><td bgcolor="#cccccc">
        <strong>Kter&aacute; t&eacute;mata V&aacute;s zaj&iacute;maj&iacute;?</strong><p>
	        Pokud si vyberete jedno nebo v&iacute;ce t&eacute;mat, můžete
		filtrovat př&iacute;spěvky z konference a dost&aacute;vat jedině
		ty, kter&eacute; V&aacute;s zaj&iacute;maj&iacute;.

                <p>U př&iacute;spěvků, kter&eacute; se nepodař&iacute; zatř&iacute;dit do ž&aacute;dn&eacute;
		kategorie, z&aacute;vis&iacute; na nastaven&iacute; dal&scaron;&iacute; volby, jestli je
		dostanete nebo ne. Pokud nezvol&iacute;te ž&aacute;dn&eacute; t&eacute;ma, budete
		dost&aacute;vat v&scaron;echny př&iacute;spěvky.
        </td><td bgcolor="#cccccc">
        <mm-topics>
        </td></tr>

    <tr><td bgcolor="#cccccc">
        <strong>Chcete dost&aacute;vat př&iacute;spěvky, kter&eacute; se nepodařilo
	zařadit do ž&aacute;dn&eacute; kategorie?</strong><p>

                Tato volba m&aacute; smysl jedině pokud jste si v předchoz&iacute;
		volbě vybral nějak&eacute; t&eacute;ma. Pokud zde
		odpov&iacute;te <em>Ne</em> nebudete dost&aacute;vat ž&aacute;dn&eacute;
		př&iacute;spěvky, kter&eacute; nespadaj&iacute; do Va&scaron;ich t&eacute;mat, jinak
		budete dost&aacute;vat i nezatřiditeln&eacute;.
        </td><td bgcolor="#cccccc">
        <mm-suppress-nonmatching-topics>Ne<br>
        <mm-receive-nonmatching-topics>Ano
        </td></tr>

    <tr><td bgcolor="#cccccc">
        <strong>Eliminuj duplicitn&iacute; př&iacute;spěvky?</strong><p>

                Pokud dostane listserver k rozesl&aacute;n&iacute; př&iacute;spěvek
                jste uvedeni v hlavičce <tt>To:</tt>
                nebo <tt>Cc:</tt> dostanete př&iacute;spěvek dvakr&aacute;t, jednou
                př&iacute;mo a jednou přes konferenci. Pokud vyberete
                volbu <em>Ano</em>, listserver takov&yacute; př&iacute;spěvek na va&scaron;i
                adresu neza&scaron;le a vy dostanete jen ten, kter&yacute; v&aacute;m
                zas&iacute;l&aacute; př&iacute;mo autor. Pokud vyberete volbu <em>Ne</em>
                dostanete př&iacute;spěvek pravděpodobně dvakr&aacute;t.

                <p>Pokud listserver rozes&iacute;l&aacute; každ&yacute; př&iacute;spěvek zvl&aacute;&scaron;ť,
                a vy m&aacute;te nastaveno, že si přejete dost&aacute;vat
                duplicitn&iacute; př&iacute;spěvky, bude m&iacute;t každ&yacute; duplicitn&iacute;
                př&iacute;spěvek přid&aacute;nu hlavičku 
                <tt>X-Mailman-Copy: yes</tt>.

        </td><td bgcolor="#cccccc">
        <mm-receive-duplicates-button>Ne<br>
        <mm-dont-receive-duplicates-button>Ano<p>
        <mm-global-nodupes-button><i>Nastavit glob&aacute;lně</i>
        </td></tr>

    <tr><TD colspan="2">
        <center><MM-options-Submit-button></center>
        </td></tr>

</table>
</center>
<p>
<MM-Form-End>

<MM-Mailman-Footer>
</body>
</html>
