<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<!-- $Revision: 7201 $ -->
<HTML>
  <HEAD>
    <TITLE><MM-List-Name> P&aacute;gina de Detalhes</TITLE>
  
  </HEAD>
  <BODY BGCOLOR="#ffffff">
    <P>
      <TABLE BORDER="0" CELLSPACING="4" CELLPADDING="5">
	<TR>
	  <TD COLSPAN="2" WIDTH="100%" BGCOLOR="#99CCFF" ALIGN="CENTER">
	    <B><FONT COLOR="#000000" SIZE="+1"><MM-List-Name> --
	<MM-List-Description></FONT></B>
	  </TD>
	</TR>
	<tr>
	    <td colspan="2">
	      <p>&nbsp;
	    </td>
	  </tr>
	  <tr>
	    <TD COLSPAN="1" WIDTH="100%" BGCOLOR="#FFF0D0">
	      <B><FONT COLOR="#000000">Sobre a lista <MM-List-Name></FONT></B>
	    </TD>
            <TD COLSPAN="1" WIDTH="100%" BGCOLOR="#FFF0D0">
              <MM-lang-form-start><MM-displang-box> <MM-list-langs>
              <MM-form-end>
            </TD>
	  </TR>
	    <tr>
	      <td colspan="2">
		<P><MM-List-Info></P>
	  <p> Para ver uma lista das mensagens que foram postadas 
	  anteriormente na lista, entre nos 
	  <MM-Archive>Arquivos da lista <MM-List-Name></MM-Archive>.
	      <MM-Restricted-List-Message>
	  </p>
	</TD>
      </TR>
      <TR>
	<TD COLSPAN="2" WIDTH="100%" BGCOLOR="#FFF0D0">
	  <B><FONT COLOR="#000000">Usando a lista <MM-List-Name></FONT></B>
	</TD>
      </TR>
      <tr>
	<td colspan="2">
	  Para postar uma mensagem para todos os membros da lista, envie um
	  email para
	  <A HREF="mailto:<MM-Posting-Addr>"><MM-Posting-Addr></A>.

	  <p>Voc&ecirc; poder&aacute; se inscrever na lista ou modificar seus dados
	  de inscri&ccedil;&atilde;o nas se&ccedil;&otilde;es abaixo.
	</td>
      </tr>
      <TR>
	<TD COLSPAN="2" WIDTH="100%" BGCOLOR="#FFF0D0">
	  <B><FONT COLOR="#000000">Inscrevendo-se na lista <MM-List-Name></FONT></B>
	</TD>
      </TR>
      <tr>
	<td colspan="2">
	  <P>
	    Para se inscrever na lista <MM-List-Name>, preencha o seguinte
	      formul&aacute;rio.
	  <MM-List-Subscription-Msg>
	  <ul>
    <MM-Subscribe-Form-Start>
	      <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2"
		WIDTH="70%">
		<TR>
		  <TD BGCOLOR="#dddddd" WIDTH="55%">Seu endere&ccedil;o de email:</TD>
		  <TD WIDTH="33%"><MM-Subscribe-Box>
	</TD>
	<TD WIDTH="12%">&nbsp;</TD></TR>
      <tr>
        <td bgcolor="#dddddd" width="55%">Seu nome (opcional):</td>
        <td width="33%"><mm-fullname-box></td>
	<TD WIDTH="12%">&nbsp;</TD></TR>
      <TR>
	<TD COLSPAN="3"><FONT SIZE=-1>Entre com uma 
	    senha privativa abaixo. Isto oferece somente 
	    seguran&ccedil;a m&eacute;dia, mas deve evitar que outras pessoas 
	    obtenham sua inscri&ccedil;&atilde;o. <b>N&atilde;o escolha uma senha 
	    usada em outras coisas</b> pois ela provavelmente 
	    lhe ser&aacute; encaminhada de volta usando o formato de texto desprotegido.

            <br><br>Caso tenha escolhido n&atilde;o entrar com uma senha, ser&aacute; gerada
	    automaticamente uma senha que lhe ser&aacute; enviada
	    assim que voc&ecirc; confirmar sua inscri&ccedil;&atilde;o. &Eacute; poss&iacute;vel requisitar
	    o reenvio de sua senha ao modificar suas op&ccedil;&otilde;es pessoais.
	    <MM-Reminder>
	    </font>
	</TD>
      </TR>  
      <TR>
	<TD BGCOLOR="#dddddd">Escolha uma senha:</TD>
	<TD><MM-New-Password-Box></TD>
	<TD>&nbsp;</TD></TR>
      <TR> 
	<TD BGCOLOR="#dddddd">Redigite a senha para confirma&ccedil;&atilde;o:</TD>
	<TD><MM-Confirm-Password></TD>
	<TD>&nbsp; </TD></TR>
      <tr>
        <TD BGCOLOR="#dddddd">Em que idioma prefere exibir suas mensagens?</TD> 
        <TD> <MM-list-langs></TD>
        <TD>&nbsp; </TD></TR>
      <mm-digest-question-start>
      <tr>
	<td>Deseja receber e-mails da lista enviados uma vez por dia em um &uacute;nico 
	email (digest)?
	  </td>
	<td><MM-Undigest-Radio-Button> N&atilde;o
	    <MM-Digest-Radio-Button>  Sim
	</TD>
      </tr>
      <mm-digest-question-end>
      <mm-recaptcha-ui>
      <mm-captcha-ui>
      <tr>
	<td colspan="3">
	  <center><MM-Subscribe-Button></center>
    </td>
    </tr>
    </TABLE>
    <MM-Form-End>
    </ul>
    <TR>
      <TD COLSPAN="2" WIDTH="100%" BGCOLOR="#FFF0D0">
	<a name="subscribers">
        <B><FONT COLOR="#000000">Inscritos na lista <MM-List-Name></FONT></B></a>
      </TD>
    </TR>
    <tr>
      <TD COLSPAN="2" WIDTH="100%">
	<MM-Roster-Form-Start>
	<MM-Roster-Option>
	    <MM-Form-End>
	  <p>
	<MM-Options-Form-Start>
	<MM-Editing-Options>
		<MM-Form-End>
      </td>
    </tr>
  </table>
<MM-Mailman-Footer>
</BODY>
</HTML>
