Questo testo pu&ograve; includere <a
href="https://docs.python.org/2/library/stdtypes.html#string-formatting-operations">Stringhe
di formato Python</a> che saranno sostituite automaticamente dai
valori degli attributi della lista.  L'elenco degli attributi permessi
&egrave;:
<ul>
	<li><b>real_name</b> - Il nome `di facciata' della 
	lista; di solito &egrave; il nome della lista con lettere maiuscole.
	
	<li><b>list_name</b> - Il nome con cui la lista 
	&egrave; identificata negli URL, dove maiuscole e minuscole sono 
	importanti.

	<li><b>host_name</b> - Il nome FQDN dell'host sul 
	quale viene eseguito il list server.
	                                                  
	<li><b>web_page_url</b> - L'URL di base per Mailman.
	A questo valore viene appeso ad esempio 
        <em>listinfo/%(list_name)s</em> per ottenere
	l'indirizzo della pagina listinfo per la lista.

	<li><b>description</b> - La descrizione sommaria 
	della lista.

	<li><b>info</b> - La descrizione completa della 
	lista.
	
	<li><b>cgiext</b> - Estensione aggiunta ai nomi
	degli script CGI
</ul>
