<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<HTML>
  <HEAD>
     <title>%(listname)s Arşivleri</title>
     <META NAME="robots" CONTENT="noindex,follow">
  </HEAD>
  <BODY BGCOLOR="#ffffff">
     <h1>%(listname)s Arşivleri </h1>
     <p>
      Bu listeye hen&uuml;z hi&ccedil; mesaj g&ouml;nderilmemiş, bu y&uuml;zden arşivler şu anda
      boş. Bu listeyle ilgili <a href="%(listinfo)s">daha fazla bilgi
      alabilirsiniz</a>.
     </p>
  </BODY>
  </HTML>

