Trang này chứa bản tóm tắt các yêu cầu quản trị cần thiết bạn tán thành cho <a href="%(adminurl)s">hộp thư chung <em>%(listname)s</em></a>.
Trước tiên, bạn sẽ tìm thấy danh sách các yêu cầu đăng ký và hủy đăng ký bị hoãn, nếu có, và sau đó nằm bài thư nào được giữ lại cho bạn tán thành.

<p>Đối với mỗi yêu câù quản trị, vui lòng chọn hành động cần làm, rồi nhắp vào cái nút  <b>Đệ trình các thay đổi</b> khi làm xong. Cũng có sẵn
<a href="%(detailsurl)s">Hướng dẫn chi tiết</a>.

<p>Bạn cũng có thể <a href="%(viewallurl)s">xem thông tin</a> về mọi bài thư đã giữ lại.
