Sprendimo laukiančių lai&scaron;kų santrauka

<p>Čia santrauka lai&scaron;kų, laukiančių jūsų sprendimo dėl 
<a href="%(adminurl)s">forumo <em>%(listname)s</em></a>.

Pradžioje - prisijungimo ir atsijungimo pra&scaron;ymai,
toliau - lai&scaron;kai, dėl kurių turite apsispręsti.

<p>Kiekvienai administravimo užklausai pažymėkite veiksmą
ir baigę paspauskite <b>Siųsti Visus Duomenis</b>.

<p>Smulkesnė instrukcija <a href="%(detailsurl)s">čia</a>.

<p>Taip pat galite peržiūrėti <a href="%(viewallurl)s">pilną sprendimo laukiančių lai&scaron;kų sąra&scaron;ą</a>.
