<html>
<head>
    <title>%(realname)s &Ouml;zel Arşivleri Girişi</title>
    <script>function sf(){document.f.username.focus();}</script>
</head>
<body bgcolor="#ffffff" onLoad="sf()">
<FORM METHOD=POST ACTION="%(action)s" name="f">
%(message)s
  <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
    <TR>
      <TD COLSPAN="2" WIDTH="100%%" BGCOLOR="#99CCFF" ALIGN="CENTER">
	<B><FONT COLOR="#000000" SIZE="+1">%(realname)s &Ouml;zel
	    Arşivleri Girişi</FONT></B>
      </TD>
    </TR>
    <tr>
        <TD><div ALIGN="Right">E-posta adresi:</div></TD>
        <TD><INPUT TYPE="text" NAME="username" SIZE="30"></TD>
    </tr>
    <tr>
      <TD><div ALIGN="Right">Şifre:</div></TD>
      <TD><INPUT TYPE="password" NAME="password" SIZE="30"></TD>
    </tr>
    <tr>
      <td colspan=2 align="middle"><INPUT type="SUBMIT"
                                          name="submit"
					  value="Giriş...">
      </td>
    </tr>
  </TABLE>
      <p><strong><em>&Ouml;nemli:</em></strong> Bu noktadan itibaren tarayıcınızda
      tanımlama bilgilerini (cookie) etkinleştirmiş olmanız gerekir, yoksa hi&ccedil;bir
      y&ouml;netimsel değişiklik yapılmayacaktır.

      <p>Mailman'in y&ouml;netimsel aray&uuml;z&uuml;nde oturum tanımlayıcı bilgileri
      kullanılır, b&ouml;ylece her y&ouml;netimsel işlemde tekrar yetkilendirme
      yapmanıza gerek kalmaz. Bu tanımlayıcı bilgi tarayıcınızdan
      &ccedil;ıktığınızda otomatik olarak yok olur, veya siz tanımlayıcı
      bilgiyi <em>Diğer Y&ouml;netimsel Aktiviteler</em> başlığı altındaki
      <em>&Ccedil;ıkış</em> linkine tıklayarak (başarıyla giriş yaptığınızda
      bunu g&ouml;receksiniz) kendiniz yok edebilirsiniz.
      <p>
    <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
    <TR>
      <TD COLSPAN="2" WIDTH="100%%" BGCOLOR="#99CCFF" ALIGN="CENTER">
	<B><FONT COLOR="#000000" SIZE="+1">Password Reminder</FONT></B>
      </TD>
    </TR>
    <tr>
      <td>If you don't remember your password, enter your email address
          above and click the <em>Remind</em> button and your
          password will be emailed to you.</td>
    </tr>
    <tr>
      <td><center><INPUT name="login-remind" type="SUBMIT" value="Remind" ></center></td>
    </tr>
  </TABLE>
</FORM>
</body>
</html>

