<!-- $Revision: 7047 $ -->
<html>
<head><title><MM-List-Name> Subscription results</title></head>
<body bgcolor="white">
<h1><MM-List-Name> Subscription results</h1>
<MM-Results>
<MM-Mailman-Footer>
</body>
</html>
