Na tej strani najdete sporočila za seznam <em>%(listname)s</em>, ki
čakajo na va&scaron;o odobritev. Trenutno je prikazano %(description)s

<p>Za vsako skrbni&scaron;ko zahtevo izberite dejanje, tako da kliknete na
gumb <b>Po&scaron;lji vse podatke</b> (Submit all data), ko končate. Bolj
podrobna navodila najdete <a href="%(detailsurl)s">tukaj</a>.

<p>Lahko si tudi <a href="%(summaryurl)s">ogledate povzetek</a> vseh
čakajočih zahtev.
