Denne siden inneholder noen av de epostene til listen <em>%(listname)s</em>
som holdes tilbake for godkjenning. N&aring; viser den
%(description)s

<p>Velg &oslash;nsket avgj&oslash;relse for hver foresp&oslash;rsel, og trykk deretter <em>Utf&oslash;re</em>
n&aring;r du er ferdig. N&aelig;rmere instruksjoner finner du <a href="%(detailsurl)s">her</a>.

<p>Du kan ogs&aring; <a href="%(summaryurl)s">vise en oversikt</a> over alle forep&oslash;rsler som venter p&aring; en avgj&oslash;relse.
