<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<HTML>
  <HEAD>
     <title>Arkiv for epostlisten %(listname)s</title>
     <META NAME="robots" CONTENT="noindex,follow">
  </HEAD>
  <BODY BGCOLOR="#ffffff">
     <h1>Arkiv for epostlisten %(listname)s</h1>
     <p>
      Ingen meldinger er sendt til denne listen enda, s&aring; arkivet er for tiden tomt.
      <a href="%(listinfo)s">Mer informasjon om listen</a> er tilgjengelig.
     </p>
  </BODY>
  </HTML>
