<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<HTML>
  <HEAD>
	  <title>Gli archivi della lista %(listname)s</title>
     <META NAME="robots" CONTENT="noindex,follow">
     %(meta)s
  </HEAD>
  <BODY BGCOLOR="#ffffff">
	  <h1>Gli archivi della lista %(listname)s</h1>
     <p>
     Puoi ottenere <a href="%(listinfo)s">ulteriori informazioni su questa lista</a>
     o puoi <a href="%(fullarch)s">scaricare l'intero archivio grezzo</a>
      (%(size)s).
     </p>
     %(noarchive_msg)s
     %(archive_listing_start)s
     %(archive_listing)s
     %(archive_listing_end)s
     </BODY>
     </HTML>
