Bu sayfa, <em>%(listname)s</em> listesine g&ouml;nderilmiş ve onayınız i&ccedil;in
bekletilen mesajların bir altk&uuml;mesini i&ccedil;erir. Şu anda g&ouml;r&uuml;nt&uuml;lenen:
%(description)s

<p>Her bir y&ouml;netimsel istek i&ccedil;in, l&uuml;tfen uygulanacak eylemi se&ccedil;in ve
işiniz bitince <strong>T&uuml;m Veriyi G&ouml;nder</strong> d&uuml;ğmesine tıklayın.
<a href="%(detailsurl)s">Burada</a> daha ayrıntılı a&ccedil;ıklamaları
bulabilirsiniz.

<p>Ayrıca t&uuml;m bekleyen isteklerin <a href="%(summaryurl)s">bir &ouml;zetini de</a>
g&ouml;rebilirsiniz.

