<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<HTML>
  <HEAD>
  <title>Els arxius de la llista %(listname)s</title>
     <META NAME="robots" CONTENT="noindex,follow">
     %(meta)s
  </HEAD>
  <BODY BGCOLOR="#ffffff">
     <h1>Arxius de la llista %(listname)s</h1>
     <p>
      Podeu obtenir <a href="%(listinfo)s">m&eacute;s informaci&oacute; sobre aquesta llista</a>.
     </p>
     %(noarchive_msg)s
     %(archive_listing_start)s
     %(archive_listing)s
     %(archive_listing_end)s
     </BODY>
     </HTML>
