<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<HTML>
  <HEAD>
     <title>Archiv konference %(listname)s</title>
     <META NAME="robots" CONTENT="noindex,follow">
  </HEAD>
  <BODY BGCOLOR="#ffffff">
     <h1>Archiv konference %(listname)s</h1>
     <p>
      Do t&eacute;to konference nebyl dosud zasl&aacute;n ž&aacute;dn&yacute; př&iacute;spěvek.
      Proto je tento archiv pr&aacute;zdn&yacute;. V&iacute;ce informac&iacute; o konferenci
      z&iacute;sk&aacute;te na <a href="%(listinfo)s">informačn&iacute; str&aacute;nce.</a>.
     </p>
  </BODY>
  </HTML>
