<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<HTML>
  <HEAD>
     <title>Le archivo %(listname)s</title>
     <META NAME="robots" CONTENT="noindex,follow">
  </HEAD>
  <BODY BGCOLOR="#ffffff">
     <h1>Le archivo %(listname)s</h1>
     <p>
      Nulle message ha ancora essite inviate al lista, ergo le archivos
      es currentemente vacue. Tu pote vider <a href="%(listinfo)s">plus
      de informationes super iste lista</a>.
     </p>
  </BODY>
  </HTML>
