<html>
<head>
<title>Autentificaci&oacute;n del %(who)s de %(listname)s</title>
  <script>function sf(){document.f.adminpw.focus();}</script>
</head>
<body bgcolor="#ffffff" onLoad="sf()">
<FORM METHOD=POST ACTION="%(path)s" name="f">
%(message)s
  <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
    <TR>
      <TD COLSPAN="2" WIDTH="100%%" BGCOLOR="#99CCFF" ALIGN="CENTER">
	<B><FONT COLOR="#000000" SIZE="+1">
        Autentificaci&oacute;n del %(who)s de %(listname)s</font></b>
      </td>
    </tr>
    <tr>
      <td><div align="right">Llista Contrase&ntilde;es %(who)s:</div>
</td>
      <TD><INPUT TYPE="password" NAME="adminpw" SIZE="30"></TD>
    </tr>
    <tr>
      <td colspan=2 align=middle><INPUT type="SUBMIT"
                                        name="admlogin"
					value="Con permisu...">
      </td>
    </tr>
  </table>
      <p><strong><em>Importante:</em></strong> A partir d'agora, tienes de tener habilitaes les cookies nel restolador, en casu contrariu, los cambeos nun fadr&aacute;n efeutu.

      <p>La interface alministrativa de Mailman emplega sesiones basaes en cookies, de mou que nun necesites identificate de contino con cada operaci&oacute;n alministrativa que faigas. La cookie va caducar autom&aacute;ticamente cuando salgas del restolador, o puedes facela caducar esbillando la opci&oacute;n <em>Salida</em> baxo la seici&oacute;n titulada <em> Otres Actividades Alministratives</em> (que ver&aacute;s una vegada que consigas entrar 
con &eacute;xitu).
</form>
</body>
</html>
