טקסט זה יכול לכלול 
<a href="https://docs.python.org/2/library/stdtypes.html#string-formatting-operations">מחרוזות
בפורמאט Python</a> אשר מפוענחות מול תכונות הרשימה. רשימת
תתי-המצבים המותרים:
<ul>
    <li><b>real_name</b> - השם "היפה" של הרשימה; בד"כ
    שם הרשימה עם אותיות ראשיות מתאימות.

    <li><b>list_name</b> - השם לפיו מזהים את הרשימה
    בקישורים, כאשר יש חשיבות לראשיות התווים.

    <li><b>host_name</b> - שם התחום המלא של השרת שמריץ
	רשימה זו.

    <li><b>web_page_url</b> - קישור הבסיס של דוור.  לזה
	אפשר להוסיף
    למשל <em>listinfo/%(list_name)s</em> שמניב את
    עמוד ה-listinfo עבור רשימת הדיוור.

    <li><b>description</b> - התאור הקצר של רשימת הדיוור.

    <li><b>info</b> - התאור המלא של רשימת הדיוור.

    <li><b>cgiext</b> - הסיומת המתווספת אל אצוות CGI.
</ul>
