<html>
<head>
  <title>%(listname)s Zerrendako %(who)s Identifikatzen</title>
  <script>function sf(){document.f.adminpw.focus();}</script>
</head>
<body bgcolor="#ffffff" onLoad="sf()">
<FORM METHOD=POST ACTION="%(path)s" name="f">
%(message)s
  <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
    <TR>
      <TD COLSPAN="2" WIDTH="100%%" BGCOLOR="#99CCFF" ALIGN="CENTER">
	<B><FONT COLOR="#000000" SIZE="+1">%(listname)s Zerrendako %(who)s
	    Identifikatzeko Orria</FONT></B>
      </TD>
    </TR>
    <tr>
      <TD><div ALIGN="Right">%(who)sren Pasahitza:</div></TD>
      <TD><INPUT TYPE="password" NAME="adminpw" SIZE="30"></TD>
    </tr>
    <tr>
      <td colspan=2 align=middle><INPUT type="SUBMIT"
                                        name="admlogin"
					value="Laga sartzen...">
      </td>
    </tr>
  </TABLE>
      <p><strong><em>Garrantzitsua:</em></strong> Hemendik aurrera, 
      cookie-ak behar dituzu nabigatzailean, bestela aldaketa administratiboak
      ez dira gauzatuko.

      <p>Mailmanen administrazio interfazeak cookie-ak erabiltzen ditu  
      zu ezagutzeko, eta ez zaitezen, behin eta berriro, zure burua 
	  identifikatzen aritu.  Cookie-ak automatikoki ezgaitzen dira zuk 
	  nabigatzailea itxi bezain azkar; nahi baduzu, zuk ere zuzenean ezgaitu ditzakezu 
	  <em>Kudeatzailearen Beste Jarduera Batzuk</em> barruan, <em>Saioa Amaitu</em> 
	  sakatuz (aukera hori behin sartu ondoren agertuko zaizu, ez lehenago).
</FORM>
</body>
</html>
