<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<HTML>
  <HEAD>
     <title>Arxius de la llista %(listname)s</title>
     <META NAME="robots" CONTENT="noindex,follow">
  </HEAD>
  <BODY BGCOLOR="#ffffff">
     <h1>Arxius de la llista %(listname)s</h1>
     <p>
      Encara no s'ha enviat cap missatge a aquesta llista, per la qual cosa els 
      arxius estan buits. Podeu obtenir <a href="%(listinfo)s">m&eacute;s informaci&oacute; 
      sobre aquesta llista</a>.
     </p>
  </BODY>
  </HTML>
