Denna sida inneh&aring;ller n&aring;gra av de e-postbrev till listan <em>%(listname)s</em> som h&aring;lls tillbaka f&ouml;r godk&auml;nnande. Nu visar den %(description)s
<p>V&auml;lj &ouml;nskat beslut f&ouml;r varje f&ouml;rfr&aring;gan. N&auml;r du &auml;r klar, klicka p&aring; <em>Utf&ouml;r</em>. N&auml;rmare instruktioner hittar du <a href="%(detailsurl)s">h&auml;r</a>.

<p>Du kan ocks&aring; <a href="%(summaryurl)s">visa en &ouml;versikt</a> &ouml;ver alla f&ouml;rfr&aring;gningar som v&auml;ntar p&aring; ett avg&ouml;rande.
