<br>
Teksti voi sis&auml;lt&auml;&auml; <a href="https://docs.python.org/2/library/stdtypes.html#string-formatting-operations"> muotoiltuja
merkkijonoja. Muotoilussa k&Atilde;&curren;ytett&Atilde;&curren;vi&Atilde;&curren; arvoja ovat:

<ul>
  <li>
    <b>real_name</b> - Listan "kaunis" nimi, normaalisti nimi, jolle listan asia on
    "omistettu"
  </li> 
  <li>
    <b>list_name</b> - Nimi, jolla lista tunnistetaan URL-osoitteena, jossa asia
    on merkitt&auml;v&auml;
  </li>
  <li>
    <b>host_name</b> - T&auml;ydellisesti m&auml;&auml;ritelty
    toimialuenimi palvelimelle, jossa lista sijaitsee
  </li>
  <li>
    <b>web_page_url</b> - Mailman p&auml;&auml;sivun
    url-osoite. T&auml;h&auml;n voidaan
    lis&auml;t&auml; esim. <em>listinfo/%(list_name)s</em>, jolla p&auml;&auml;see
    suoraan postituslistan listinfo-sivulle
  </li>
  <li>
    <b>description</b> - Lyhyt kuvaus postituslistan
    k&auml;ytt&ouml;tarkoituksesta
  </li>  
  <li>
    <b>info</b> - T&auml;ydellinen kuvaus postituslistasta
  </li>
</ul>

</body>
</html>
