Esta p&aacute;xina cont&eacute;n un sumario das solicitudes administrativas que
requiren da s&uacute;a aprobaci&oacute;n para a <a href="%(adminurl)s">rolda de
distribuci&oacute;n</em>
<em>%(listname)s</em></a>.

O primeiro que atopar&aacute; ser&aacute;n as solicitudes de alta e de baixa
na rolda,
sempre
que existir algunha, seguida por calquera env&iacute;o &aacute; rolda que precisar
da s&uacute;a
aprobaci&oacute;n.

<p>Seleccione a acci&oacute;n que se debe tomar para cada unha das solicitudes administrativas
  e
prema o bot&oacute;n <b>Enviar todos os datos</b> logo de rematar.
Pode ver aqu&iacute; unhas <a href="%(detailsurl)s">instruci&oacute;ns m&aacute;is detalladas</a>.

<p>Tam&eacute;n pode <a href="%(viewallurl)s">ver os detalles</a> de todos os
  env&iacute;os
retidos.
