This page contains a subset of the <em>%(listname)s</em> mailing list
postings that are being held for your approval.  It currently shows
%(description)s

<p>For each administrative request, please select the action to take,
clicking on the <b>Submit All Data</b> when finished.  More detailed
instructions are available <a href="%(detailsurl)s">here</a>.

<p>You can also <a href="%(summaryurl)s">view a summary</a> of all
pending requests.
