Esta p&aacute;gina cont&eacute;m um resumo do conjunto atual de requisi&ccedil;&otilde;es 
administrativas requerendo sua aprova&ccedil;&atilde;o na 
<a href="%(adminurl)s">lista de discuss&atilde;o <em>%(listname)s</em></a>.
Primeiro voc&ecirc; ver&aacute; a lista de inscri&ccedil;&otilde;es/desinscri&ccedil;&otilde;es pendentes, 
se tiver alguma, seguida de qualquer postagem que esteja aguardando sua
aprova&ccedil;&atilde;o.

<p>Para cada requisi&ccedil;&atilde;o administrativa, selecione a conex&atilde;o para 
ser feita clicando em <b>Enviar todos os dados</b> quando terminar.
<a href="%(detailsurl)s">Instru&ccedil;&otilde;es mais detalhadas</a> tamb&eacute;m est&atilde;o
dispon&iacute;veis. 

<p>Voc&ecirc; tamb&eacute;m pode <a href="%(viewallurl)s">ver os detalhes</a> de 
todas as postagens aguardando aprova&ccedil;&atilde;o. 
