このテキストには、リストの属性と置き換えられる
<a href="https://docs.python.org/2/library/stdtypes.html#string-formatting-operations">
Pythonフォーマット文字列</a>を挿入することができます。
(<a href="https://docs.python.org/ja/2.7/library/stdtypes.html#string-formatting-operations">
日本語版</a>)
ここで使える置換文字列は以下の通りです。

<ul>
    <li><b>real_name</b> - リストの「きれいな」名前;
    普通は大文字と小文字を混ぜて表記されたリストの名前になります。

    <li><b>list_name</b> - URL の中でリストを示す名前。
    大文字と小文字の違いは区別されます。(互換性のため、
    _internal_nameでも同じになります)

    <li><b>host_name</b> - Mailmanが稼働しているホストの
    完全ドメイン名(FQDN)。

    <li><b>web_page_url</b> - Mailman の基本 URL。
    たとえば、このURLに <em>listinfo/%(list_name)s</em> を付け加えると
    メーリングリストの案内ページになります。

    <li><b>description</b> - このメーリングリストの簡潔な説明。

    <li><b>info</b> - このメーリングリストの長い説明。

    <li><b>cgiext</b> - CGIスクリプトの拡張子。
</ul>
