Prehľad požiadaviek pre konferenciu <a href=\"%(adminurl)s\"><em>%(listname)s</em></a>.

T&aacute;to str&aacute;nka obsahuje prehľad v&scaron;tk&yacute;ch požiadaviek pre administr&aacute;tora
zoraden&yacute; tak, že požiadavky od jedn&eacute;ho &uacute;častn&iacute;ka s&uacute; zl&uacute;čen&eacute; dokopy
a m&ocirc;že o nich byť rozhodnut&eacute; naraz.

Žiadosti o prihl&aacute;senie a odhl&aacute;senie s&uacute; raden&eacute; ako prv&eacute; a za nimi
pr&iacute;padn&eacute; pr&iacute;spevky, ktor&eacute; čakaj&uacute; na schv&aacute;lenie moder&aacute;torom.

<p>Pri každej administrat&iacute;vnej požiadavke mus&iacute;te vybrať činnosť, ktor&aacute; sa
s ňou m&aacute; previesť a nakoniec vybran&eacute; činnosti uskutočn&iacute;te kliknut&iacute;m na 
<b>Potvrdiť v&scaron;etky zmeny</b>. Podrobnej&scaron;ie inform&aacute;ce o tom, ako
zaobch&aacute;dzať s administrat&iacute;vnym rozhran&iacute;m n&aacute;jdete 
<a href="%(detailsurl)s">pod t&yacute;mto odkazom</a>.

<p>Tiež si m&ocirc;žete prezrieť detailn&yacute; prehľad v&scaron;etk&yacute;ch
<a href="%(viewallurl)s">čakaj&uacute;cich požiadaviek</a> kde je každ&yacute;
pr&iacute;spovek zobrazovan&yacute; samostatne.
