<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<!-- $Revision: 5865 $ -->
<HTML>
  <HEAD>
    <TITLE>עמוד המידע של <MM-List-Name></TITLE>
  
  </HEAD>
  <BODY BGCOLOR="#ffffff" dir="rtl">

    <P>
      <TABLE BORDER="0" CELLSPACING="4" CELLPADDING="5">
	<TR>
	  <TD COLSPAN="2" WIDTH="100%" BGCOLOR="#99CCFF" ALIGN="CENTER">
	    <B><FONT COLOR="#000000" SIZE="+1"><MM-List-Name> --
	<MM-List-Description></FONT></B>
	  </TD>
	</TR>
	<tr>
	    <td colspan="2">
	      <p>&nbsp;
	    </td>
	  </tr>
	  <tr>
	    <TD COLSPAN="1" WIDTH="100%" BGCOLOR="#FFF0D0">
	      <B><FONT COLOR="#000000">אודות <MM-List-Name></FONT></B>
	    </TD>
            <TD COLSPAN="1" WIDTH="100%" BGCOLOR="#FFF0D0">
              <MM-lang-form-start><MM-displang-box> <MM-list-langs>
              <MM-form-end>
            </TD>
	  </TR>
	    <tr>
	      <td colspan="2">
		<P><MM-List-Info></P>
	  <p> כדי לצפות באוסף המסרים הקודמים לרשימה זו,
	      בקר בארכיון של <MM-Archive><MM-List-Name>
		 </MM-Archive>.
	      <MM-Restricted-List-Message>
	  </p>
	</TD>
      </TR>
      <TR>
	<TD COLSPAN="2" WIDTH="100%" BGCOLOR="#FFF0D0">
	  <B><FONT COLOR="#000000">השימוש ב- <MM-List-Name></FONT></B>
	</TD>
      </TR>
      <tr>
	<td colspan="2">
		כדי לשלוח מסר אל כל מנויי הרשימה, שלח דוא"ל אל
	  <A HREF="mailto:<MM-Posting-Addr>"><MM-Posting-Addr></A>.

	  <p>ניתן להרשם אל הרשימה, או לשנות את המנוי הנוכחי שלך,
	בקטע למטה.	</td>
      </tr>
      <TR>
	<TD COLSPAN="2" WIDTH="100%" BGCOLOR="#FFF0D0">
	  <B><FONT COLOR="#000000">הרשמה אל <MM-List-Name></FONT></B>
	</TD>
      </TR>
      <tr>
	<td colspan="2">
	  <P>
	    הרשם אל <MM-List-Name> על יד מילוי הטופס
	      הבא.
	  <MM-List-Subscription-Msg>
	  <ul>
    <MM-Subscribe-Form-Start>
	      <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2"
		WIDTH="70%">
		<TR>
		  <TD BGCOLOR="#dddddd" WIDTH="55%">כתובת הדוא"ל שלך:</TD>
		  <TD WIDTH="33%"><MM-Subscribe-Box>
	</TD>
	<TD WIDTH="12%">&nbsp;</TD></TR>
      <tr>
        <td bgcolor="#dddddd" width="55%">שמך (לא חובה):</td>
        <td width="33%"><mm-fullname-box></td>
	<TD WIDTH="12%">&nbsp;</TD></TR>
      <TR>
	<TD COLSPAN="3"><FONT SIZE=-1>אפשר להקליד סיסמת פרטיות למטה.
		זה מספק רק אבטחה קלה, אבל אמור למנוע מאחרים מאפשרות
		התעסקות עם המנוי שלך. <b>אין להשתמש בסיסמא חשובה
		לך</b> כיוון שהיא תישלח אליך בדוא"ל בטקסט נקי מדי פעם.
		<br><br>אם תבחר שלא להקליד סיסמא, המערכת תיצור לך סיסמא
		באופן אוטומטי, והיא תישלח אליך לאחר שתאשר את המנוי שלך.
		תמיד ניתן לבקש דואר חוזר עם הסיסמא שלך כאשר אתה עורך
		את ההגדרות האישיות שלך.
	    <MM-Reminder>
	    </font>
	</TD>
      </TR>  
      <TR>
	<TD BGCOLOR="#dddddd">בחר סיסמא:</TD>
	<TD><MM-New-Password-Box></TD>
	<TD>&nbsp;</TD></TR>
      <TR> 
	<TD BGCOLOR="#dddddd">הסיסמא שוב, לאישור:</TD>
	<TD><MM-Confirm-Password></TD>
	<TD>&nbsp; </TD></TR>
      <tr>
        <TD BGCOLOR="#dddddd">באיזה שפה אתה מעדיף לקבל את ההודעות שלך?</TD> 
        <TD> <MM-list-langs></TD>
        <TD>&nbsp; </TD></TR>
      <mm-digest-question-start>
      <tr>
	<td>האם תרצה לקבל את משלוחי הרשימה בתקצירים יומיים?
	  </td>
	<td><MM-Undigest-Radio-Button> לא
	    <MM-Digest-Radio-Button>  כן
	</TD>
      </tr>
      <mm-digest-question-end>
      <mm-recaptcha-ui>
      <mm-captcha-ui>
      <tr>
	<td colspan="3">
	  <center><MM-Subscribe-Button></center>
    </td>
    </tr>
    </TABLE>
    <MM-Form-End>
    </ul>
    <TR>
      <TD COLSPAN="2" WIDTH="100%" BGCOLOR="#FFF0D0">
	<a name="subscribers">
        <B><FONT COLOR="#000000"><MM-List-Name> מנויים</FONT></B></a>
      </TD>
    </TR>
    <tr>
      <TD COLSPAN="2" WIDTH="100%">
	<MM-Roster-Form-Start>
	<MM-Roster-Option>
	    <MM-Form-End>
	  <p>
	<MM-Options-Form-Start>
	<MM-Editing-Options>
		<MM-Form-End>
      </td>
    </tr>
  </table>
<MM-Mailman-Footer>
</BODY>
</HTML>
