Административные запросы представлены двум способами: на странице
<a href="%(summaryurl)s">сводный список</a> и на странице <em>подробная
информация</em>. В сводном списке представлены ожидающие обработки
запросы на подписку и удаление оной, а также сообщения, которые
были отложены для рассмотрения (все такие сообщения сгрупированы
по адресу отправителя). На странице с подробной информацией вы можете
увидеть как все заголовки так и небольшую часть сообщения.

<p>На каждой из страниц Вы можете выбрать одно из следующих действий:

<ul>
    <li><b>Отложить</b> &mdash; отложить решение на потом.  Используйте это
    действие, если вы хотите указанно сообжение переправить или сохранить (см.
    ниже).

    <li><b>Принять/Одобрить</b> &mdash; принять сообщение и переправить его
    в список рассылки. Для запросов об изменении подписки, одобрить их.

    <li><b>Отказать</b> &mdash; отвергнуть сообщение, отправив отправителю
    уведомление, что его сообщение принято не было.  Само сообщение после
    этого удаляется.

    <li><b>Удалить</b> &mdash; удалить указанное сообщение без каких-либо
    извещений отправителю.  Данное действие может быть полезным в случае
    спама.
</ul>

<p>Параметр <b>Сохранить</b> позволяет вам сохранить копию сообщения для
администратора сервера.  Это может оказаться полезным для сообщений, которые
вы хотели бы удалить, но перед этим внимательно его рассмотреть.

<p>Параметр <b>Переслать копию</b> позволяет вам переслать копию сообщения
кому-нибудь, кто не подписан на список рассылки.  Для того, чтобы изменить
отложенное сообщение для последующей переправки его в список рассылки, мы
рекомендуем переслать это сообщение себе (или владельцам списка рассылки),
при этом удалив отложенное сообщение из очереди. После того, как сообщение
появится в вашем почтовом ящике, вы можете необходимым образом изменить его,
а затем переслать прямо в список рассылки, при этом вам необходимо указать
дополнительный заголовок <tt>Approved:</tt>, значением которого необходимо
указать пароль списка рассылки. В этом случае также является хорошим тоном
указать, что вы изменили текст оригинального сообщения.

<p>Если отправитель сообщения является подписчиком этого списка рассылки,
вы можете убрать флажок модерирования, что означает что этот подписчик
может отправлять сообщения в список рассылки без дополнительного утверждения.
Это может оказаться полезным в случае, если все новые подписчики должны пройти
испытательный срок.

<p>Если отправитель сообщения не является подписчиком этого списка рассылки,
вы можете добавить его адрес в <em>список фильтрация</em>. Эти списки описаны
на страничке <a href="%(filterurl)s">sender filter privacy page</a>, и
их несколько типов: <b>auto-accept</b> (Accepts), <b>auto-hold</b> (Holds),
<b>auto-reject</b> (Rejects) или <b>auto-discard</b> (Discards).  Этот параметр
не будет доступен, если адрес отправителя уже присутствует в одном из списков
фильтрации.

<p>После того, как вы обработали все запросы, нажмите на кнопку
<em>Выполнить</em> в начале или в конце этой страницы.  Только после этого
все выбранные действия будут выполнены.

<p><a href="%(summaryurl)s">Веруться к сводному списку запросов</a>.
