<!-- $Revision: 6837 $ -->
<html>
<head>
    <link rel="SHORTCUT ICON" href="<mm-favicon>">
<title><MM-List-Name> メーリングリストでの <MM-Presentable-User> の設定</title>

</head>
<BODY BGCOLOR="#ffffff">
    <TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="5">
    <TR><TD WIDTH="100%" BGCOLOR="#99CCFF"><B>
	<FONT COLOR="#000000" SIZE=+1>
        <MM-List-Name> メーリングリストでの <MM-Presentable-User> の設定
	</FONT></B></TD></TR>
    </TABLE>
<p>
<table width="100%" border="0" cellspacing="5" cellpadding="5">
    <tr><td>
        <b><MM-List-Name> メーリングリストでの<MM-Presentable-User></b> さんの
        会員設定状況、パスワード、オプションの設定状況。
        </td><td><MM-Form-Start><mm-logout-button><MM-Form-End></td>
    </tr><tr>
        <td colspan="2">
        <MM-Case-Preserved-User>

        <MM-Disabled-Notice>

        <p><mm-results>
        </td>
    </tr>
</table>

<MM-Form-Start>
<p>
<table width="100%" border="0" cellspacing="0" cellpadding="5">
    <tr><td width="100%" bgcolor="#fff0d0" colspan="2">
        <font color="#000000">
        <b><MM-List-Name> 会員アドレスの変更</b>
        </font></td></tr>
    <tr><td colspan="2">メーリングリストに登録した配送アドレス
        を変更するには、下の欄に新しいアドレスを入力してください。
        なお新アドレスに送る確認のメールに対する確認があるまで
	処理は保留されます。

        <p>約<mm-pending-days>後に確認の期限が切れます。

        <p>また、オプションであなたの実名(例:<em>寺田寅彦</em>)を
	設定したり変更したりできます。

        <p><mm-host>に登録されているすべてのメーリングリストの
        会員アドレスを変更する場合、
        <em>全部変更</em>ボックスをチェックしてください。
        </td></tr>
    <tr><td><center>
        <table border="0" cellspacing="2" cellpadding="2" width="80%" cols="2">
        <tr><td bgcolor="#dddddd"><div align="right">新アドレス:</div></td>
            <td><mm-new-address-box></td>
            </tr>
        <tr><td bgcolor="#dddddd"><div align="right">
            確認用再入力:</div></td>
            <td><mm-confirm-address-box></td>
            </tr>
        </tr></table></center>
        </td>
        <td><center>
        <table border="0" cellspacing="2" cellpadding="2" width="80%" cols="2">
            <tr><td bgcolor="#dddddd"><div align="right">名前
            (省略可):</div></td>
            <td><mm-fullname-box></td>
            </tr>
        </table></center>
        </td>
        </tr>
    <tr><td colspan="2"><center><mm-change-address-button>
            <p><mm-global-change-of-address>全部変更
            </center></td>
    </tr>
</table>

<p>
<TABLE WIDTH="100%" BORDER="0" CELLSPACING="5" CELLPADDING="5">
    <TR><TD WIDTH="50%" BGCOLOR="#FFF0D0"><FONT COLOR="#000000">
        <B><MM-List-Name> を退会する</B></td>

        <TD WIDTH="50%" BGCOLOR="#FFF0D0"><FONT COLOR="#000000">
        <B>あなたの他の <MM-Host> での入会状況</B>
        </FONT></TD></TR>

    <tr><td>
        退会するには確認ボックスをチェックして、この
        ボタンをクリックしてください。<strong>警告:</strong>
        これは直ちに退会手続きを完了します。
        <p>
        <center><MM-Unsubscribe-Button></center></td>
    <td>
        <mm-host>で入会している全てのメーリングリスト
        のリストを見ることができます。他の会員オプションも
        変更するのであればこれを利用してください。

        <p>
        <center><MM-Other-Subscriptions-Submit></center>
	</TD></TR>
</table>

<TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="5">
    <TR><TD COLSPAN=2 WIDTH="100%" BGCOLOR="#FFF0D0"><FONT COLOR="#000000">
        <B><MM-List-Name> のパスワード</B>
	</FONT></TD></TR>
    <tr valign="TOP"><td WIDTH="50%">
        <a name=reminder>
        <center>
        <h3>パスワードを忘れたら?</h3>
        </center>
        このボタンをクリックすると、メールでパスワードを送信します。
        <p><MM-Umbrella-Notice>
        <center>
        <MM-Email-My-Pw>
        </center>
        </td>

<td WIDTH="50%">
        <a name=changepw>
        <center>
        <h3>パスワード変更</h3>
        <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2" WIDTH="70%" COLS=2>
            <TR><TD BGCOLOR="#dddddd"><div align="right">
                新パスワード:</div></TD>
	        <TD><MM-New-Pass-Box></TD>
                </TR>
            <TR>
	        <TD BGCOLOR="#dddddd"><div align="right">
                確認用再入力:</div></TD>
	        <TD><MM-Confirm-Pass-Box></TD>
            </TR>
        </table>
        <MM-Change-Pass-Button>
        <p><center><mm-global-pw-changes-button>全部変更
        </center>
</TABLE>

<p>
<TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="5">
    <TR><TD WIDTH="100%" BGCOLOR="#FFF0D0"><FONT COLOR="#000000">
        <B><MM-List-Name> の会員オプション</B>
	</FONT></TD></TR>
</table>

<p>
<i><strong>現在の設定がチェックされています。</strong></i>
<p><em>全部設定</em>のチェックボックスをチェックすると、
入会している<mm-host>の全メーリングリストでの設定を変更することができます。
上の<em>他のメーリングリストへの入会状況</em>で、
自分が入会しているメーリングリストを調べることができます。
<p>
<TABLE BORDER="0" CELLSPACING="2" CELLPADDING="3" WIDTH="100%">
    <tr><TD BGCOLOR="#cccccc">
        <a name="disable">
        <strong> メール配送 </strong> <br>
        メーリングリストに投稿されたメールの配送を開始させるときは、
	このオプションを<em>有効</em>にします。<em>停止</em>を選ぶと、
        一時的にメールの配送を止めることができます
        (例えば短期間の休暇中など)。配送を停止したときは、
        休暇が終わったら有効に設定し直すことをお忘れなく。
        </td><td bgcolor="#cccccc">
        <mm-delivery-enable-button> 有効<br>
        <mm-delivery-disable-button> 停止<p>
        <mm-global-deliver-button><i>全部設定</i>
        </td></tr>

<!--Start-Digests-Delete-->
    <tr><TD BGCOLOR="#cccccc">
        <strong> まとめ読みモードに設定</strong> <br>
        有効 を選ぶと、投稿のたびにメールを送らず、すべてのメールを
	毎日1通にまとめてメールが届きます。まとめ読みモードの設定を
        有効 から 無効 に変更すると、最後に1通のまとめメールが送られます。
        </td><td bgcolor="#cccccc">
        <MM-Undigest-Radio-Button> 無効<br>
        <MM-Digest-Radio-Button> 有効
        </td></tr>

    <tr><TD BGCOLOR="#cccccc">
        <strong> まとめ読みメールを受け取る形式。
	平文またはMIMEの添付ファイル形式。</strong><p>
        メールソフトによっては MIME形式でまとめ読みメールを読めない
        ものもあります。一般的にはMIME形式の方が便利ですが、
        MIME形式のメールが読めない場合は平文を選んでください。
        </td><td bgcolor="#cccccc">
        <MM-Mime-Digests-Button> MIME <br>
        <MM-Plain-Digests-Button> 平文 <p>
        <mm-global-mime-button><i>全部設定</i>
        </td></tr>
<!--End-Digests-Delete-->

    <tr><TD BGCOLOR="#cccccc">
        <strong> 自分が投稿したメールを受け取りますか? </strong><p>
        通常は、自分がリストに投稿したメールのコピーを送信します。
        自分が投稿したメールのコピーを受け取りたくなければ、
        このオプションを<em>いいえ</em>に設定してください。
        </td><td bgcolor="#cccccc">
        <mm-dont-receive-own-mail-button> いいえ <br>
        <mm-receive-own-mail-button> はい
        </td></tr>

    <tr><TD BGCOLOR="#cccccc">
        <strong> リストへの投稿に対する確認通知が必要ですか?</strong><p>
        </td><td bgcolor="#cccccc">
        <mm-dont-ack-posts-button> いいえ<br>
        <mm-ack-posts-button> はい
        </td></tr>

    <tr><td bgcolor="#cccccc">
        <strong>このリストからのパスワード通知を受け取りますか?</strong><p>
        はいを選ぶと、このホストで運用される各メーリングリストから、毎月
        パスワード備忘通知メールを受け取ることになります。
        <em>いいえ</em>を選ぶと、このメーリングリストからの備忘通知
        の送信を止めることができます。全部設定をチェックして
	<em>いいえ</em>を設定すると、備忘通知メールは完全に送られなくなります。
        </td><td bgcolor="#cccccc">
        <mm-dont-get-password-reminder-button>いいえ<br>
        <mm-get-password-reminder-button>はい<p>
        <mm-global-remind-button><i>全部設定</i>
        </td></tr>

    <tr><TD BGCOLOR="#cccccc">
        <strong> 会員リストでアドレスを非表示にしますか? </strong><br>
        リストの会員名簿には、あなたのメールアドレスが表示されます
        (ただし迷惑メールのアドレス収集を防ぐために表示をあいまいにしています)。
        会員名簿に自分のメールアドレスを表示させたくない場合は、
        <em>隠してください</em>を選びます。
        </td><td bgcolor="#cccccc">
        <MM-Public-Subscription-Button> 表示します <br>
        <MM-Hide-Subscription-Button> 隠してください
        </td></tr>

    <tr><TD BGCOLOR="#cccccc">
        <strong> どの言語を使いますか?</strong><p>
        </td><td bgcolor="#cccccc">
        <MM-list-langs>
        </td></tr>

    <tr><td bgcolor="#cccccc">
        <strong>受信したい話題の分類は?</strong><p>
	メーリングリストに送り出されるメールに
	フィルタをかけることができます。
	受け取りたい話題を選んでください。
	選択した話題に該当しないメールは送られなくなります。

	<p>どの話題にも該当しないメールの配送規則は、下の項目で設定します。
	何も話題を選択しなければ、すべてのメールを配送します。
        </td><td bgcolor="#cccccc">
        <mm-topics>
        </td></tr>

    <tr><td bgcolor="#cccccc">
        <strong>どの話題フィルタにも合致しないメールを受け取りますか?</strong><p>
	前の設定で話題を選択した場合に、
	どの話題にも該当しないメールに対するデフォルトの配送規則を決めます。
	<em>いいえ</em>を選ぶと、どの話題にも該当しないメールは配送しません。
	<em>はい</em>を選ぶと、どの話題にも該当しないメールを配送します。

	<p>前の設定で何も話題を選択しなかった場合は、
	このオプションでの設定にかかわらず、
	すべてのメールを配送します。
        </td><td bgcolor="#cccccc">
        <mm-suppress-nonmatching-topics>いいえ<br>
        <mm-receive-nonmatching-topics>はい
        </td></tr>

    <tr><td bgcolor="#cccccc">
        <strong>重複したメールを受け取らないようにしますか?</strong><p>

            自分自身のアドレスが<tt>To:</tt>または<tt>Cc:</tt>ヘッダに
            含まれているときは、メーリングリストからのメールを受け取らない
            ようにすることができます。
            <em>はい</em>を選ぶと、重複するメールを受け取りません。
            <em>いいえ</em>を選ぶと、重複するメールも受け取ります。

            <p>リストが個人別配送モードになっている場合、
            「いいえ」を選ぶと <tt>X-Mailman-Copy: yes</tt> という
            ヘッダが付くようになります。

        </td><td bgcolor="#cccccc">
        <mm-receive-duplicates-button>いいえ<br>
        <mm-dont-receive-duplicates-button>はい<br>
        <mm-global-nodupes-button><i>全部設定</i>
        </td></tr>

    <tr><TD colspan="2">
        <center><MM-options-Submit-button></center>
        </td></tr>

</table>
</center>

<p>
<MM-Form-End>

<MM-Mailman-Footer>
</body>
</html>
