עמוד זה מכיל סיכום של קבוצת כל הבקשות המנהלתיות שדורשות
את אישורך עבור <a href="%(adminurl)s"><em>רשימת הדיוור</em> %(listname)s</a>.
ראשית, תמצא את בקשות ההצטרפות והעזיבה הממתינות, אם יש,
ואחריכן כל המסרים הממתינים לאישורך.

<p>עבור כל בקשה מנהלתית, נא לבחור את הפעולה שיש לנקוט,
ולחץ אל הלחצן <b>הגש את כל המידע</b> כשתסיים.
ישנן גם <a href="%(detailsurl)s">הוראות מפורטות יותר</a> זמינות.

בנוסף, אפשר גם <a href="%(viewallurl)s">לצפות בפרטים</a> של כל המסרים הממתינים.
