<!-- $Revision: 5063 $ -->
T&auml;ll&auml; sivulla on lista toimiasi vaativista 
yll&auml;pitopyynn&ouml;ist&auml;

<a href="%(adminurl)s"><em>%(listname)s</em> mailing list</a>.

Ensin on lista liittymis ja eroamispyynn&ouml;ist&auml;, jos niit&auml; on.

Seuraavaksi on lista viesteist&auml;, jotka vaativat hyv&auml;ksynt&auml;si.

<p>Valitse toiminta jokaiselle yll&auml;pitotoimelle ja klikkaa
<b>Submit All Data</b> button when finished.

<a href="%(detailsurl)s">Lis&auml;ohjeita</a> on my&ouml;s saatavilla.

<p>Voit my&ouml;s <a href="%(viewallurl)s"> tutustua tarkemmin</a> 
kaikkiin toimenpiteit&auml; vaativiin viesteihin.
