<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<HTML>
  <HEAD>
     <title>%(listname)s arch&iacute;vum</title>
     <META NAME="robots" CONTENT="noindex,follow">
  </HEAD>
  <BODY BGCOLOR="#ffffff">
     <h1>%(listname)s arch&iacute;vum</h1>
     <p>
      A list&aacute;ra m&eacute;g nem k&uuml;ldtek levelet, ez&eacute;rt jelenleg &uuml;res az arch&iacute;vum.
      B&#337;vebb <a href="%(listinfo)s">inform&aacute;ci&oacute; a list&aacute;r&oacute;l</a>. 
     </p>
  </BODY>
  </HTML>
