<html>
<head>
    <title>%(realname)s πιστοποίηση στον προστατευόμενο χώρο αποθήκευσης ιστορικού μηνυμάτων</title>
    <script>function sf(){document.f.username.focus();}</script>
</head>
body bgcolor="#ffffff" onLoad="sf()">
<FORM METHOD=POST ACTION="%(action)s/" name="f">
%(message)s
  <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
    <TR>
      <TD COLSPAN="2" WIDTH="100%%" BGCOLOR="#99CCFF" ALIGN="CENTER">
	<B><FONT COLOR="#000000" SIZE="+1">%(realname)s πιστοποίηση στον προστατευόμενο χώρο 
	    αποθήκευσης ιστορικού μηνυμάτων</FONT></B>
      </TD>
    </TR>
    <tr>
        <TD><div ALIGN="Right">Διεύθυνση ηλεκτρονικού ταχυδρομείου:</div></TD>
        <TD><INPUT TYPE="text" NAME="username" SIZE="30"></TD>
    </tr>
    <tr>
      <TD><div ALIGN="Right">Κωδικός πρόσβασης:</div></TD>
      <TD><INPUT TYPE="password" NAME="password" SIZE="30"></TD>
    </tr>
    <tr>
      <td colspan=2 align="middle"><INPUT type="SUBMIT"
                                          name="submit"
					  value="Είσοδος">
      </td>
    </tr>
  </TABLE>
      <p><strong><em>Σημαντικό:</em></strong> Από αυτό το σημείο και έπειτα, 
      θα πρέπει να έχετε ενεργοποιημένα τα cookies στον Browser που
      χρησιμοποιείτε αλλιώς οι αλλαγές του διαχειριστή δεν θα ισχύσουν.

      <p>Τα Session cookies χρησιμοποιούνται στο διαχειριστικό περιβάλλον 
      του Mailman ώστε να μη χρειάζεται να κάνετε πιστοποίηση των στοιχείων 
      σας κάθε φορά που εκτελείτε μια λειτουργία διαχείρισης. Αυτό το 
      cookie θα λήξει αυτόματα μόλις κλείσετε τον browser, ή μπορείτε και 
      εσείς να κάνετε το cookie να λήξει πατώντας το link της
      <em>Αποσύνδεσης</em>.
      <p>
    <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
    <TR>
      <TD COLSPAN="2" WIDTH="100%%" BGCOLOR="#99CCFF" ALIGN="CENTER">
	<B><FONT COLOR="#000000" SIZE="+1">Password Reminder</FONT></B>
      </TD>
    </TR>
    <tr>
      <td>If you don't remember your password, enter your email address
          above and click the <em>Remind</em> button and your
          password will be emailed to you.</td>
    </tr>
    <tr>
      <td><center><INPUT name="login-remind" type="SUBMIT" value="Remind" ></center></td>
    </tr>
  </TABLE>
</FORM>
</body>
</html>
