Esta p&aacute;gina cont&eacute;m um sum&aacute;rio dos pedidos administrativos da lista
<a href="%(adminurl)s">lista <em>%(listname)s</em></a>  que 
requerem a sua autoriza&ccedil;&atilde;o. Em primeiro lugar encontra a lista de pedidos
de inscri&ccedil;&atilde;o ou de anula&ccedil;&atilde;o pendentes, se exitirem, seguida das eventuais
mensagens suspensas para sua aprova&ccedil;&atilde;o.

<p>Seleccione a ac&ccedil;&atilde;o a tomar em rela&ccedil;&atilde;o a cada pedido administrativo
e carregue em <b>Submeter toda a informa&ccedil;&atilde;o</b> quando tiver terminado.
<a href="%(detailsurl)s">Instru&ccedil;&otilde;es mais detalhadas</a> est&atilde;o tamb&eacute;m
dispon&iacute;veis aqui</a>.

<p>Se preferir pode <a href="%(viewallurl)s">ver os detalhes</a> de todas 
as mensagens suspensas.
