Этот текст может включать <a
href="https://docs.python.org/2/library/stdtypes.html#string-formatting-operations">строки
подстановки Python (текст по-английски)</a>, которые заменяются следующими атрибутами
списка рассылки:

<ul>
    <li><b>real_name</b> &mdash; "красивое" имя списка рассылки;
    обычно это имя списка рассылки с заглавной буквы.

    <li><b>list_name</b> &mdash; имя, которое используется в адресах
    страниц, регистр символов имеет значение.

    <li><b>host_name</b> &mdash; полное имя домена (FQDN) списка рассылки.

    <li><b>web_page_url</b> &mdash; базовый адрес для Mailman. Именно к этому
    адресу нужно добавлять, например, <em>listinfo/%(list_name)s</em>
    чтобы получить адрес информационной страницы списка рассылки.

    <li><b>description</b> &mdash; краткое описание списка рассылки.

    <li><b>info</b> &mdash; полное описание списка рассылки.

    <li><b>cgiext</b> &mdash; расширение файлов CGI-сценариев.
</ul>
