Testu honek 
<a href="https://docs.python.org/2/library/stdtypes.html#string-formatting-operations">Python
kateak</a> izan ditzake; zerrendako atributuen bidez ordezkatuko dira.  
Onartzen diren ordezkapenak hauexek dira:

<ul>
    <li><b><code>real_name</code></b> - Zerrendaren izen `polita'; gehienetan
    zerrendaren izen berbera, baina lehenengo letra larria duena.

    <li><b><code>list_name</code></b> - URL-etan zerrenda identifikatzeko
    erabiltzen den izena; letra larriek garrantzia dute.  (Konpatibilitatea dela 
	eta, <code>_internal_izena</code> kodearen baliokidea da).

    <li><b><code>host_name</code></b> - Bere baitan zerrenda duen zerbitzariaren
    izen kanonikoa.

    <li><b><code>web_page_url</code></b> - Mailmanen oinarrizko URLa.  
    Adibidez, zerrendaren informazio orria adierazteko, atzean
    <em><code>listinfo/%(list_name)s</code></em> gehitzea
	bakarrik behar da.

    <li><b><code>description</code></b> - Posta zerrendaren laburpen xumea.

    <li><b><code>info</code></b> - Posta zerrendaren azalpen luze eta 
	sakonagoa.

    <li><b><code>cgiext</code></b> - CGI script-ei gehitzen zaien luzapena.
</ul>
