<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<!-- $Revision: 6029 $ -->
<HTML>
  <HEAD>
   <TITLE><MM-List-Name> Inform&aacute;ci&oacute;s lapja</TITLE>
  </HEAD>
  <BODY BGCOLOR="#ffffff">
    <P>
      <TABLE BORDER="0" CELLSPACING="4" CELLPADDING="5">
	<TR>
	  <TD COLSPAN="2" WIDTH="100%" BGCOLOR="#99CCFF" ALIGN="CENTER">
	    <B><FONT COLOR="#000000" SIZE="+1"><MM-List-Name> --
	<MM-List-Description></FONT></B>
	  </TD>
	</TR>
	<tr>
	    <td colspan="2">
	      <p>&nbsp;
	    </td>
	  </tr>
	  <tr>
	    <TD COLSPAN="1" WIDTH="100%" BGCOLOR="#FFF0D0">
	      <B><FONT COLOR="#000000"><MM-List-Name> list&aacute;r&oacute;l</FONT></B>
	    </TD>
            <TD COLSPAN="1" WIDTH="100%" BGCOLOR="#FFF0D0">
	      <MM-lang-form-start><MM-displang-box> <MM-list-langs>
	      <MM-form-end>
	    </TD>
	  </TR>
	    <tr>
	      <td colspan="2">
		<P><MM-List-Info></P>
	  <p>Ha a kor&aacute;bbi leveleket, hozz&aacute;sz&oacute;l&aacute;sokat szeretn&eacute;d l&aacute;tni, l&aacute;togasd meg
	     a(z) <MM-Archive><MM-List-Name> arch&iacute;vumot </MM-Archive>.
              <MM-Restricted-List-Message>
	  </p>
	</TD>
      </TR>
      <TR>
	<TD COLSPAN="2" WIDTH="100%" BGCOLOR="#FFF0D0">
	  <B><FONT COLOR="#000000"><MM-List-Name> lista haszn&aacute;lata</FONT></B>
	</TD>
      </TR>
      <tr>
	<td colspan="2">
	  Ha a list&aacute;ra szeretn&eacute;l &iacute;rni, akkor erre a c&iacute;mre k&uuml;ldd hozz&aacute;sz&oacute;l&aacute;sodat:
	  <A HREF="mailto:<MM-Posting-Addr>"><MM-Posting-Addr></A>.

	  <p>Itt lejjebb feliratkozhatsz a list&aacute;ra, vagy m&oacute;dos&iacute;thatod
              a listatags&aacute;gi param&eacute;tereidet.
	</td>
      </tr>
      <TR>
	<TD COLSPAN="2" WIDTH="100%" BGCOLOR="#FFF0D0">
	  <B><FONT COLOR="#000000">Feliratkoz&aacute;s a(z) <MM-List-Name> list&aacute;ra</FONT></B>
	</TD>
      </TR>
      <tr>
	<td colspan="2">
	  <P>
 	  T&ouml;ltsd ki az al&aacute;bbi &#369;rlapot a(z) <MM-List-Name> list&aacute;ra val&oacute; feliratkoz&aacute;shoz.	    
	  <MM-List-Subscription-Msg>
	  <P>Feliratkoz&aacute;s el&#337;tt k&eacute;rlek olvasd el a listaszerver
            <A HREF="/illik.html">illemtan&aacute;t</A>!

	  <ul>
    <MM-Subscribe-Form-Start>
	      <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2"
		WIDTH="70%">
		<TR>
		  <TD BGCOLOR="#dddddd" WIDTH="55%">E-mail c&iacute;med:</TD>
		  <TD WIDTH="33%"><MM-Subscribe-Box>
	</TD>
	<TD WIDTH="12%">&nbsp;</TD></TR>
      <TR>
	<td bgcolor="#dddddd" width="55%">Neved (opcion&aacute;lis):</td>
        <td width="33%"><mm-fullname-box></td>
	<TD WIDTH="12%">&nbsp;</TD></TR>
      <TR>
	      <TD COLSPAN="3"><FONT SIZE=-1>Meg kell adnod egy jelsz&oacute;t.
  A jelsz&oacute; csak enyhe biztons&aacute;got ny&uacute;jt, de megel&#337;zheted vele,
  hogy m&aacute;sok tudtod n&eacute;lk&uuml;l m&oacute;dos&iacute;ts&aacute;k listatags&aacute;gi be&aacute;ll&iacute;t&aacute;saidat!
  <b>Ne haszn&aacute;lj olyan jelszavakat amiket m&aacute;shol haszn&aacute;lsz</b>,
  mivel havonta egyszer eml&eacute;keztet&#337;&uuml;l sima sz&ouml;veges form&aacute;ban elk&uuml;ld&eacute;sre fog ker&uuml;lni. 
  
  <br><br>Ha nem adsz meg jelsz&oacute;t, akkor a Mailman automatikusan l&eacute;trehoz egyet, &eacute;s
  feliratkoz&aacute;sod meger&#337;s&iacute;t&eacute;se ut&aacute;n elk&uuml;ldi neked. Szem&eacute;lyes be&aacute;ll&iacute;t&aacute;said szerkeszt&eacute;s&eacute;n&eacute;l
  term&eacute;szetesen b&aacute;rmikor e-mailben kik&eacute;rheted a jelszavadat.
	    <MM-Reminder>
	    </font>
	</TD>
      </TR>  
      <TR>
	<TD BGCOLOR="#dddddd">A jelsz&oacute;:</TD>
	<TD><MM-New-Password-Box></TD>
	<TD>&nbsp;</TD></TR>
      <TR> 
	<TD BGCOLOR="#dddddd">A jelsz&oacute; m&eacute;g egyszer:</TD>
	<TD><MM-Confirm-Password></TD>
	<TD>&nbsp; </TD></TR>
    <tr>
      <TD BGCOLOR="#dddddd">Milyen nyelven szeretn&eacute;d a list&aacute;t haszn&aacute;lni?</TD>
      <TD><MM-list-langs></TD>
      <TD>&nbsp; </TD></TR>
	<mm-digest-question-start>
    <tr>
	<td>Szeretn&eacute;d a list&aacute;t digest form&aacute;ban kapni, naponta 1-2 lev&eacute;lben?</td>
	<td><MM-Undigest-Radio-Button> Nem
	    <MM-Digest-Radio-Button>  Igen
	</TD>
      </tr>
      <tr>
    <mm-digest-question-end>
    <mm-recaptcha-ui>
    <mm-captcha-ui>
	<td colspan="3">
	  <center><MM-Subscribe-Button></center>
    </td>
    </tr>
    </TABLE>
    <MM-Form-End>
    </ul>
    <TR>
      <TD COLSPAN="2" WIDTH="100%" BGCOLOR="#FFF0D0">
	<a name="subscribers">
        <B><FONT COLOR="#000000"><MM-List-Name> lista tagjai</FONT></B></a>
      </TD>
    </TR>
    <tr>
      <TD COLSPAN="2" WIDTH="100%">
	<MM-Roster-Form-Start>
	<MM-Roster-Option>
	    <MM-Form-End>
	  <p>
	<MM-Options-Form-Start>
	<MM-Editing-Options>
		<MM-Form-End>
      </td>
    </tr>
  </table>
<MM-Mailman-Footer>
</BODY>
</HTML>
