<html>
<head>
    <link rel="SHORTCUT ICON" href="<mm-favicon>">
    <title>Agordoj de la abono de <MM-Presentable-User> je la listo <MM-List-Name>
    </title>
</head>
<BODY BGCOLOR="#ffffff">
    <TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="5">
    <TR><TD WIDTH="100%" BGCOLOR="#99CCFF"><B>
        <FONT COLOR="#000000" SIZE=+1>
	Agordoj de la abono de <MM-Presentable-User> je la listo
	<MM-List-Name>
        </FONT></B></TD></TR>
    </TABLE>
<p>
<table width="100%" border="0" cellspacing="5" cellpadding="5">
    <tr><td>
        Abonstato, pasvorto kaj agordoj de <b><MM-Presentable-User></b> je la listo <MM-List-Name>.
        </td><td><MM-Form-Start><mm-logout-button><MM-Form-End></td>
    </tr><tr>
        <td colspan="2">
        <MM-Case-Preserved-User>

        <MM-Disabled-Notice>

        <p><mm-results>
        </td>
    </tr>
</table>

<MM-Form-Start>
<p>
<TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="5">
    <TR><TD WIDTH="100%" BGCOLOR="#FFF0D0" colspan="2">
        <FONT COLOR="#000000">
        <B>Kiel ŝanĝi la informon de via abono je la listo <MM-List-Name></B>
        </FONT></TD></TR>
    <tr><td colspan="2">Vi povas ŝanĝi la retpoŝtadreson per kiu vi abonas la dissendoliston enskribante la novan adreson en la ĉi-suban kampon. Post tio, konfirmilo estos sendata al la nova adreso, kaj vi devos konfirmi la ŝanĝon antaŭ ol ĝi efektiviĝos.

        <p>La konfirmiloj kadukiĝas post <mm-pending-days>.

        <p>Vi ankaŭ povas aldoni aŭ ŝanĝi vian nedevigan realan nomon (Ekzemple <em>Ludoviko Ajnulo</em>).

        <p>Se vi volas efektivigi ĉi tiujn ŝanĝojn je ĉiuj viaj listoj abonataj en <mm-host>, marku la konfirmujon <em>Ŝanĝu ĉie</em>. </p>

        </td></tr>
    <tr><td><center>
        <table border="0" cellspacing="2" cellpadding="2" width="80%" cols="2">
        <tr><td bgcolor="#dddddd"><div align="right">Nova adreso:</div>
            <td><mm-new-address-box></td>
            </tr>
        <tr><td bgcolor="#dddddd"><div align="right">Reenskribu por konfirmi ĝin:</div></td> 
            <td><mm-confirm-address-box></td>
            </tr>
        </tr></table></center>
      </td>
      <td><center>
        <table border="0" cellspacing="2" cellpadding="2" width="80%" cols="2">
            <tr><td bgcolor="#dddddd"><div align="right">Via nomo
            (nedevige):</div></td>
            <td><mm-fullname-box></td>
            </tr>
        </table></center>
        </td>
        </tr>
    <tr><td colspan="2"><center><mm-change-address-button>
        <p><mm-global-change-of-address>Ŝanĝu ĉie</center></td>
    </tr>
</table>

<p>
<TABLE WIDTH="100%" BORDER="0" CELLSPACING="5" CELLPADDING="5">
    <TR><TD WIDTH="50%" BGCOLOR="#FFF0D0"><FONT COLOR="#000000">
        <B>Kiel malaboni la liston <MM-List-Name></B></td>

        <TD WIDTH="50%" BGCOLOR="#FFF0D0"><FONT COLOR="#000000">
        <B>Viaj aliaj abonoj en <MM-Host>.</B>
        </FONT></TD></TR>

    <tr><td>
        Marku la konfirmujon kaj premu la butonon por malaboni ĉi tiun dissendoliston. <strong>Averto:</strong>
        ĉi tiu ŝanĝo efektiviĝos tuj!
        <p>
        <center><MM-Unsubscribe-Button></center></td>
    <td>
        Vi povas vidi liston de la aliaj dissendolistoj kiujn vi abonas en <MM-Host>. Uzu tion se vi volas efektivigi la samajn reagordojn ankaŭ je tiuj abonoj.

        <p>
        <center><MM-Other-Subscriptions-Submit></center>
        </TD></TR>
</table>

<TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="5">
    <TR><TD COLSPAN=2 WIDTH="100%" BGCOLOR="#FFF0D0"><FONT COLOR="#000000">
        <B>Via pasvorto en <MM-List-Name></B>
        </FONT></TD></TR>

    <tr valign="TOP"><td WIDTH="50%">
        <a name=reminder>
        <center>
        <h3>Ĉu vi forgesis la pasvorton?</h3>
        </center>
        Premu ĉi tiun butonon por rericevi vian pasvorton per retpoŝto.
        <p><MM-Umbrella-Notice>
        <center>
        <MM-Email-My-Pw>
        </center>
        </td>

    <td WIDTH="50%">
        <a name=changepw>
        <center>
        <h3>Ŝanĝo de la pasvorto</h3>
        <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2" WIDTH="70%" COLS=2>
            <TR><TD BGCOLOR="#dddddd"><div align="right">Nova pasvorto:</div></TD>
                <TD><MM-New-Pass-Box></TD>
                </TR>
            <TR>
                <TD BGCOLOR="#dddddd"><div align="right">Konfirmu ĝin:</div></TD>
                <TD><MM-Confirm-Pass-Box></TD>
            </TR>
        </table>

        <MM-Change-Pass-Button>
        <p><center><mm-global-pw-changes-button>Ŝanĝu ĉie
        </center>
</TABLE>

<p>
<TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="5">
    <TR><TD WIDTH="100%" BGCOLOR="#FFF0D0"><FONT COLOR="#000000">
        <B>Viaj abonagordoj en <MM-List-Name></B>
        </FONT></TD></TR>
</table>

<p> 
<i><strong>La nunaj valoroj estas markitaj.</strong></i>

<p>Rimarku ke kelkaj agordoj havas konfirmujon nomatan <em>Ŝanĝu ĉie</em>. Se vi markos ĉi tiun konfirmujon la ŝanĝo efektiviĝos en ĉiuj dissendolistoj kiujn vi abonas en <mm-host>. Premu sur <em>Listigu miajn aliajn abonojn</em>
por vidi kiujn aliajn dissendolistojn vi abonas. </p>
<p>
<TABLE BORDER="0" CELLSPACING="3" CELLPADDING="4" WIDTH="100%">
    <tr><TD BGCOLOR="#cccccc">
        <a name="disable">
        <strong>Poŝtoliverado</strong></a><p>
        Elektu <em>Aktiva</em>'n por ricevi la poŝton sendatan al tiu ĉi listo. Elektu <em>Malaktiva</em>'n
        se vi volas plu aboni la liston sed ne volas ricevi poŝton dum iu tempo (ekzemple dum ferioj), aŭ volas nur sendi poŝton kaj legi la arĥivojn de la listo. Se vi malŝaltos poŝtoliveradon, memoru ke ĝi ne reaktiviĝos aŭtomate.
      </td><td bgcolor="#cccccc">
        <mm-delivery-enable-button>Aktiva<br>
        <mm-delivery-disable-button>Malaktiva<p>
        <mm-global-deliver-button><i>Ŝanĝu ĉie</i></p>
        </td></tr>

<!--Start-Digests-Delete-->
    <tr><TD BGCOLOR="#cccccc">
        <strong>Ŝaltu resum-modon</strong><p> 
        Se vi ŝaltos la resum-modon, vi ricevos ĉiujn mesaĝojn kompilitaj en unu resumon (kutime po unu resumo tage, sed eble pli ofte en tre aktivaj listoj), anstataŭ ricevi unuopajn mesaĝojn po unu tuj kiam ili estas sendataj. Se vi malŝaltos la resum-modon, eblas ke vi ankoraŭ ricevos unu lastan resumon antaŭ ol komenci ricevi unuopajn mesaĝojn.
        </td><td bgcolor="#cccccc">
        <MM-Undigest-Radio-Button>Malaktiva<br>
        <MM-Digest-Radio-Button>Aktiva</td>
        </td></tr>
        
    <tr><TD BGCOLOR="#cccccc">
        <strong>Ĉu vi preferas resumojn en aranĝo MIME aŭ en simpla teksto?</strong><p>
        Povas okazi ke via retpoŝtilo ne bone akceptos resumojn MIME. Tiuj estas preferindaj, sed se ili ne estos facile legeblaj, elektu simpla-tekstajn resumojn.
        </td><td bgcolor="#cccccc">
        <MM-Mime-Digests-Button>MIME<br>
        <MM-Plain-Digests-Button>Simpla teksto<p>
        <mm-global-mime-button><i>Ŝanĝu ĉie</i>
        </td></tr>
<!--End-Digests-Delete-->
        
    <tr><TD BGCOLOR="#cccccc">
        <strong>Ĉu vi volas ricevi poŝton senditan de vi al la listo?</strong><p>
        Kutime, vi ricevos kopion de ĉiu mesaĝo kiun vi mem sendos al la listo. Se vi ne volas ricevi tiun kopion, elektu <em>Ne</em>'n.
        </td><td bgcolor="#cccccc">
        <mm-dont-receive-own-mail-button>Ne<br>
        <mm-receive-own-mail-button>Jes
        </td></tr>

    <tr><TD BGCOLOR="#cccccc">
        <strong>Ĉu vi volas ricevi konfirmilon post kiam vi sendos poŝton al la listo?</strong><p>
        </td><td bgcolor="#cccccc">
        <mm-dont-ack-posts-button>Ne<br>
        <mm-ack-posts-button>Jes
        </td></tr>

    <tr><td bgcolor="#cccccc">
        <strong>Ĉu vi volas ricevi memorigilon de via pasvorto?</strong><p>
        Unu fojon monate vi ricevos memorigilon kun la pasvortoj de ĉiu listo kiun vi abonas en <mm-host>. Vi povas malŝalti tiun memorigilon por ĉiu listo elektante <em>Ne</em>'n. </p>
        </td><td bgcolor="#cccccc">
        <mm-dont-get-password-reminder-button>Ne<br>
        <mm-get-password-reminder-button>Jes<p>
        <mm-global-remind-button><i>Ŝanĝu ĉie</i>
        </td></tr>

    <tr><TD BGCOLOR="#cccccc">
        <strong>Ĉu vi volas kaŝi vin en la listanaro?</strong><p>
        Kiam iu vidas la liston de abonantoj de tiu ĉi dissendolisto, via retpoŝtadreso estos videbla (en maniero iom maskita por kaŝi ĝin de trudpoŝtistoj). Se vi ne deziras ke via adreso aperu sur la listanaro, elektu <em>Jes
      </em>'on ĉi tie.
        </td><td bgcolor="#cccccc">
        <MM-Public-Subscription-Button>Ne<br>
        <MM-Hide-Subscription-Button>Jes
        </td></tr>

    <tr><TD BGCOLOR="#cccccc">
        <strong>Kiun lingvon vi preferas?</strong><p>
        </td><td bgcolor="#cccccc">
        <MM-list-langs>
        </td></tr>

    <tr><td bgcolor="#cccccc">
        <strong>Kiujn temojn vi volas aboni?</strong><p>
                Se vi elektos unu aŭ plurajn interestemojn, la poŝto de la listo estos filtrata kaj vi ricevos nur parton. Se mesaĝo konformas al iu temo elektita de vi, vi ĝin ricevos; alie ne ricevos.

                <p>Se mesaĝo konformas al neniu temo, ĝian liveron regos la ĉi-suba agordo. Se vi elektos neniun temon, vi ricevos la tutan poŝton de la listo.</p>
        </td><td bgcolor="#cccccc">
        <mm-topics>
        </td></tr>

    <tr><td bgcolor="#cccccc">
        <strong>Ĉu vi volas ricevi poŝton konforman al neniu temfiltro?</strong><p>

                Ĉi tiu agordo vin koncernas nur se vi abonis almenaŭ unu temon en la ĉi-supra agordo. Ĝi priskribas la regulon por liveri poŝton konforman al neniu difinita temo. Elektinte <em>Ne</em>'n, vi ne ricevos poŝton kiu konformas al neniu temo, dum elektinte <em>Jes</em>'on ĝin ja ricevos.</p>

                <p>Se neniun temon elektis supre, vi ricevos ĉiun poŝton de la listo.
        </td><td bgcolor="#cccccc">
        <mm-suppress-nonmatching-topics>Ne<br>
        <mm-receive-nonmatching-topics>Jes
        </td></tr>

    <tr><td bgcolor="#cccccc">
        <strong>Ĉu vi volas eviti duobligon de poŝto?</strong><p>

                Vi povas elekti ne ricevi duan kopion de mesaĝo sendita tra la listo kiam via adreso aperas en ĝiaj kampoj <tt>Al: (To:)</tt> aŭ<tt> Cc:</tt>. Elektu <em>Jes</em>'on por ne ricevi duoblaĵojn, aŭ elektu <em>Ne</em>'n por ricevi ilin.

                <p>Se la listo estas agordita por personecigi poŝton kaj vi elektis ricevi duoblaĵojn, la kaplinio <tt>'X-Mailman-Copy: yes'</tt> estos aldonita al tiuj kopioj.

        </td><td bgcolor="#cccccc">
        <mm-receive-duplicates-button>Ne<br>
        <mm-dont-receive-duplicates-button>Jes<p>
        <mm-global-nodupes-button><i>Ŝanĝu ĉie</i>
        </td></tr>

    <tr><TD colspan="2">
        <center><MM-options-Submit-button></center>
        </td></tr>

</table>
</center>
<p>
<MM-Form-End>

<MM-Mailman-Footer>
</body>
</html>
