<html>
<head>
  <title>%(listname)s %(who)s Login</title>
  <script>function sf(){document.f.adminpw.focus();}</script>
</head>
<body bgcolor="#ffffff" onLoad="sf()">
<FORM METHOD=POST ACTION="%(path)s" name="f">
%(message)s
  <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
    <TR>
      <TD COLSPAN="2" WIDTH="100%%" BGCOLOR="#99CCFF" ALIGN="CENTER">
	<B><FONT COLOR="#000000" SIZE="+1">%(listname)s %(who)s
	    Login</FONT></B>
      </TD>
    </TR>
    <tr>
      <TD><div ALIGN="Right">Listens %(who)s adgangskode:</div></TD>
      <TD><INPUT TYPE="password" NAME="adminpw" SIZE="30"></TD>
    </tr>
    <tr>
      <td colspan=2 align=middle><INPUT type="SUBMIT"
                                        name="admlogin"
					value="Log ind...">
      </td>
    </tr>
  </TABLE>
      <p><strong><em>Vigtigt:</em></strong> Din Webbrowser skal acceptere
      modtagelse af cookies - ellers vil ingen af de administrative &aelig;ndringer
      blive gemt.

      <p><i>Session cookies</i> bruges p&aring; Mailmans administrative sider,
      s&aring; du ikke beh&oslash;ver at indtaste adgangskode for hver &aelig;ndring du foretager.
      De vil forsvinde automatisk n&aring;r du lukker din browser, eller du
      kan fjerne dem manuelt ved at klikke p&aring;
      <em>Log ud</em> linket under <em>Andre administrative aktiviteter</em>
      (som du f&aring;r op efter at have logget ind).
</FORM>
</body>
</html>
