עמוד זה מכיל תת-קבוצה של המסרים של <em>%(listname)s</em> ברשימת
הדיוור.  הוא כרגע מציג %(description)s

<p>עבור כל בקשה מנהלתית, נא לבחור את הפעולה שיש לנקוט, ולחץ על הלחצן
<b>הגש את כל המידע</b> כשתסיים.  הוראות מפורטות יותר זמינות <a href="%(detailsurl)s">כאן</a>.

<p>ניתן גם <a href="%(summaryurl)s">לצפות בסיכום</a> של כל הבקשות הממתינות.
