Teksten kan inneholde formateringskoder
som byttes ut med verdier fra listens oppsett. For detaljer, se
<a href="https://docs.python.org/2/library/stdtypes.html#string-formatting-operations">Pythons
formateringsregler (engelsk)</a>. Gyldige koder er:

<ul>
    <li><b>real_name</b> - Listens formaterte navn; vanligvis
    listenavnet med stor forbokstav eller store bokstaver enkelte steder.

    <li><b>list_name</b> - Listens navn som brukt i URLer,
    der det har betydning om den staves med store eller sm&aring; bokstaver.

    <li><b>host_name</b> - Internettadressen (fully qulified
    domain name) til maskinen som listeserveren g&aring;r p&aring;.

    <li><b>web_page_url</b> - Basis URL for Mailman. Denne kan
    legges til sammen med, f.eks. <em>listinfo/%(list_name)s</em>
    for &aring; danne URLen til en listes infoside.

    <li><b>description</b> - En kort beskrivelse av listen.

    <li><b>info</b> - Full beskrivelse av listen.

    <li><b>cgiext</b> - Tillegg som legges til CGI scripts.
</ul>
