Sellel lehel on &uuml;levaade k&otilde;igist 
<a href="%(adminurl)s"><em>%(listname)s</em> listi</a>
administratiivtaotlustest.

Alguses on nimekiri k&otilde;igist tellimise ja tellimise katkestamise
soovidest (kui neid on) ja seej&auml;rel tuleb l&auml;bivaatuseks kinni
peetud kirjade nimekiri.

<p>Iga taotluse juures valige toiming ja klikkige <b>Salvesta k&otilde;ik valikud</b>
kui olete l&otilde;petanud. 
T&auml;psemad juhendeid <a href="%(detailsurl)s">v&otilde;ib lugeda siin</a>.

<p><a href="%(viewallurl)s">&Uuml;levaade</a> k&otilde;igist kinni peetud kirjadest.
