Deze pagina bevat een lijst van de berichten op de <em>%(listname)s</em> maillijst
die wachten op uw goedkeuring.<br>
Het toont momenteel %(description)s

<p>Voor elk administratief verzoek dient u de te ondernemen handeling te selecteren.
Als u daarmee klaar bent, drukt u op de button <b>Verstuur de wijzigingen</b>.<br>
Meer gedetailleerde instructies kunt u <a href="%(detailsurl)s">hier</a> vinden.

<p>U kunt ook een <a href="%(summaryurl)s">totaaloverzicht bekijken</a> van alle onbehandelde verzoeken.