    </ul>
    <p>
      <a name="end"><b>Дата последнего сообщения:</b></a> 
       <i>%(lastdate)s</i><br>
    <b>Архив обновлен:</b> <i>%(archivedate)s</i>
    <p>
    <ul>
         <li> <b>Сортировать по:</b>
                %(thread_ref)s
                %(subject_ref)s
                %(author_ref)s
                %(date_ref)s
            <li><b><a href="%(listinfo)s">Подробная информация о списке рассылки...</a></b></li>
     </ul>
     <p>
     <hr>
     <i>Этот архив был создан программой Pipermail %(version)s.</i>
  </BODY>
</HTML>
