<html>
<head>
<title>Autenticazione per %(who)s di %(listname)s</title>
<script>function sf(){document.f.adminpw.focus();}</script>
</head>
<body bgcolor="#ffffff" onLoad="sf()">
<FORM METHOD=POST ACTION="%(path)s" name="f">
%(message)s
  <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
    <TR>
      <TD COLSPAN="2" WIDTH="100%%" BGCOLOR="#99CCFF" ALIGN="CENTER">
	<B><FONT COLOR="#000000" SIZE="+1">Autenticazione per %(who)s di
			%(listname)s</FONT></B>
      </TD>
    </TR>
    <tr>
    <TD><div ALIGN="Right">Password di lista per %(who)s:</div></TD>
      <TD><INPUT TYPE="password" NAME="adminpw" SIZE="30"></TD>
    </tr>
    <tr>
      <td colspan=2 align=middle><INPUT type="SUBMIT"
                                        name="admlogin"
					value="Fammi entrare...">
      </td>
    </tr>
  </TABLE>
  <p><strong><em>Importante:</em></strong> Da questo momento in
  avanti devi avere i cookie abilitati nel browser o non potrai
  effettuare nessuna operazione.

  <p>I cookie di sessione sono usati dal pannello di controllo
  di mailman in modo che tu non sia costretto a ri-autenticarti ad 
  ogni operazione.  Questo cookie sar&agrave; cancellato
  automaticamente all'uscita dal tuo browser oppure puoi chiedere
  la cancellazione esplicita cliccando il link <em>Termina sessione</em> nella
  sezione <em>Altre attivit&agrave; amministrative</em> (che vedrai
  quando ti sarai correttamente autenticato).
</FORM>
</body>
</html>
