Esti testu puede incluyir 
<a href="https://docs.python.org/2/library/stdtypes.html#string-formatting-operations">cadenes de formatu Python</a> que sustituyir&aacute;nse polos atributos de la llista. La llista de sustituciones permit&iacute;es son:

<ul>
    <li><b>real_name</b> - El nome 'presentable' de la llista. Davezu ye'l nome de la llista cola primer lletra en may&uacute;scula.
    
    <li><b>list_name</b> - El nome pol que s'identifica la llista nes URLs, estr&eacute;mense may&uacute;scules de min&uacute;scules.

    <li><b>host_name</b> - El nome can&oacute;nicu del sirvidor qu'agospia la llista.

    <li><b>web_page_url</b> - El URL base de Mailman. Por exemplu pa indicar la p&aacute;xina d'informaci&oacute;n de la llista nam&aacute;i habr&iacute;a d'amest&aacute;-y darrera: <em>listinfo/%(list_name)s</em>

    <li><b>description</b> - Una descripci&oacute;n concisa tocante a la llista de distribuci&oacute;n.

    <li><b>info</b> - La descripci&oacute;n completa tocante a la
    llista de distribuci&oacute;n.

    <li><b>cgiext</b> - La estensi&oacute;n que s'amiesta a los guiones
    CGI.
</ul>
