このページは、承認のために保留されている
<em>%(listname)s</em>メーリングリストの投稿の一部が表示します。
現在の表示は: %(description)s

<p>それぞれの管理申請に対する処理を選択してください。
選択後に、<b>全部送信</b> ボタンをクリックしてください。
<a href="%(detailsurl)s">詳しい説明</a> もあります。

<p>また、全ての管理申請の <a href="%(summaryurl)s">要約を見る</a>
こともできます。
