<html>
<head>
    <title>Avtentikacija za zasebne arhive člana %(realname)s</title>
    <script>function sf(){document.f.username.focus();}</script>
</head>
<body bgcolor="#ffffff" onLoad="sf()">
<FORM METHOD=POST ACTION="%(action)s" name="f">
%(message)s
  <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
    <TR>
      <TD COLSPAN="2" WIDTH="100%%" BGCOLOR="#99CCFF" ALIGN="CENTER">
	<B><FONT COLOR="#000000" SIZE="+1">Avtentikacija za zasebne
	    arhive člana %(realname)s</FONT></B>
      </TD>
    </TR>
    <tr>
        <TD><div ALIGN="Right">E-po&scaron;tni naslov:</div></TD>
        <TD><INPUT TYPE="text" NAME="username" SIZE="30"></TD>
    </tr>
    <tr>
      <TD><div ALIGN="Right">Geslo:</div></TD>
      <TD><INPUT TYPE="password" NAME="password" SIZE="30"></TD>
    </tr>
    <tr>
      <td colspan=2 align="middle"><INPUT type="SUBMIT"
                                          name="submit"
					  value="Let me in...">
      </td>
    </tr>
  </TABLE>
      <p><strong><em>Pomembno:</em></strong> Od tega trenutka
      dalje morate v brskalniku imeti omogočene pi&scaron;kotke,
      drugače skrbni&scaron;ke spremembe ne bodo veljale.

      <p>Skrbni&scaron;ki vmesnik programa Mailman uporablja
      pi&scaron;kotke sej zato, da se vam ni potrebno za vsako
      skrbni&scaron;ko operacijo ponovno avtenticirati.  Ta
      pi&scaron;kotek bo potekel samodejno, ko boste zaprli
      brskalnik ali se odjavili s povezavo
      <em>Odjava</em> v <em>Ostale skrbni&scaron;ke dejavnosti</em>
      (ki bo vidno, takoj ko se prijavite).
      <p>
    <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
    <TR>
      <TD COLSPAN="2" WIDTH="100%%" BGCOLOR="#99CCFF" ALIGN="CENTER">
	<B><FONT COLOR="#000000" SIZE="+1">Password Reminder</FONT></B>
      </TD>
    </TR>
    <tr>
      <td>If you don't remember your password, enter your email address
          above and click the <em>Remind</em> button and your
          password will be emailed to you.</td>
    </tr>
    <tr>
      <td><center><INPUT name="login-remind" type="SUBMIT" value="Remind" ></center></td>
    </tr>
  </TABLE>
</FORM>
</body>
</html>
