Đoạn này có thể gồm 
<a href="https://docs.python.org/2/library/stdtypes.html#string-formatting-operations">chuỗi dạng thức Python</a> mà được khớp với thuộc tính hộp thư chung. Danh sách các điều thay thế có thể là:

<ul>
    <li><b>real_name</b> &mdash; ten « xinh » của hộp thư chung đó, thường là tên hộp thư với chữ hoa đầu từ.

    <li><b>list_name</b> &mdash; tên nhận diện hộp thư chung đó trong địa chỉ Mạng, mà phân biệt chữ hoa/thường.

    <li><b>host_name</b> &mdash; tên miền có khả năng đầy đủ nơi trình phục vụ hộp thư chung đó có chạy.

    <li><b>web_page_url</b> &mdash; địa chỉ cơ bản cho Mailman. Có thể phụ thêm, v.d. <em>listinfo/%(list_name)s</em> để tạo trang thông tin về hộp thư chung đó.

    <li><b>description</b> &mdash; mô tả ngắn về hộp thư chung đó.

    <li><b>info</b> &mdash; mô tả đầy đủ về hộp thư chung đó.

    <li><b>cgiext</b> &mdash; phần mở rộng được thêm vào tập lệnh CGI.
</ul>
