<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<HTML>
  <HEAD>
	<title>Archivo de la lista %(listname)s</title>
     <META NAME="robots" CONTENT="noindex,follow">
  </HEAD>
  <BODY BGCOLOR="#ffffff">
     <h1>Archivu de la llista %(listname)s</h1>
     <p>
      Ent&aacute; nun s'unvi&oacute; deng&uacute;n mensax a esta llista, de mou que l'archivu ta angua&ntilde;o ermu. Puedes obtener <a href="%(listinfo)s"> m&aacute;s informaci&oacute;n tocante a esta llista</a>.
     </p>
  </BODY>
  </HTML>
