Aquest text pot incloure 
<a href="https://docs.python.org/2/library/stdtypes.html#string-formatting-operations">cadenes 
de format del Python</a>, les quals es resoldran com atributs de la llista. 
La llista de les substitucions permeses &eacute;s la seg&uuml;ent: 

<ul>
    <li><b>real_name </b>- el nom formatat de la llista; normalment &eacute;s el nom 
    de la llista amb les maj&uacute;scules adequades.

    <li><b>list_name</b> - el nom amb el qual s'identifica la llista per 
    a URLs que distingeixen entre maj&uacute;scules i min&uacute;scules.

    <li><b>host_name</b> - el nom complet del servidor on s'executa el servidor de 
    llistes de correu.

    <li><b>web_page_url</b> - l'URL b&agrave;sic del Mailman. S'hi afegir, per exemple, 
    <em>listinfo/%(list_name)s</em> per a obtenir la p&agrave;gina d'informaci&oacute; 
    de la llista de correu.

    <li><b>description</b> - la descripci&oacute; breu de la llista de correu. 

    <li><b>info</b> - la descripci&oacute; completa de la llista de correu. 

    <li><b>cgiext</b> - l'extensi&oacute; que s'afegeix als scripts CGI. 

</ul>

