<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<html>
 <head>
  <title>Archiwum listy %(listname)s</title>
  <meta name="robots" content="noindex,follow">
  %(meta)s
 </head>
 <body bgcolor="#ffffff">
  <h1>Archiwum listy %(listname)s</h1>
  <p>Odwied&#378; <a href="%(listinfo)s">stron&#281; informacyjn&#261; tej listy</a>.</p>
  %(noarchive_msg)s
  %(archive_listing_start)s
  %(archive_listing)s
  %(archive_listing_end)s
 </body>
</html>
