Administratiivseid &uuml;lesandeid n&auml;idatakse kahel viisil, 
<a href="%(summaryurl)s">&uuml;levaate lehel</a>, ja <em>detailide lehel</em>.
&Uuml;levaateleht sisaldab ootel olevaid tellimuse ja tellimuse katkestamise
n&otilde;udeid ning ka postitusi, mis on &uuml;levaatamiseks kinni peetud, sorteerituna
saatja aadressi j&auml;rgi. Detailide leht sisaldab p&otilde;hjalikumat infot iga
kinnipeetud postituse kohta, k.a. k&otilde;iki p&auml;iseid ja l&otilde;iku kirja sisust.

<p>M&otilde;lemal lehel on v&otilde;imalik sooritada j&auml;rgnevaid tegevusi:

<ul>
<li><b>Viivita</b> -- Viivita otsuse tegemisega. See taotlus j&auml;&auml;b
    edasist otsust ootama, kinni peetud kirju on siiski v&otilde;imalik 
    edasi saata v&otilde;i preservida (l&auml;hme info allpool)

<p><li><b>N&otilde;ustu</b> -- Anna luba kiri listi edastada v&otilde;i n&otilde;ustu
tellimuse v&otilde;i tellimuse katkestmaisega.

<p><li><b>Keeldu</b> -- Keeldu kirja listi edastamisest, saatjat
    teavitatakse ning kiri eemaldatakse j&auml;rjekorrast. Tellimusn&otilde;uete
    puhul keeldu n&otilde;ude rahuldamisest. M&otilde;lemal juhul oleks soovitav
    lisada tekstikasti selgitus keeldumise kohta.

<p><li><b>Viska &auml;ra</b> -- Viska kiri minema saatjat teavitamata.
    Tellimusn&otilde;uete puhul visatakse tellimus lihtsalt minema, ilma
    tellijat teavitamata. Seda on soovitav teha, kui tegemist on 
    sp&auml;mmiga.
</ul>

<p>Kinni peetud kirjade puhul m&auml;rgistage kastike <b>Preserve</b> 
kastikesse, kui soovite j&auml;tta koopiat sellest kirjast listserveri
haldurile. See on kasulik abusive teadete puhul, mida soovid oma
huvialast eemaldada, kui mida tahad siiski hilisemaks inspekteerimiseks
alles hoida.

<p>M&auml;rgistage <b>Edasta</b> kastike ja kirjutage vastavasse lahtrisse
aadress kui soovite kirja edasi saata kellegile, kes ei ole listis.
Kui soovite kinnipeetud kirja enne listi saatmist muuta, siis peaksite
selle kirja k&otilde;igepealt endale edastama (v&otilde;i listihalduritele) ning
seej&auml;rel originaalse kirja kustutama. Siis, kui kiri on teie postkasti
j&otilde;udnud, tehke oma muudatused ja saatke kiri tagasi listi, lisades
<tt>Approved:</tt> p&auml;ise koos listi parooliga. Netiketi kohaselt
on viisakas kui lisate originaalkirjale juurde m&auml;rkuse selle kohta,
et olete kirja muutnud.

<p>Kui kirja saatjaks on listi tellija, keda modereeritakse, siis on
teil v&otilde;imalik saatjalt see piirang eemaldada. See on kasulik juhul,
kui teie listis kasutatakse uute liikmete prooviaega ja te olete
otsustanud, et see liige v&otilde;ib postitada ilma listihaldurit asjasse
segamata.

<p>Kui saatja ei ole listi liige, siis on teil v&otilde;imalik tema aadress
<em>saatjate filtrisse</em> lisada. Neid filtreid kirjeldatakse l&auml;hemalt
<a href="%(filterurl)s">saatjafiltrite privaatsuse lehel</a> ja see
v&otilde;ib olla &uuml;ks j&auml;rgnevatest: <b>auto-accept</b> (lubatakse l&auml;bi), <b>auto-hold</b>
 (peetakse l&auml;bivaatuseks kinni), <b>auto-reject</b> (keeldutakse) v&otilde;i
 <b>auto-discard</b> (visatakse minema). Seda seadistust ei ole v&otilde;imalik
 kasutada, kui aadress on juba &uuml;hes neist saatjafiltritest.

<p>Kui olete l&otilde;petanud, klikkide nupul <em>Salvesta k&otilde;ik valikud</em> lehe
alguses v&otilde;i l&otilde;pus. See submitid k&otilde;ik tegevused k&otilde;igile administratiivn&otilde;utele
mille kohta te olete otsuse teinud.

<p><a href="%(summaryurl)s">Tagasi kokkuv&otilde;ttesse</a>.
