Teksten kan indeholde formateringskoder
som udskiftes med v&aelig;rdier fra listens ops&aelig;tning. For detaljer, se
<a href="https://docs.python.org/2/library/stdtypes.html#string-formatting-operations">Pythons
formateringsregler (engelsk)</a>. Gyldige koder er:

<ul>
    <li><b><code>real_name</code></b> - Listens formaterede navn; normalt
    listenavnet med stort forbogstav eller store bogstaver enkelte steder.

    <li><b><code>list_name</code></b> - Listens navn som brugt i URLer,
    hvor det har betydning om den staves med store eller sm&aring; bogstaver.
    (For bagudkompatibilitet, er <code>_internal_name</code> det samme.)

    <li><b><code>host_name</code></b> - Internetadressen (fully qualified
    domain name) til maskinen som listeserveren k&oslash;rer p&aring;.

    <li><b><code>web_page_url</code></b> - Basis URL for Mailman. Denne kan
    kombineres med f.eks. <em><code>listinfo/%(list_name)s</code></em>
    for at danne URLen til en listes infoside.

    <li><b><code>description</code></b> - En kort beskrivelse af listen.

    <li><b><code>info</code></b> - Fuld beskrivelse af listen.

    <li><b><code>cgiext</code></b> - Extension som tilf&oslash;jes CGI scripts.
</ul>
