
	    <tr>
            <td>%(archivelabel)s:</td>
            
  <td> <A href="%(archive)s/thread.html">[ стабло]</a> <A href="%(archive)s/subject.html">[ 
    тема]</a> <A href="%(archive)s/author.html">[ аутор]</a> <A href="%(archive)s/date.html">[ 
    датум ]</a> </td>
            %(textlink)s
            </tr>

