<html>
<head>
  <title>%(listname)s %(who)s prisijungimas</title>
<script>function sf(){document.f.adminpw.focus();}</script>
</head>
<body bgcolor="#ffffff" onLoad="sf()">
<FORM METHOD=POST ACTION="%(path)s" name="f">
%(message)s
  <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
    <TR>
      <TD COLSPAN="2" WIDTH="100%%" BGCOLOR="#99CCFF" ALIGN="CENTER">
	<B><FONT COLOR="#000000" SIZE="+1">%(listname)s %(who)s
	    prisijungimas</FONT></B>
      </TD>
    </TR>
    <tr>
      <TD><div ALIGN="Right">Forumo %(who)s slaptažodis:</div></TD>
      <TD><INPUT TYPE="password" NAME="adminpw" SIZE="30"></TD>
    </tr>
    <tr>
      <td colspan=2 align=middle><INPUT type="SUBMIT"
                                        name="admlogin"
					value="Užeiti">
      </td>
    </tr>
  </TABLE>
      <p><strong><em>Svarbu:</em></strong> 
      Jūs turite nustatyti "cookies enabled",
      kitaip &scaron;io puslapio nustatymų pakeitimai nebus i&scaron;saugoti.
      
      <p>Tai reikalinga tam, kad kiekvieno Jūsų veiksmo patrvirtinimui nereikėtų i&scaron; naujo įvedinėti slaptažodžių.
      Prisijungimo informacija bus i&scaron;saugota Jūsų kompiueryje.
      &Scaron;i informacija i&scaron;trinama kai tik i&scaron;einate i&scaron; tinklapių peržiūros programos
      arba atsijungiate nuo administratoriaus puslapio paspausdami <em>Logout</em>
      lange <em>Kita priežiūros veikla</em>, nuoroda į kurį atsiras kai tik sėkmingai prisijungsite.
</FORM>
</body>
</html>
