<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<HTML>

<HEAD>
    <TITLE>Общая информация о списке рассылки <MM-List-Name></TITLE>

</HEAD>
<BODY BGCOLOR="#ffffff">
    <P>
      <TABLE BORDER="0" CELLSPACING="4" CELLPADDING="5">
        <TR>
          <TD COLSPAN="2" WIDTH="100%" BGCOLOR="#99CCFF" ALIGN="CENTER">
            <B><FONT COLOR="#000000" SIZE="+1"><MM-List-Name> &mdash; <MM-List-Description></FONT></B>
          </TD>
        </TR>
        <tr>
            <td colspan="2">
              <p>&nbsp;
            </td>
          </tr>
          <tr>
            <TD COLSPAN="1" WIDTH="100%" BGCOLOR="#FFF0D0"><B><FONT COLOR="#000000">О списке рассылки <MM-List-Name></FONT></B></TD>
            <TD COLSPAN="1" WIDTH="100%" BGCOLOR="#FFF0D0">
              <MM-lang-form-start><MM-displang-box> <MM-list-langs>
              <MM-form-end>
            </TD>
          </TR>
            <tr>
              <td colspan="2">
                <P><MM-List-Info></P>
                <p>Для просмотра сообщений, отправленных в лист рассылки ранее, Вы можете воспользоваться <MM-Archive>архивом сообщений <MM-List-Name></MM-Archive>.
                <MM-Restricted-List-Message></p>
              </TD>
            </TR>
      <TR>
        <TD COLSPAN="2" WIDTH="100%" BGCOLOR="#FFF0D0"><B><FONT COLOR="#000000">Как пользоваться списком рассылки <MM-List-Name></FONT></B></TD>
      </TR>
      <tr>
        <td colspan="2">
            Для того, чтобы отправить сообщение всем подписчикам списка рассылки, посылайте письмо
            по адресу <A HREF="mailto:<MM-Posting-Addr>"><MM-Posting-Addr></A>.

            <p>Ниже Вы можете подписаться на этот список рассылки
            или изменить параметры своей подписки</p>
        </td>
      </tr>
      <TR>
        <TD COLSPAN="2" WIDTH="100%" BGCOLOR="#FFF0D0">
        <B><FONT COLOR="#000000">Подписаться на список рассылки <MM-List-Name></FONT></B>
        </TD>
      </TR>
      <tr>
        <td colspan="2">
          <P>
          Для того, чтобы подписаться на список рассылки <MM-List-Name>, заполните следующую форму.
          <MM-List-Subscription-Msg>
          <ul>
    <MM-Subscribe-Form-Start>
              <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2"
                WIDTH="70%">
                <TR>
                  <TD BGCOLOR="#dddddd" WIDTH="55%">Ваш электронный адрес:</TD>
                  <TD WIDTH="33%"><MM-Subscribe-Box>
        </TD>
        <TD WIDTH="12%">&nbsp;</TD></TR>
      <tr>
          <td bgcolor="#dddddd" width="55%">Ваше имя (необязательно):</td>
        <td width="33%"><mm-fullname-box></td>
        <TD WIDTH="12%">&nbsp;</TD></TR>
      <TR>
        <TD COLSPAN="3"><FONT SIZE=-1>Вы можете указать пароль, защищающий параметры Вашей подписки
            от несанкционированного изменения.
            <b>Не используйте важных паролей</b>, так как в системе Mailman пароли пересылаются
            по электронной почте в открытом виде.

            <br><br>Если Вы не хотите указывать пароль, система создаст его автоматически
            и вышлет на Ваш адрес подписки. Вы всегда можете инициировать оправку его
            Вам снова со страницы параметров подписки.
            <MM-Reminder>
            </font>
        </TD>
      </TR>  
      <TR>
        <TD BGCOLOR="#dddddd">Укажите пароль:</TD>
        <TD><MM-New-Password-Box></TD>
        <TD>&nbsp;</TD></TR>
      <TR> 
        <TD BGCOLOR="#dddddd">Подтвердите выбранный пароль:</TD>
        <TD><MM-Confirm-Password></TD>
        <TD>&nbsp; </TD></TR>
      <tr>
        <TD BGCOLOR="#dddddd">На каком языке Вы хотели бы видеть сообщения?</TD> 
        <TD> <MM-list-langs></TD>
        <TD>&nbsp; </TD></TR>
      <mm-digest-question-start>
      <tr>
        <td>Хотите ли Вы получать подписку в виде дайджестов?</td>
        <td><MM-Undigest-Radio-Button> Нет
            <MM-Digest-Radio-Button>  Да
        </TD>
      </tr>
      <mm-digest-question-end>
      <mm-recaptcha-ui>
      <mm-captcha-ui>
      <tr>
        <td colspan="3">
          <center><MM-Subscribe-Button></center>
    </td>
    </tr>
    </TABLE>
    <MM-Form-End>
    </ul>
    <TR>
      <TD COLSPAN="2" WIDTH="100%" BGCOLOR="#FFF0D0">
        <a name="subscribers">
        <B><FONT COLOR="#000000">Подписчики списка рассылки <MM-List-Name></FONT></B></a>
      </TD>
    </TR>
    <tr>
      <TD COLSPAN="2" WIDTH="100%">
        <MM-Roster-Form-Start>
        <MM-Roster-Option>
            <MM-Form-End>
          <p>
        <MM-Options-Form-Start>
        <MM-Editing-Options>
                <MM-Form-End>
      </td>
    </tr>
  </table>
<MM-Mailman-Footer>
</BODY>
</HTML>
