<html>
<head>
  <title>Автентифікація користувача %(who)s списку листування %(listname)s</title>
<script>function sf(){document.f.adminpw.focus();}</script>
</head>
<body bgcolor="#ffffff" onLoad="sf()">
<FORM METHOD=POST ACTION="%(path)s" name="f">
%(message)s
  <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
    <TR>
      <TD COLSPAN="2" WIDTH="100%%" BGCOLOR="#99CCFF" ALIGN="CENTER">
	<B><FONT COLOR="#000000" SIZE="+1">Автентифікація користувача %(who)s списку
	 листування %(listname)s</FONT></B>
      </TD>
    </TR>
    <tr>
      <TD><div ALIGN="Right">Введіть пароль користувача %(who)s:</div></TD>
      <TD><INPUT TYPE="password" NAME="adminpw" SIZE="30"></TD>
    </tr>
    <tr>
      <td colspan=2 align=middle><INPUT type="SUBMIT"
                                        name="admlogin"
					value="Почати роботу...">
      </td>
    </tr>
  </TABLE>
      <p><strong><em>Увага:</em></strong> Необхідно дозволити 
	використання cookies у вашому переглядачі, у іншому випадку
	ви не зможете внести жодних змін. 

      <p>Cookies використовуються для зберігання інформації про сеанс
	роботи, це дозволяє не вводити пароль при виконанні будь-якого
	адміністративного завдання. Інформація про сеанс автоматично
	скасовується при закриванні переглядача. Також ви можете негайно
	завершити сеанс натисшувши посилання <em>Від'єднатись</em> 
	у розділі <em>Інші адміністративні завдання</em> 
	(Ви зможете його побачити лише після початку сеансу).
</FORM>
</body>
</html>
