<html>
<head>
    <title>אימות של הארכיון הפרטי של %(realname)s</title>
    <script>function sf(){document.f.username.focus();}</script>
</head>
<body bgcolor="#ffffff" dir="rtl" onLoad="sf()">
<FORM METHOD=POST ACTION="%(action)s" name="f">
%(message)s
  <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
    <TR>
      <TD COLSPAN="2" WIDTH="100%%" BGCOLOR="#99CCFF" ALIGN="CENTER">
	<B><FONT COLOR="#000000" SIZE="+1">אימות של הארכיון הפרטי של%(realname)s</FONT></B>
      </TD>
    </TR>
    <tr>
        <TD><div ALIGN="Right">כתובת דוא"ל:</div></TD>
        <TD><INPUT TYPE="text" NAME="username" SIZE="30"></TD>
    </tr>
    <tr>
      <TD><div ALIGN="Right">סיסמא:</div></TD>
      <TD><INPUT TYPE="password" NAME="password" SIZE="30"></TD>
    </tr>
    <tr>
      <td colspan=2 align="middle"><INPUT type="SUBMIT"
                                          name="submit"
					  value="הכנס אותי...">
      </td>
    </tr>
  </TABLE>
      <p><strong><em>חשוב:</em></strong> מנקודה זו ואילך, עוגיות חייבות
		להיות מאופשרות בדפדפן שלך, אחרת תאלץ
		לעבור אימות נוספת בעבור כל פעולה שתבצע.

<p>עוגיות מושב משמשים לדוור בממשק הארכיון הפרטי כדי
		שלא תצטריך לבצע אימות מחדש עם כל פעולה.
		תפוג תוקפה של עוגיה זו אוטומטית כאשר תסגור
		את הדפדפן, או שאתה יכול לגרום לפוגת תוקפה
		מפורשות על ידי כניסה לעמוד האפשריות המנוי שלך
		ולחיצה על הלחצן <em>יציאה</em>.
      <p>
    <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
    <TR>
      <TD COLSPAN="2" WIDTH="100%%" BGCOLOR="#99CCFF" ALIGN="CENTER">
	<B><FONT COLOR="#000000" SIZE="+1">Password Reminder</FONT></B>
      </TD>
    </TR>
    <tr>
      <td>If you don't remember your password, enter your email address
          above and click the <em>Remind</em> button and your
          password will be emailed to you.</td>
    </tr>
    <tr>
      <td><center><INPUT name="login-remind" type="SUBMIT" value="Remind" ></center></td>
    </tr>
  </TABLE>
</FORM>
</body>
</html>
