Administrativni zahtjevi su prikazani na jedan od dva načina, na <a
href="%(summaryurl)s">stranici sažetak</a> i na stranici <em>detalji</em>.
 Stranica sažetak sadrži zahtjeve za pretplatom i odjavom koji su na 
čekanju, kao i poruke koje čekaju va&scaron;e odobrenje, grupirane po e-mail adresi 
po&scaron;iljatelja. Stranica detalji sadrži detaljan prikaz svake zadržane poruke, 
uključujući sva zaglavlja poruke i izvadak tijela poruke.

<p>Sljedeće akcije dostupne su na svim stranicama:

<ul>
<li><b>Odgodi</b> -- Odgodite odluku za kasnije. Nikakva akcija 
    nije poduzeta za ovaj administrativni zahtjev na čekanju, ali &scaron;to  
    se tiče zadržanih poruka, njih možete i dalje proslijediti (pogledajte niže).

<li><b>Odobri</b> -- Odobri poruku &scaron;aljući je na listu.
    Kod zahtjeva za članstvom odobri promjenu u statusu članstva.

<li><b>Odbaci</b> -- Odbaci poruku &scaron;aljući poruku o odbacivanju 
    po&scaron;iljatelju i napusti izvornu poruku.  Kod zahtjeva za članstvom 
    odbaci promjenu u statusu članstva. U bilo kojem slučaju 
    trebali biste napisati razlog odbacivanja u pratećem polju za tekst.

<li><b>Napusti</b> -- Odbaci izvornu poruku bez slanja poruke o odbacivanju. 
    Kod zahtjeva za članstvom, ovo jednostavno napu&scaron;ta zahtjev bez ikakve poruke 
    osobi koja je uputila zahtjev. To je obično akcija koju želite poduzeti za poznate spam
		poruke.
</ul>

<p>Za zadržane poruke, uključite opciju <b>Sačuvaj</b> ako želite 
pohraniti kopiju poruke za administratora. Ovo je korisno za 
zloupotrebljene poruke koje želite odbaciti, ali želite sačuvati 
podatak za kasnju provjeru.

<p>Uključite opciju <b>Proslijedi</b> i upi&scaron;ite adresu na koju želite proslijediti poruku 
ako je prosljeđujete nekome tko nije na listi. Da biste uredili zadržanu poruku 
prije nego &scaron;to je ona poslana na listu, trebali biste je proslijediti sebi (ili vlasnicima liste) 
i napustiti izvornu poruku. Nakon pojavljivanja poruke u Va&scaron;em po&scaron;tanskom pretincu, 
napravite izmjene i ponovno po&scaron;aljite poruku na listu, uključujući <tt>Odobreno:</tt> 
zaglavlje koje sadrži lozinku liste. U ovom slučaju nije preporučljivo pisati komentar o promjeni
teksta poruke.

<p>Ako je po&scaron;iljatelj član liste koja je moderirana, opcionalno možete obrisati njegovu 
moderacijsku oznaku. Ovo je korisno kada je Va&scaron;a lista konfigurirana tako da stavlja 
nove članove na probno kori&scaron;tenje, a Vi ste odlučili da se tome članu može vjerovati 
kod slanja novih poruka bez odobravanja istih.

<p>Ako po&scaron;iljatelj nije član liste, možete dodati e-mail adresu u 
<em>po&scaron;iljateljev filter</em>.  Po&scaron;iljateljevi filteri su opisani na <a
href="%(filterurl)s">stranici privatnost po&scaron;iljateljevi filteri</a> i mogu biti:  
<b>auto-prihvati</b> (Prihvaćeni), <b>auto-zadrži</b> (Zadržani),
<b>auto-odbaci</b> (Odbačeni), ili <b>auto-napusti</b> (Napu&scaron;teni).  Ova 
opcija neće biti omogućena ako je adresa već na jednom od po&scaron;iljateljevih filtera.

<p>Kada ste zavr&scaron;ili, kliknite na gumb <em>Po&scaron;alji Sve Podatke</em>
na vrhu ili na dnu stranice. Ovo će poslati sve odabrane akcije za sve administrativne 
zahtjeve za koje ste se odlučili.

<p><a href="%(summaryurl)s">Povratak na stranicu sažetak</a>.
