<html>
<head>
    <link rel="SHORTCUT ICON" href="<mm-favicon>">
    <title><MM-Presentable-User> persoonlijke instellingen voor <MM-List-Name>
    </title>
</head>
<BODY BGCOLOR="#ffffff">
    <TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="5">
    <TR><TD WIDTH="100%" BGCOLOR="#99CCFF"><B>
        <FONT COLOR="#000000" SIZE=+1>
        <MM-List-Name> persoonlijke instellingen voor <MM-Presentable-User>
        </FONT></B></TD></TR>
    </TABLE>
<p>
<table width="100%" border="0" cellspacing="5" cellpadding="5">
    <tr><td>
        <b><MM-Presentable-User></b>'s aanmeldstatus,
        wachtwoord, en andere instellingen voor de <MM-List-Name> maillijst.
        </td><td><MM-Form-Start><mm-logout-button><MM-Form-End></td>
    </tr><tr>
        <td colspan="2">
        <MM-Case-Preserved-User>

        <MM-Disabled-Notice>

        <p><mm-results>
        </td>
    </tr>
</table>

<MM-Form-Start>
<p>
<TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="5">
    <TR><TD WIDTH="100%" BGCOLOR="#FFF0D0" colspan="2">
        <FONT COLOR="#000000">
        <B>Uw <MM-List-Name> lidmaatschapsinformatie wijzigen</B>
        </FONT></TD></TR>
    <tr><td colspan="2">U kunt het adres veranderen waaronder u bij de maillijst staat
     aangemeld door het nieuwe adres in de onderstaande velden in te voeren.  Let erop dat u een aan
     dit nieuwe adres verzonden bevestingsbericht moet beantwoorden voordat de adreswijziging definitief
     wordt doorgevoerd.
        
        <p>U moet de adreswijziging bevestigen binnen <mm-pending-days>.

        <p>U kunt ook - optioneel - uw naam wijzigen (b.v. <em>Piet Paaltjes</em>).

        <p>Als u al uw lidmaatschappen van maillijsten op <mm-host> wilt wijzigen, dient u de checkbox
        <em>Wijzig in alle lijsten</em> aan te vinken.

        </td></tr>
    <tr><td><center>
        <table border="0" cellspacing="2" cellpadding="2" width="80%" cols="2">
        <tr><td bgcolor="#dddddd"><div align="right">Nieuw e-mailadres:</div></td>
            <td><mm-new-address-box></td>
            </tr>
        <tr><td bgcolor="#dddddd"><div align="right">Herhaal het nieuwe e-mailadres:</div></td> 
            <td><mm-confirm-address-box></td>
            </tr>
        </tr></table></center>
        </td>
        <td><center>
        <table border="0" cellspacing="2" cellpadding="2" width="80%" cols="2">
            <tr><td bgcolor="#dddddd"><div align="right">Uw naam (optioneel):</div></td>
            <td><mm-fullname-box></td>
            </tr>
        </table></center>
        </td>
        </tr>
    <tr><td colspan="2"><center><mm-change-address-button>
        <p><mm-global-change-of-address>Wijzig in alle lijsten</center></td>
    </tr>
</table>

<p>
<TABLE WIDTH="100%" BORDER="0" CELLSPACING="5" CELLPADDING="5">
    <TR><TD WIDTH="50%" BGCOLOR="#FFF0D0"><FONT COLOR="#000000">
        <B>Uzelf afmelden van de <MM-List-Name> mailing lijst</B></td>

        <TD WIDTH="50%" BGCOLOR="#FFF0D0"><FONT COLOR="#000000">
        <B>Andere  <MM-Host> maillijsten waarbij u bent aangemeld</B>
        </FONT></TD></TR>

    <tr><td>
        Vink de onderstaande checkbox aan en klik op de button om uw lidmaatschap
        van deze maillijst te beeindigen. <strong>Waarschuwing:</strong>
        u wordt direct uit de maillijst verwijderd!
        <p>
        <center>
        <p><MM-Unsubscribe-Button></p>
        </center></td>
    <td>
        U kunt een overzicht bekijken van alle andere maillijsten op <mm-host> waarvan
        u lid bent. Gebruik dit als u als dezelfde wijzigingen in uw persoonlijke instellingen
        wilt doorvoeren bij die andere lijsten.
        <p>
        <center>
        <p><MM-Other-Subscriptions-Submit></p>
        </center>
        </TD></TR>
</table>

<TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="5">
    <TR><TD COLSPAN=2 WIDTH="100%" BGCOLOR="#FFF0D0"><FONT COLOR="#000000">
        <B>Uw <MM-List-Name> wachtwoord</B>
        </FONT></TD></TR>

    <tr valign="TOP"><td WIDTH="50%">
        <a name=reminder>
        <center>
        <h3>Uw wachtwoord vergeten?</h3>
        </center>
        Druk op de knop, en het wachtwoord wordt verstuurd naar uw e-mailadres.
        <p><MM-Umbrella-Notice>
        <center>
        <p>
        <MM-Email-My-Pw>
        </p>
        </center>
        </td>

    <td WIDTH="50%">
        <a name=changepw>
        <center>
        <h3>Uw wachtwoord wijzigen</h3>
        <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2" WIDTH="70%" COLS=2>
            <TR><TD BGCOLOR="#dddddd"><div align="right">Nieuw wachtwoord:</div></TD>
                <TD><MM-New-Pass-Box></TD>
                </TR>
            <TR>
                <TD BGCOLOR="#dddddd"><div align="right">Herhaal het nieuwe wachtwoord:</div></TD>
                <TD><MM-Confirm-Pass-Box></TD>
            </TR>
        </table>

        <MM-Change-Pass-Button>
        <p><center><mm-global-pw-changes-button>Wijzig in alle lijsten
        </center>
</TABLE>

<p>
<TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="5">
    <TR><TD WIDTH="100%" BGCOLOR="#FFF0D0"><FONT COLOR="#000000">
        <B>Uw <MM-List-Name> persoonlijke instellingen</B>
        </FONT></TD></TR>
</table>

<p>
<i><strong>De huidige instellingen zijn aangevinkt.</strong></i>

<p>Let erop dat sommige instellingen een <em>Instellen voor alle lijsten</em>
optie hebben. Het aanvinken van deze checkbox houdt in dat de wijzigingen in alle <mm-host>
lijsten waarvan u lid bent wordt doorgevoerd. Klik hierboven op
<em>Laat mijn andere aanmeldingen zien</em> voor een overzicht van die lijsten.
<p>
<TABLE BORDER="0" CELLSPACING="3" CELLPADDING="4" WIDTH="100%">
    <tr><TD BGCOLOR="#cccccc">
        <a name="disable">
        <strong>Mail ontvangen</strong></a><p>
        Zet dit op <em>Aan</em> om berichten van de lijst
        te ontvangen.  Zet dit op <em>Uit</em> als u lid wilt blijven, maar tijdelijk
        geen berichten wilt ontvangen (bv. als u op vakantie gaat). Vergeet niet om de
        ontvangst bij thuiskomst weer in te schakelen; dit gebeurt niet automatisch.
        </td><td bgcolor="#cccccc">
        <mm-delivery-enable-button>Aan<br>
        <mm-delivery-disable-button>Uit<p>
        <mm-global-deliver-button><i>Instellen voor alle lijsten</i>
        </td></tr>

<!--Start-Digests-Delete-->
    <tr><TD BGCOLOR="#cccccc">
        <strong>Verzamelmail ontvangen</strong><p>
        Als u deze optie op <em>Aan</em> zet, ontvangt u geen losse berichten op
        het moment dat ze verzonden worden, maar ontvangt u die gebundeld
        (gewoonlijk &eacute;&eacute;n per dag, bij 'drukke' lijsten kunnen het er meerdere zijn). Als u
        de optie van <em>Aan</em> naar <em>Uit</em> verandert, zult u mogelijk 
        nog &eacute;&eacute;n laatste verzamelmail ontvangen.
        </td><td bgcolor="#cccccc">
        <MM-Undigest-Radio-Button>Uit<br>
        <MM-Digest-Radio-Button>Aan
        </td></tr>
        
    <tr><TD BGCOLOR="#cccccc">
        <strong>Verzamelmail in MIME of gewone tekst?</strong><p>
        Uw mailprogramma ondersteunt mogelijk geen MIME verzamelmails. Over het algemeen
        genieten MIME verzamelmails de voorkeur, maar als u problemen hebt om ze te lezen,
        kies dan voor <em>Gewone tekst</em>.
        </td><td bgcolor="#cccccc">
        <MM-Mime-Digests-Button>MIME<br>
        <MM-Plain-Digests-Button>Gewone tekst<p>
        <mm-global-mime-button><i>Instellen voor alle lijsten</i>
        </td></tr>
<!--End-Digests-Delete-->
        
    <tr><TD BGCOLOR="#cccccc">
        <strong>Door uzelf verstuurde berichten ontvangen?</strong><p>
        Normaal ontvangt u alle berichten van deze lijst. Als u niet uw eigen berichten wilt
        ontvangen, zet deze optie op <em>Nee</em>.
        </td><td bgcolor="#cccccc">
        <mm-dont-receive-own-mail-button>Nee<br>
        <mm-receive-own-mail-button>Ja
        </td></tr>

    <tr><TD BGCOLOR="#cccccc">
        <strong>Ontvangstbevestiging van door uzelf verstuurde berichten?</strong><p>
        </td><td bgcolor="#cccccc">
        <mm-dont-ack-posts-button>Nee<br>
        <mm-ack-posts-button>Ja
        </td></tr>

    <tr><td bgcolor="#cccccc">
        <strong>Wachtwoordherinneringen?</strong><p>
        Eenmaal per maand ontvangt u een e-mail met een wachtwoordherinnering
        voor elke lijst waarbij u bent aangemeld. U kunt dit per lijst uitzetten door de
        optie <em>Nee</em> aan te vinken. Als u de wachtwoordherinneringen voor
        alle lijsten uitzet, zullen geen herinneringsberichten naar u worden gestuurd.
        </td><td bgcolor="#cccccc">
        <mm-dont-get-password-reminder-button>Nee<br>
        <mm-get-password-reminder-button>Ja<p>
        <mm-global-remind-button><i>Instellen voor alle lijsten</i>
        </td></tr>

    <tr><TD BGCOLOR="#cccccc">
        <strong>Uzelf geheimhouden op de ledenlijst?</strong><p>
        Normaal wordt uw e-mailadres getoond als iemand de ledenlijst bekijkt (zij het in
        een afwijkende vorm om het oogsten van adressen door spammers tegen te
        gaan). Als u &uuml;berhaupt niet wilt dat uw e-mailadres in de ledenlijst wordt
        getoond, selecteer de optie <em>Ja</em>.
        </td><td bgcolor="#cccccc">
        <MM-Public-Subscription-Button>Nee<br>
        <MM-Hide-Subscription-Button>Ja
        </td></tr>

    <tr><TD BGCOLOR="#cccccc">
        <strong>Wat is uw voorkeurstaal?</strong><p>
        </td><td bgcolor="#cccccc">
        <MM-list-langs>
        </td></tr>

    <tr><td bgcolor="#cccccc">
        <strong>Van welke onderwerp-categori&euml;en wilt u berichten ontvangen?</strong><p>
                Door &eacute;&eacute;n of meer onderwerpen te kiezen, kunt u de via deze maillijst verstuurde
                berichten filteren, zodat u slechts een deel van de berichten ontvangt.
                Als een bericht overeenkomt met &eacute;&eacute;n van de door u gekozen onderwerpen,
                dan zult u het bericht ontvangen, in het andere geval niet.

                <p>Als een bericht met geen enkel onderwerp overeenkomt, hangt het van de
                hieronder vermelde instelling af of u het bericht zult ontvangen. Als u geen enkel
                onderwerp kiest, zult u &aacute;lle berichten van deze maillijst ontvangen.
                </td><td bgcolor="#cccccc">
        <mm-topics>
        </td></tr>

    <tr><td bgcolor="#cccccc">
        <strong>Wilt u berichten ontvangen die met geen enkele onderwerp-filter overeenkomen?</strong><p>
                Deze optie heeft alleen effect als u hierboven ten minste &eacute;&eacute;n onderwerp hebt
                gekozen. De optie geeft de standaard aflevering aan voor berichten die met geen enkele
                van de hierboven gekozen onderwerpen overeenkomen. Het selecteren van <em>Nee</em>
                houdt in dat als het bericht met geen enkel onderwerp-filter overeenkomt, u het bericht niet
                zult ontvangen, terwijl het selecteren van <em>Ja</em> inhoudt dat dergelijke berichten wel
                zullen worden ontvangen.
                
                <p>Als hierboven geen onderwerpen zijn geselecteerd, zult u elk bericht van deze maillijst
                ontvangen.
                </td><td bgcolor="#cccccc">
        <mm-suppress-nonmatching-topics>Nee<br>
        <mm-receive-nonmatching-topics>Ja
        </td></tr>

    <tr><td bgcolor="#cccccc">
        <strong>Dubbele berichten vermijden?</strong><p>

                Als u ook zelf expliciet genoemd wordt in de <tt>Aan:</tt> of
                <tt>Cc:</tt> headers van een aan de lijst geadresseerd bericht, kunt u ervoor kiezen dat u
                het bericht niet dubbel ontvangt via de maillijst. Kies <em>Ja</em> om dergelijke dubbele
                berichten te vermijden; kies <em>Nee</em> om beide berichten te ontvangen.

                <p>Als de lijst verpersoonlijkte berichten toestaat, en u hebt ervoor gekozen om
                dubbele berichten te ontvangen, zal aan elk bericht de header <tt>X-Mailman-Copy: yes</tt>
                toegevoegd worden.
                
        </td><td bgcolor="#cccccc">
        <mm-receive-duplicates-button>Nee<br>
        <mm-dont-receive-duplicates-button>Ja<p>
        <mm-global-nodupes-button><i>Instellen voor alle lijsten</i>
        </td></tr>

    <tr><TD colspan="2">
        <center><MM-options-Submit-button></center>
        </td></tr>

</table>
</center>
<p>
<MM-Form-End>

<MM-Mailman-Footer>
</body>
</html>
