<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<!-- $Revision: 6023 $ -->
<HTML>
  <HEAD>
    <TITLE>Informace o konferenci <MM-List-Name></TITLE>
  
  </HEAD>
  <BODY BGCOLOR="#ffffff">

    <P>
      <TABLE BORDER="0" CELLSPACING="4" CELLPADDING="5">
	<TR>
	  <TD COLSPAN="2" WIDTH="100%" BGCOLOR="#99CCFF" ALIGN="CENTER">
	    <B><FONT COLOR="#000000" SIZE="+1"><MM-List-Name> --
	<MM-List-Description></FONT></B>
	  </TD>
	</TR>
	<tr>
	    <td colspan="2">
	      <p>&nbsp;
	    </td>
	  </tr>
	  <tr>
	    <TD COLSPAN="1" WIDTH="100%" BGCOLOR="#FFF0D0">
	      <B><FONT COLOR="#000000">Konference <MM-List-Name></FONT></B>
	    </TD>
            <TD COLSPAN="1" WIDTH="100%" BGCOLOR="#FFF0D0">
              <MM-lang-form-start><MM-displang-box> <MM-list-langs>
              <MM-form-end>
            </TD>
	  </TR>
	    <tr>
	      <td colspan="2">
		<P><MM-List-Info></P>
	  <p> Pokud si chcete prohl&eacute;dnou předchoz&iacute; př&iacute;spěvky 
              v t&eacute;to konferenci, nav&scaron;tivte 
	      <MM-Archive>archiv konference <MM-List-Name>
	      </MM-Archive>.
	      <MM-Restricted-List-Message>
	  </p>
	</TD>
      </TR>
      <TR>
	<TD COLSPAN="2" WIDTH="100%" BGCOLOR="#FFF0D0">
	  <B><FONT COLOR="#000000">Jak komunikovat s konferenc&iacute; <MM-List-Name></FONT></B>
	</TD>
      </TR>
      <tr>
	<td colspan="2">
	  Př&iacute;spěvky zas&iacute;lejte na adresu:
	  <A HREF="mailto:<MM-Posting-Addr>"><MM-Posting-Addr></A>.

	  <p>Pokud se chcete přihl&aacute;sit, nebo nějak konfigurovat sv&eacute; uživatelsk&eacute; konto,
              můžete tak učinit pr&aacute;vě zde.
	</td>
      </tr>
      <TR>
	<TD COLSPAN="2" WIDTH="100%" BGCOLOR="#FFF0D0">
	  <B><FONT COLOR="#000000">Přihl&aacute;&scaron;en&iacute; do konference <MM-List-Name></FONT></B>
	</TD>
      </TR>
      <tr>
	<td colspan="2">
	  <P>
             Pro přihl&aacute;&scaron;en&iacute; do konference <MM-List-Name> mus&iacute;te vyplnit n&aacute;sleduj&iacute;c&iacute; formul&aacute;ř.
	  <MM-List-Subscription-Msg>
	  <ul>
    <MM-Subscribe-Form-Start>
	      <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2"
		WIDTH="70%">
		<TR>
		  <TD BGCOLOR="#dddddd" WIDTH="55%">Va&scaron;e e-mailov&aacute; adresa:</TD>
		  <TD WIDTH="33%"><MM-Subscribe-Box>
	</TD>
	<TD WIDTH="12%">&nbsp;</TD></TR>
      <tr>
        <td bgcolor="#dddddd" width="55%">Va&scaron;e jm&eacute;no (nepovinn&eacute;):</td>
        <td width="33%"><mm-fullname-box></td>
	<TD WIDTH="12%">&nbsp;</TD></TR>
      <TR>
	<TD COLSPAN="3"><FONT SIZE=-1>Mus&iacute;te zadat heslo  pro ochranu sv&eacute;ho konta
	před nepovolan&yacute;mi osobami. V ž&aacute;dn&eacute;m př&iacute;padě nepouž&iacute;vejte ž&aacute;dn&eacute; heslo, kter&eacute;
	použ&iacute;v&aacute;te na nějak&eacute;m jin&eacute;m syst&eacute;mu, př&iacute;padně heslo, kter&eacute; je potřeba
	utajovat. Heslo je přen&aacute;&scaron;eno bez jak&eacute;hokoliv zabezpečen&iacute; a  nav&iacute;c
	V&aacute;m bude zas&iacute;l&aacute;no elektronickou po&scaron;tou.
            <br><br>
        Pokud heslo nezad&aacute;te, syst&eacute;m V&aacute;m přiděl&iacute; n&aacute;hodn&eacute; heslo, kter&eacute; V&aacute;m
        bude zasl&aacute;no mailem.
	    <MM-Reminder>
	    </font>
	</TD>
      </TR>  
      <TR>
	<TD BGCOLOR="#dddddd">Zvolte si heslo:</TD>
	<TD><MM-New-Password-Box></TD>
	<TD>&nbsp;</TD></TR>
      <TR> 
	<TD BGCOLOR="#dddddd">A je&scaron;tě jednou to sam&eacute; pro kontrolu:</TD>
	<TD><MM-Confirm-Password></TD>
	<TD>&nbsp; </TD></TR>
      <tr>
        <TD BGCOLOR="#dddddd">Jak&yacute; jazyk preferujete pro komunikaci s mailmanem?</TD> 
        <TD> <MM-list-langs></TD>
        <TD>&nbsp; </TD></TR>
      <mm-digest-question-start>
      <tr>
	<td>Přejete si dost&aacute;vat př&iacute;spěvky jen jednou denně, v&scaron;echny v jednom
	dopise? Tuto volbu zn&aacute;te asi jako digest.
	  </td>
	<td><MM-Undigest-Radio-Button> Ne
	    <MM-Digest-Radio-Button>  Ano
	</TD>
      </tr>
      <mm-digest-question-end>
      <mm-recaptcha-ui>
      <mm-captcha-ui>
      <tr>
	<td colspan="3">
	  <center><MM-Subscribe-Button></center>
    </td>
    </tr>
    </TABLE>
    <MM-Form-End>
    </ul>
    <TR>
      <TD COLSPAN="2" WIDTH="100%" BGCOLOR="#FFF0D0">
	<a name="subscribers">
        <B><FONT COLOR="#000000">&Uacute;častn&iacute;ci konference <MM-List-Name></FONT></B></a>
      </TD>
    </TR>
    <tr>
      <TD COLSPAN="2" WIDTH="100%">
	<MM-Roster-Form-Start>
	<MM-Roster-Option>
	    <MM-Form-End>
	  <p>
	<MM-Options-Form-Start>
	<MM-Editing-Options>
		<MM-Form-End>
      </td>
    </tr>
  </table>
<MM-Mailman-Footer>
</BODY>
</HTML>
