Цей текст може включати 
<a href="https://docs.python.org/2/library/stdtypes.html#string-formatting-operations">
форматовані рядки</a>, які пов'язані з ознаками списку.  Перелік
дозволених ознак:

<ul>
    <li><b>real_name</b> - "гарна" назва списку; зазвичай назва
	списку з великою першою літерою.

    <li><b>list_name</b> - назва списку, яка використовується
	у URL адресах сторінок, регістр літер має значення.

    <li><b>host_name</b> - повна назва домену списку розсилки.

    <li><b>web_page_url</b> - базова адреса для Mailman.  
	Цю адресу слід додавати, щоб отримати адресу інформаційної сторінки
	списку розсилки, наприклад <em>listinfo/%(list_name)s</em>.

    <li><b>description</b> - короткий опис списку розсилки.

    <li><b>info</b> - повний опис списку розсилки.

    <li><b>cgiext</b> - розширення файлів CGI сценаріїв.
</ul>
