<html>
<head>
  <title>%(listname)s 論壇 壇主驗證</title>
<script>function sf(){document.f.adminpw.focus();}</script>
</head>
<body bgcolor="#ffffff" onload="sf()">
<FORM METHOD=POST ACTION="%(path)s" name="f">
%(message)s
  <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
    <TR>
      <TD COLSPAN="2" WIDTH="100%%" BGCOLOR="#99CCFF" ALIGN="CENTER">
	<B><FONT COLOR="#000000" SIZE="+1">%(listname)s 論壇 壇主驗證</FONT></B>
      </TD>
    </TR>
    <tr>
      <TD> <div ALIGN="Right"> 壇主密碼: </div> </TD>
      <TD> <INPUT TYPE=password NAME=adminpw SIZE=30></TD>
    </tr>
    <tr>
      <td colspan=2 align=middle> <INPUT TYPE=SUBMIT name="request_login"
						     value="我填好了...">
      </td>
    </tr>
  </TABLE>
      <p><strong><em>重點:</em></strong> 從現在開始， 您必須
      將瀏覽器的 cookie 功能打開，否則您所作的異動將不會發生效用。

      <p>Mailman 的管理介面使用了 Session cookies ， 因此您不需要在每次
      異動資料時重新驗證密碼。此cookie 在您關閉瀏覽器時自動失效，
      或者您按下在 <em>Other Administrative Activities</em> 網頁中     
      <em>Logout</em> 的超連結 (一旦您成功的登錄之後，您就可以看到)。
</FORM>
