<html>
<head>
    <link rel="SHORTCUT ICON" href="<mm-favicon>">
    <title>Personlig medlemside for <MM-Presentable-User> p&aring; listen <MM-List-Name>
    </title>
</head>
<BODY BGCOLOR="#ffffff">
    <TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="5">
    <TR><TD WIDTH="100%" BGCOLOR="#99CCFF"><B>
        <FONT COLOR="#000000" SIZE=+1>
	Personlig medlemside for <MM-Presentable-User> p&aring; listen <MM-List-Name>
	</FONT></B></TD></TR>
    </TABLE>
<p>
<table width="100%" border="0" cellspacing="5" cellpadding="5">
    <tr><td>
        <b>Medlemsstatus, passord, og innstillinger for <MM-Presentable-User></b>
        p&aring; epostlisten <MM-List-Name>.
        </td><td><MM-Form-Start><mm-logout-button><MM-Form-End></td>
    </tr><tr>
        <td colspan="2">
        <MM-Case-Preserved-User>

        <MM-Disabled-Notice>

        <p><mm-results>
        </td>
    </tr>
</table>

<MM-Form-Start>
<p>
<TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="5">
    <TR><TD WIDTH="100%" BGCOLOR="#FFF0D0" colspan="2">
        <FONT COLOR="#000000">
        <B>Bytte epostadresse p&aring; <MM-List-Name></B>
	</FONT></TD></TR>
    <tr><td colspan="2">Du kan bytte ut den epostadressen du har meldt inn p&aring;
        listen ved &aring; skrive inn en annen epostadresse i feltene nedenfor.
        Merk at en epost med n&aelig;rmere instruksjoner vil da bli sendt til den nye
        adressen. Endringene trer ikke i kraft f&oslash;r du har bekreftet dem.
        Du har <mm-pending-days> p&aring; deg til &aring; bekrefte endringen.

        <p>Du kan ogs&aring; oppgi eller endre navnet ditt p&aring; listen (f.eks <em>Ola Normann</em>).

        <p>Hvis du vil endre epostadressen din for alle
           epostlistene du er p&aring;meldt p&aring; <mm-host>, kryss av for 
        <em>Endre alle lister</em>.

        </td></tr>
    <tr><td><center>
        <table border="0" cellspacing="2" cellpadding="2" width="80%" cols="2">
        <tr><td bgcolor="#dddddd"><div align="right">Ny epostadresse:</div></td>
            <td><mm-new-address-box></td>
            </tr>
        <tr><td bgcolor="#dddddd"><div align="right">Epostadresse en gang til:
            </div></td> 
            <td><mm-confirm-address-box></td>
            </tr>
        </tr></table></center>
        </td>
        <td><center>
        <table border="0" cellspacing="2" cellpadding="2" width="80%" cols="2">
            <tr><td bgcolor="#dddddd"><div align="right">Ditt navn
            (valgfritt):</div></td>
            <td><mm-fullname-box></td>
            </tr>
        </table></center>
        </td>
        </tr>
    <tr><td colspan="2"><center><mm-change-address-button>
         <p><mm-global-change-of-address>Endre min epostadresse p&aring; alle lister jeg er medlem av</center></td>
    </tr>
</table>

<p>
<TABLE WIDTH="100%" BORDER="0" CELLSPACING="5" CELLPADDING="5">
    <TR><TD WIDTH="50%" BGCOLOR="#FFF0D0"><FONT COLOR="#000000">
        <B>Melde deg av <MM-List-Name></B></td>

	<TD WIDTH="50%" BGCOLOR="#FFF0D0"><FONT COLOR="#000000">
        <B>Andre lister du er medlem av p&aring; <MM-Host></B>
	</FONT></TD></TR>

    <tr><td>
        Kryss av i avkrysningsboksen og klikk f&oslash;lgende knapp for &aring; melde deg
        av denne epostlisten.
        <strong>MERK:</strong> Du vil umiddelbart bli meldt ut av listen!
        <p>
        <center><MM-Unsubscribe-Button></center></td>
    <td>
        Du kan velge &aring; se alle lister du er p&aring;meldt, slik at du kan gj&oslash;re samme
        endringer p&aring; flere lister p&aring; en gang.

        <p>
        <center><MM-Other-Subscriptions-Submit></center>
	</TD></TR>
</table>

<TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="5">
    <TR><TD COLSPAN=2 WIDTH="100%" BGCOLOR="#FFF0D0"><FONT COLOR="#000000">
        <B>Ditt passord for <MM-List-Name></B>
	</FONT></TD></TR>

    <tr valign="TOP"><td WIDTH="50%">
        <a name=reminder>
        <center>
        <h3>Har du glemt passordet ditt?</h3>
        </center>
        Trykk p&aring; denne knappen for &aring; f&aring; passordet ditt tilsendt p&aring; epost.
        <p><MM-Umbrella-Notice>
        <center>
        <MM-Email-My-Pw>
        </center>
        </td>

    <td WIDTH="50%">
        <a name=changepw>
        <center>
        <h3>Bytte passord</h3>
        <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2" WIDTH="70%" COLS=2>
            <TR><TD BGCOLOR="#dddddd"><div align="right">Nytt
                passord:</div></TD>
                <TD><MM-New-Pass-Box></TD>
                </TR>
            <TR>
                <TD BGCOLOR="#dddddd"><div align="right">Nytt passord en gang
                til:</div></TD>
                <TD><MM-Confirm-Pass-Box></TD>
            </TR>
        </table>

        <MM-Change-Pass-Button>
        <p><center><mm-global-pw-changes-button>Endre passordet for alle
        lister jeg er medlem av p&aring; <mm-host>.
        </center>
</TABLE>

<p>
<TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="5">
    <TR><TD WIDTH="100%" BGCOLOR="#FFF0D0"><FONT COLOR="#000000">
        <B>Dine innstillinger for <MM-List-Name></B>
	</FONT></TD></TR>
</table>

<p>
<i><strong>Gjeldende innstillinger er valgt.</strong></i>

<p>Merk at noen av innstillingene har et <em>Bruk p&aring; alle</em> valg.
Krysser du av for det, vil alle lister du er medlem av p&aring; <mm-host> ogs&aring;
f&aring; innstillingen satt slik som du setter den her. Klikk p&aring; <em>Vise andre
lister jeg er medlem av</em> ovenfor for &aring; se hvilke andre epostlister du
er medlem av.
<p>
<TABLE BORDER="0" CELLSPACING="3" CELLPADDING="4" WIDTH="100%">
    <tr><TD BGCOLOR="#cccccc">
        <a name="disable">
        <strong>Motta meldinger</strong></a><p>
	Sett denne til <em>Ja</em> for &aring; motta epost som sendes til denne listen.
        Sett den til <em>Nei</em> hvis du i en periode ikke &oslash;nsker &aring; motta epost som sendes til listen,
        men likevel &oslash;nsker &aring; v&aelig;re medlem av listen. (kan v&aelig;re nyttig f.eks. hvis du skal p&aring; ferie)
        Setter du den til <em>Nei</em>, m&aring; du huske &aring; sette den tilbake igjen,
        for den vil ikke bli satt tilbake til <em>Ja</em> automatisk.
        </td><td bgcolor="#cccccc">
        <mm-delivery-enable-button>Ja<br>
        <mm-delivery-disable-button>Nei<p>
        <mm-global-deliver-button><i>Bruk p&aring; alle</i>
        </td></tr>

<!--Start-Digests-Delete-->
    <tr><TD BGCOLOR="#cccccc">
        <strong>Sammendrag-modus</strong><p>
	Setter du p&aring; sammendrag-modus, vil du med jevne mellomrom (vanligvis en gang om dagen,
        muligens flere ganger, det kommer an p&aring; hvor mye som sendes til listen) f&aring; en
	samle-epost som inneholder alle meldinger som blir sendt til listen, istedenfor &aring; f&aring; hver
	enkelt melding. Hvis du bytter fra sammendrag-modus til normal-
	modus, vil du muligens allikevel f&aring; en siste epost med sammendrag
	selv om du allerede da vil begynne &aring; motta alle meldinger som
	kommer til listen.
        </td><td bgcolor="#cccccc">
        <MM-Undigest-Radio-Button>Av<br>
        <MM-Digest-Radio-Button>P&aring;
        </td></tr>
        
    <tr><TD BGCOLOR="#cccccc">
        <strong>Motta sammendrag som ren tekst eller i MIME-format?</strong><p>
	Det kan v&aelig;re epostleseren din ikke st&oslash;tter sammendrag i MIME-format.
	&Aring; motta sammendrag i MIME-format anbefales, men f&aring;r du problemer med
	&aring; lese epost i det formatet, kan du velge ren tekst her.
        </td><td bgcolor="#cccccc">
        <MM-Mime-Digests-Button>MIME<br>
        <MM-Plain-Digests-Button>Ren tekst<p>
        <mm-global-mime-button><i>Bruk p&aring; alle</i>
        </td></tr>
<!--End-Digests-Delete-->
        
    <tr><TD BGCOLOR="#cccccc">
        <strong>Motta dine egne meldinger til listen?</strong><p>

        Vanligvis vil du motta epost som du selv sender til listen.
        Hvis du ikke vil motta disse, b&oslash;r du velge <em>Nei</em> her.
        </td><td bgcolor="#cccccc">
        <mm-dont-receive-own-mail-button>Nei<br>
        <mm-receive-own-mail-button>Ja
        </td></tr>

    <tr><TD BGCOLOR="#cccccc">
        <strong>Motta bekreftelse n&aring;r du sender epost til listen?</strong><p>

        Velg <em>Ja</em> her hvis du &oslash;nsker &aring; f&aring; en bekreftelse hver gang du sender en epost til listen.
        </td><td bgcolor="#cccccc">
        <mm-dont-ack-posts-button>Nei<br>
        <mm-ack-posts-button>Ja
        </td></tr>

    <tr><td bgcolor="#cccccc">
        <strong>F&aring; passordet ditt tilsendt jevnlig?</strong><p>
	En gang i m&aring;neneden kan det v&aelig;re du f&aring;r en epost som inneholder
	passordene for alle listene du er medlem av p&aring; dette systemet.
	Du kan skru av dette for denne enkelte listen her.
        </td><td bgcolor="#cccccc">
        <mm-dont-get-password-reminder-button>Nei<br>
        <mm-get-password-reminder-button>Ja<p>
        <mm-global-remind-button><i>Bruk p&aring; alle</i>
        </td></tr>

    <tr><TD BGCOLOR="#cccccc">
        <strong>Vil du vises p&aring; listen over medlemmer av listen?</strong><p>
	N&aring;r noen g&aring;r inn p&aring; websiden for &aring; se alle medlemmer av listen, vil
	vanligvis din epostadresse vises. (Men stavet p&aring; en m&aring;te slik at
	roboter som plukker opp epostadresser fra websider (og kanskje
	deretter sender s&oslash;ppel og reklame til den), ikke vil forst&aring; at det
	er en epostadresse.) Velg 'Nei' her hvis du ikke vil at epostadressen
	din skal vises p&aring; listen.
        </td><td bgcolor="#cccccc">
        <MM-Hide-Subscription-Button>Nei<br>
        <MM-Public-Subscription-Button>Ja
        </td></tr>

    <tr><TD BGCOLOR="#cccccc">
        <strong>Hvilket spr&aring;k foretrekker du?</strong><p>
        </td><td bgcolor="#cccccc">
        <MM-list-langs>
        </td></tr>

    <tr><td bgcolor="#cccccc">
        <strong>Hvilke emner vil du motta?</strong>
        <p>Ved &aring; velge ett eller flere emner, kan du filtrere meldingene som sendes til
        epostlisten, slik at du kun vil motta det som kan interessere deg.

        <p>Hvis en melding ikke g&aring;r under noen emner, kommer det an p&aring; innstillingen nedenfor
        om du vil motta meldingen eller ikke. Hvis du ikke velger noen emner her, vil
        du motta alle meldinger som sendes til listen.
        </td><td bgcolor="#cccccc">
        <mm-topics>
        </td></tr>

    <tr><td bgcolor="#cccccc">
        <strong>Vil du motta meldinger som ikke g&aring;r under noe emne?</strong>
        <p>Dette valget gjelder bare hvis du har valgt et eller flere emner ovenfor.
        Det avgj&oslash;r om du skal motta meldinger som ikke g&aring;r under noen emner.
        Velger du <em>Nei</em> vil du ikke motta dem, velger du <em>Ja</em> vil
        du motta dem.

        <p>Hvis du ikke har valgt noen emner i innstillingen ovenfor, vil du motta alle
        meldinger som sendes til listen.

        </td><td bgcolor="#cccccc">
        <mm-suppress-nonmatching-topics>Nei<br>
        <mm-receive-nonmatching-topics>Ja
      </td></tr>

    <tr><td bgcolor="#cccccc">
        <strong>Unng&aring; &aring; f&aring; epost fra listen som ogs&aring; er adressert direkte til deg?</strong><p>

        Du kan velge hva som skal skje dersom det kommer en epost til listen som i tillegg er
        adressert direkte til deg (dvs. din epostadresse st&aring;r i <tt>To:</tt> eller <tt>Cc:</tt>
        feltet). Velg <em>Ja</em> for da &aring; unng&aring; &aring; motta epost fra listen; velg <em>Nei</em>
        for likevel &aring; motta epost fra listen.

        <p>For spesielt interesserte: Dersom listen er satt opp til &aring; personifisere
        meldinger sendt til listen, og du velger &aring; motta epost fra listen, vil hver
        kopi ha et <tt>X-Mailman-Copy: yes</tt> felt i meldingshodet.
 
	</td><td bgcolor="#cccccc">
        <mm-receive-duplicates-button>Nei<br>
        <mm-dont-receive-duplicates-button>Ja<p>
        <mm-global-nodupes-button><i>Sett globalt</i>
      </td></tr>
    <tr><TD colspan="2">
        <center><MM-options-Submit-button></center>
        </td></tr>

</table>
</center>
<p>
<MM-Form-End>

<MM-Mailman-Footer>
</body>
</html>
