<html>
<head>
	<title>%(listname)s %(who)s Autentikacija</title>
	<script>function sf(){document.f.adminpw.focus();}</script>
</head>
<body bgcolor="#ffffff" onLoad="sf()">
<FORM METHOD=POST ACTION="%(path)s" name="f">
%(message)s
  <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
    <TR>
      <TD COLSPAN="2" WIDTH="100%%" BGCOLOR="#99CCFF" ALIGN="CENTER">
	<B><FONT COLOR="#000000" SIZE="+1">%(listname)s - Autentikacija %(who)sa
	    </FONT></B>
      </TD>
    </TR>
    <tr>
      <TD><div ALIGN="Right">%(who)sska lozinka liste:</div></TD>
      <TD><INPUT TYPE="password" NAME="adminpw" SIZE="30"></TD>
    </tr>
    <tr>
      <td colspan=2 align=middle><INPUT type="SUBMIT"
                                        name="admlogin"
					value="Pusti me unutra...">
      </td>
    </tr>
  </TABLE>
      <p><strong><em>Važno:</em></strong> Odavde, morate imati 
			omogućene kolačiće (cookies) u Va&scaron;em browseru, jer u suprotnom 
			administrativne promjene neće biti moguće.
			
			<p>Mailmanov administracijski interface koristi sesijske kolačiće (session cookies) 
			tako da se ne trebate ponovno autenticirati kod svake administrativne operacije. 
			Ovaj kolačić (cookie) će automatski isteći kada izađete iz browsera, ali ga možete i 
			eksplicitno uni&scaron;titi klikanjem na link <em>Izlaz</em> pod <em>Druge 
      Administracijske Aktivnosti</em> (koji ćete vidjeti onda kada se uspje&scaron;no prijavite).
</FORM>
</body>
</html>
