<html>
<head>
  <title>Autentica&ccedil;&atilde;o de %(who)s na lista %(listname)s</title>
  <script>function sf(){document.f.adminpw.focus();}</script>
</head>
<body bgcolor="#ffffff" onLoad="sf()">
<FORM METHOD=POST ACTION="%(path)s" name="f">
%(message)s
  <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
    <TR>
      <TD COLSPAN="2" WIDTH="100%%" BGCOLOR="#99CCFF" ALIGN="CENTER">
	<B><FONT COLOR="#000000" SIZE="+1">Autentica&ccedil;&atilde;o de %(who)s na lista %(listname)s
	    </FONT></B>
      </TD>
    </TR>
    <tr>
      <TD><div ALIGN="Right">Senha de %(who)s na Lista:</div></TD>
      <TD><INPUT TYPE="password" NAME="adminpw" SIZE="30"></TD>
    </tr>
    <tr>
      <td colspan=2 align=middle><INPUT type="SUBMIT"
                                        name="admlogin"
					value="Deixe-me entrar...">
      </td>
    </tr>
  </TABLE>
      <p><strong><em>Importante:</em></strong> Deste ponto em diante, 
      voc&ecirc; dever&aacute; ter os cookies ativados em seu navegador, caso 
      contr&aacute;rio nenhuma modifica&ccedil;&atilde;o administrativa ter&aacute; efeito. 

      <p>Os cookies de se&ccedil;&atilde;o s&atilde;o usados na interface administrativa
      do Mailman assim n&atilde;o ser&aacute; necess&aacute;ria uma nova autentica&ccedil;&atilde;o em 
      cada opera&ccedil;&atilde;o administrativa. Este cookie expirar&aacute; automaticamente
      quando sair do seu navegador ou automaticamente clicando no bot&atilde;o 
      <em>Sair</em> em baixo de <em>Outras Atividades Administrativas</em> 
      (que ver&aacute; logo ap&oacute;s logar na p&aacute;gina). 
</FORM>
</body>
</html>
