<html>
<head>
  <title>%(listname)s %(who)s přihl&aacute;&scaron;en&iacute;</title>
<script>function sf(){document.f.adminpw.focus();}</script>
</head>
<body bgcolor="#ffffff" onLoad="sf()">
<FORM METHOD=POST ACTION="%(path)s" name="f">
%(message)s
  <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
    <TR>
      <TD COLSPAN="2" WIDTH="100%%" BGCOLOR="#99CCFF" ALIGN="CENTER">
	<B><FONT COLOR="#000000" SIZE="+1">%(listname)s %(who)s
	    přihl&aacute;&scaron;en&iacute;</FONT></B>
      </TD>
    </TR>
    <tr>
      <TD><div ALIGN="Right">Heslo pro %(who)s:</div></TD>
      <TD><INPUT TYPE="password" NAME="adminpw" SIZE="30"></TD>
    </tr>
    <tr>
      <td colspan=2 align=middle><INPUT type="SUBMIT"
                                        name="admlogin"
					value="Pusť mě dovnitř...">
      </td>
    </tr>
  </TABLE>
      <p><strong><em>Pozor:</em></strong> Aby syst&eacute;m fungoval 
      spr&aacute;vně mus&iacute;te m&iacute;t povolen&eacute; cookie ve Va&scaron;em prohl&iacute;žeči.

      <p>Cookies se použ&iacute;vaj&iacute; na to, abyste nemuseli jeden
      každ&yacute; požadavek znovu potvrzovat heslem. Zaniknou
      pokud ukonč&iacute;te prohl&iacute;žeč a nebo když se odhl&aacute;s&iacute;te.
      Odhl&aacute;sit se můžete kliknut&iacute;m na <em>Odhl&aacute;sit</em>. 
      Tento odkaz uvid&iacute;te až po &uacute;spě&scaron;n&eacute;m přihl&aacute;&scaron;en&iacute;.
</FORM>
</body>
</html>
