<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<!-- $Revision: 6052 $ -->
<HTML>
  <HEAD>
    <TITLE><MM-List-Name> Infosida</TITLE>
  
  </HEAD>
  <BODY BGCOLOR="#ffffff">

    <P>
      <TABLE BORDER="0" CELLSPACING="4" CELLPADDING="5">
	<TR>
	  <TD COLSPAN="2" WIDTH="100%" BGCOLOR="#99CCFF" ALIGN="CENTER">
	    <B><FONT COLOR="#000000" SIZE="+1"><MM-List-Name> --
	<MM-List-Description></FONT></B>
	  </TD>
	</TR>
	<tr>
	    <td colspan="2">
	      <p>&nbsp;
	    </td>
	  </tr>
	  <tr>
	    <TD COLSPAN="1" WIDTH="100%" BGCOLOR="#FFF0D0">
	      <B><FONT COLOR="#000000">Om <MM-List-Name></FONT></B>
	    </TD>
            <TD COLSPAN="1" WIDTH="100%" BGCOLOR="#FFF0D0">
              <MM-lang-form-start><MM-displang-box> <MM-list-langs>
              <MM-form-end>
            </TD>
	  </TR>
	    <tr>
	      <td colspan="2">
		<P><MM-List-Info></P>
	  <p>F&ouml;r att se arkivet &ouml;ver e-postbrev som skickats till denna lista, g&aring; in p&aring; arkivet 	       <MM-Archive>
							<MM-List-Name>
						</MM-Archive>.
	      <MM-Restricted-List-Message>
	  </p>
	</TD>
      </TR>
      <TR>
	<TD COLSPAN="2" WIDTH="100%" BGCOLOR="#FFF0D0">
	  <B><FONT COLOR="#000000">Hur anv&auml;nds e-postlistan <MM-List-Name></FONT></B>
	</TD>
      </TR>
      <tr>
	<td colspan="2">F&ouml;r att skicka ett e-postbrev till alla p&aring; listan, skicka det till 	  <A HREF="mailto:<MM-Posting-Addr>"><MM-Posting-Addr></A>.

	  <p>Du kan anm&auml;la dig till listan eller &auml;ndra inst&auml;llningarna f&ouml;r ditt medlemskap p&aring; listan nedan:	</td>
      </tr>
      <TR>
	<TD COLSPAN="2" WIDTH="100%" BGCOLOR="#FFF0D0"><B><FONT COLOR="#000000">Anm&auml;l dig till 
							<MM-List-Name>
						</FONT></B></TD>
      </TR>
      <tr>
	<td colspan="2">
	  <P>Du kan anm&auml;la dig till <MM-List-Name> genom att fylla i n&ouml;dv&auml;ndig information nedan. 	  <MM-List-Subscription-Msg>
	  <ul>
    <MM-Subscribe-Form-Start>
	      <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2"
		WIDTH="70%">
		<TR>
		  <TD BGCOLOR="#dddddd" WIDTH="55%">Din e-postadress:</TD>
		  <TD WIDTH="33%"><MM-Subscribe-Box>
	</TD>
        <TD WIDTH="12%">&nbsp;</TD></TR>
      <tr>
        <td bgcolor="#dddddd" width="55%">Namn (valfritt):</td>
        <td width="33%"><mm-fullname-box></td>
	<TD WIDTH="12%">&nbsp;</TD></TR>
      <TR>
	<TD COLSPAN="3"><font size=-1>Du kan skriva ett l&ouml;senord i f&ouml;ljande f&auml;lt. Detta ger d&aring;lig s&auml;kerhet, men f&ouml;rhindrar att andra f&aring;r tillg&aring;ng til dina inst&auml;llningar. <b>Anv&auml;nd inte n&aring;got v&auml;rdefullt l&ouml;senord</b> - l&ouml;senordet kan n&auml;mligen bli skickat till dig i klartext via e-postbrev. </font>
										<p>Om du inte skriver n&aring;got l&ouml;senord, kommer du att automatiskt bli  tilldelad ett l&ouml;senord. Det kommer att skickas till dig s&aring; snart du har bekr&auml;ftat din anm&auml;lan. Du kan senare beg&auml;ra att f&aring; l&ouml;senordet skickat till dig eller &auml;ndrat.&nbsp;
            <MM-Reminder>
        </TD>
      </TR>  
      <TR>
	<TD BGCOLOR="#dddddd">&Ouml;nskat l&ouml;senord:</TD>
	<TD><MM-New-Password-Box></TD>
	<TD>&nbsp;</TD></TR>
      <TR> 
	<TD BGCOLOR="#dddddd">&Ouml;nskat l&ouml;senord en g&aring;ng till:</TD>
	<TD><MM-Confirm-Password></TD>
	<TD>&nbsp; </TD></TR>
      <tr>
        <TD BGCOLOR="#dddddd">V&auml;lj spr&aring;k f&ouml;r meddelanden:</TD> 
        <TD> <MM-list-langs></TD>
        <TD>&nbsp; </TD></TR>
      <mm-digest-question-start>
      <tr>
	<td BGCOLOR="#dddddd">Vill du f&aring; sammandragsversioner?</td>
									<td><MM-Undigest-Radio-Button> Nej 	    <MM-Digest-Radio-Button> Ja	</TD>
								</tr>
      <mm-digest-question-end>
      <mm-recaptcha-ui>
      <mm-captcha-ui>
      <tr>
	<td colspan="3">
	  <center><MM-Subscribe-Button></center>
    </td>
    </tr>
    </TABLE>
    <MM-Form-End>
    </ul>
    <TR>
      <TD COLSPAN="2" WIDTH="100%" BGCOLOR="#FFF0D0">
	<a name="subscribers">
        <B><FONT COLOR="#000000">Medlemmar av <MM-List-Name></FONT></B></a>
      </TD>
    </TR>
    <tr>
      <TD COLSPAN="2" WIDTH="100%">
	<MM-Roster-Form-Start>
	<MM-Roster-Option>
	    <MM-Form-End>
	  <p>
	<MM-Options-Form-Start>
	<MM-Editing-Options>
		<MM-Form-End>
      </td>
    </tr>
  </table>
<MM-Mailman-Footer>
</BODY>
</HTML>
