<!-- $Revision: 5063 $ -->
<html>
<head>
    <title><MM-Presentable-User> membership configuration for <MM-List-Name>
    </title>
</head>
<BODY BGCOLOR="#ffffff">
    <TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="5">
    <TR><TD WIDTH="100%" BGCOLOR="#99CCFF"><B>
        <FONT COLOR="#000000" SIZE=+1>
        <MM-List-Name> Postituslistan j&auml;senyyden asetukset
        <MM-Presentable-User>
	</FONT></B></TD></TR>
    </TABLE>
<p>
<table width="100%" border="0" cellspacing="5" cellpadding="5">
    <tr><td>
        <b><MM-Presentable-User></b>'s liittymistilanne,
        salasana, ja postituslistan <MM-List-Name> asetukset.
        </td><td><MM-Form-Start><mm-logout-button><MM-Form-End></td>
    </tr><tr>
        <td colspan="2">
        <MM-Case-Preserved-User>

        <MM-Disabled-Notice>

        <p><mm-results>
        </td>
    </tr>
</table>

<MM-Form-Start>
<p>
<TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="5">
    <TR><TD WIDTH="100%" BGCOLOR="#FFF0D0" colspan="2">
        <FONT COLOR="#000000">
        <B>J&auml;sentietojen <MM-List-Name> muuttaminen</B>
	</FONT></TD></TR>
    <tr><td colspan="2">Voit vaihtaa osoitettasi, jolla olet liittynyt postituslistalle,
	  kirjoittamalla uuden osoitteen alapuolella olevaan kentt&auml;&auml;n. Huomioi, ett&auml; tulet saamaan
	  vahvistuspyynn&ouml;n uuteen osoitteeseesi ja muutos pit&auml;&auml; hyv&auml;ksy&auml;, ennen kuin se suoritetaan.

        <p>Confirmations time out after about <mm-pending-days>.

        <p>Voit my&ouml;s halutessasi asettaa tai vaihtaa nimesi.
        (esim. <em>Ville Virtanen</em>).

        <p>Jos haluat tehd&auml; j&auml;senyystietojesi muutoksen kaikille listoille, joille olet liittynyt
	  <mm-host>, laita rasti
        <em>Muuta kaikkiin</em> ruutuun.

        </td></tr>
    <tr><td><center>
        <table border="0" cellspacing="2" cellpadding="2" width="80%" cols="2">
        <tr><td bgcolor="#dddddd"><div align="right">Uusi osoite:</div></td>
            <td><mm-new-address-box></td>
            </tr>
        <tr><td bgcolor="#dddddd"><div align="right">Uusi osoite uudestaan:
            </div></td> 
            <td><mm-confirm-address-box></td>
            </tr>
        </tr></table></center>
        </td>
        <td><center>
        <table border="0" cellspacing="2" cellpadding="2" width="80%" cols="2">
            <tr><td bgcolor="#dddddd"><div align="right">Nimi
            (vapaaehtoinen):</div></td>
            <td><mm-fullname-box></td>
            </tr>
        </table></center>
        </td>
        </tr>
    <tr><td colspan="2"><center><mm-change-address-button>
        <p><mm-global-change-of-address>Muuta kaikkiin listoihin</center></td>
    </tr>
</table>

<p>
<TABLE WIDTH="100%" BORDER="0" CELLSPACING="5" CELLPADDING="5">
    <TR><TD WIDTH="50%" BGCOLOR="#FFF0D0"><FONT COLOR="#000000">
        <B>Eroaminen <MM-List-Name></B></td>

	<TD WIDTH="50%" BGCOLOR="#FFF0D0"><FONT COLOR="#000000">
        <B>N&auml;yt&auml; muut  <MM-Host> liittym&auml;tiedot</B>
	</FONT></TD></TR>

    <tr><td>
        Aseta liittymistarkistusnappi??? aktiiviseksi ja paina t&auml;t&auml; nappia
	  erotaksesi t&auml;lt&auml; postituslistalta.  <strong>Varoitus:</strong>
        T&auml;m&auml; toimenpide suoritetaan v&auml;litt&ouml;m&auml;sti!
        <p>
        <center><MM-Unsubscribe-Button></center></td>
    <td>
        Voit katsoa mill&auml; <mm-host> postituslistoilla, joissa olet j&auml;senen&auml;.
        K&auml;yt&auml; t&auml;t&auml;, mik&auml;li haluat tehd&auml; samat j&auml;senyystietojen muutokset my&ouml;s muille postituslistoille,
	  joille olet liittynyt.

        <p>
        <center><MM-Other-Subscriptions-Submit></center>
	</TD></TR>
</table>

<TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="5">
    <TR><TD COLSPAN=2 WIDTH="100%" BGCOLOR="#FFF0D0"><FONT COLOR="#000000">
        <B><MM-List-Name> Salasana</B>
	</FONT></TD></TR>

    <tr valign="TOP"><td WIDTH="50%">
        <a name=reminder>
        <center>
        <h3>Oletko unohtanut salasanasi?</h3>
        </center>
        Paina t&auml;t&auml; valintaa, niin salasanasi l&auml;hetet&auml;&auml;n siihen osoitteeseen,
        jonka olet ilmoittanut listalle liittyess&auml;si.
        <p><MM-Umbrella-Notice>
        <center>
        <MM-Email-My-Pw>
        </center>
        </td>

    <td WIDTH="50%">
        <a name=changepw>
        <center>
        <h3>Vaihda salasana</h3>
        <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2" WIDTH="70%" COLS=2>
            <TR><TD BGCOLOR="#dddddd"><div align="right">Uusi
                salasana:</div></TD>
                <TD><MM-New-Pass-Box></TD>
                </TR>
            <TR>
                <TD BGCOLOR="#dddddd"><div align="right">Uusi 
                salasana uudestaan:
                </div></TD>
                <TD><MM-Confirm-Pass-Box></TD>
            </TR>
        </table>

        <MM-Change-Pass-Button>
        <p><center><mm-global-pw-changes-button>Muuta kaikkiin.
        </center>
</TABLE>

<p>
<TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="5">
    <TR><TD WIDTH="100%" BGCOLOR="#FFF0D0"><FONT COLOR="#000000">
        <B><MM-List-Name> Postituslistan j&auml;senkohtaiset m&auml;&auml;ritykset</B>
	</FONT></TD></TR>
</table>

<p>
<i><strong>Nykyiset arvot on tarkistettu.</strong></i>

<p>Huomioi, ett&auml; joissakin valinnoissa on <em>Muuta kaikkiin</em>
m&auml;&auml;ritysmahdollisuus. T&auml;m&auml;n kent&auml;n rastittaminen aiheuttaa sen, ett&auml; muutokset tehd&auml;&auml;n
kaikille <mm-host> postituslistoille, joihin olet liittynyt.  Klikkaa yll&auml;olevaa
<em>N&auml;yt&auml; muut liittym&auml;tiedot</em> -valintaa n&auml;hd&auml;ksesi, mille muille postituslistoille
olet liittynyt.
<p>
<TABLE BORDER="0" CELLSPACING="3" CELLPADDING="4" WIDTH="100%">
    <tr><TD BGCOLOR="#cccccc">
        <a name="disable">
        <strong>Viestin l&auml;hetys</strong></a><p>
        Aseta t&auml;m&auml;n arvoksi <em>P&auml;&auml;ll&auml;</em> saadaksesi t&auml;lle listalle
        l&auml;hetetyt viestit.  Aseta arvoksi <em>Pois</em> jos et
        halua saada v&auml;h&auml;&auml;n aikaan viestej&auml; itsellesi (esim. l&auml;hdet
        lomalle).  Mik&auml;li asetat viestien tulon pois p&auml;&auml;lt&auml;, &auml;l&auml; unohda
        loman j&auml;lkeen laittaa sit&auml; takaisin p&auml;&auml;lle!
        </td><td bgcolor="#cccccc">
        <mm-delivery-enable-button>P&auml;&auml;ll&auml;<br>
        <mm-delivery-disable-button>Pois<p>
        <mm-global-deliver-button><i>Muuta kaikkiin</i>
        </td></tr>

<!--Start-Digests-Delete-->
    <tr><TD BGCOLOR="#cccccc">
        <strong>Koontitilan asetus</strong><p>
        Jos asetat koontitilan p&auml;&auml;lle,
        saat postisi koostettuna yhdeksi kokoelmaviestiksi
        kerran p&auml;iv&auml;ss&auml;, etk&auml; erikseen jokaista l&auml;hetetty&auml; postia. Jos koontitila
        muutetaan pois p&auml;&auml;lt&auml;, saat viimeisen koontil&auml;hetyksen heti.
        </td><td bgcolor="#cccccc">
        <MM-Undigest-Radio-Button>Pois<br>
        <MM-Digest-Radio-Button>P&auml;&auml;ll&auml;
        </td></tr>
        
    <tr><TD BGCOLOR="#cccccc">
        <strong>MIME-tyyliset tai tavalliset tekstikoonnit</strong><p>
        S&auml;hk&ouml;postiohjelmistosi joko tukee tai ei tue MIME-tyylisi&auml; koonteja. Yleens&auml;
        MIME-tyyliset koonnit ovat parempia, mutta jos esiintyy ongelmia niiden 
        lukemisessa, valitse pelk&auml;t tekstikoonnit.
        </td><td bgcolor="#cccccc">
        <MM-Mime-Digests-Button>MIME<br>
        <MM-Plain-Digests-Button>Teksti
        </td></tr>
<!--End-Digests-Delete-->
        
    <tr><TD BGCOLOR="#cccccc">
        <strong>Haluatko saada listalle l&auml;hett&auml;m&auml;si postit itse?</strong><p>
        Tavallisesti saat kopion jokaisesta t&auml;lle listalle l&auml;hett&auml;m&auml;st&auml;si viestist&auml;.
        Jos et halua saada kopiota omista viesteist&auml;si, aseta
        arvoksi <em>Ei</em>.
        </td><td bgcolor="#cccccc">
        <mm-dont-receive-own-mail-button>Ei<br>
        <mm-receive-own-mail-button>Kyll&auml;
        </td></tr>

    <tr><TD BGCOLOR="#cccccc">
        <strong>Haluatko saada kuittauksen listalle l&auml;hett&auml;m&auml;st&auml;si viestist&auml;?</strong><p>
        </td><td bgcolor="#cccccc">
        <mm-dont-ack-posts-button>Ei<br>
        <mm-ack-posts-button>Kyll&auml;
        </td></tr>

    <tr><td bgcolor="#cccccc">
        <strong>L&auml;hetet&auml;&auml;nk&ouml; t&auml;m&auml;n listan salasanasta muistutus?</strong><p>
        Kerran kuukaudessa saat viestin, joka sis&auml;lt&auml;&auml; kaikkien niiden postituslistojen 
	  salasanat, joille olet t&auml;ll&auml; postituslistapalvelimella liittynyt.
        Voit asettaa t&auml;m&auml;n muistutuspyynn&ouml;n pois p&auml;&auml;lt&auml; tietylle listalle, valitsemalla
        <em>Ei</em>.  Jos asetat salasanamuistuksen pois p&auml;&auml;lt&auml; kaikista listoista, 
	  joille olet liittynyt, et saa ollenkaan salasanamuistusviesti&auml;.
        </td><td bgcolor="#cccccc">
        <mm-dont-get-password-reminder-button>Ei<br>
        <mm-get-password-reminder-button>Kyll&auml;<p>
        <mm-global-remind-button><i>Muuta kaikkiin</i>
        </td></tr>

    <tr><TD BGCOLOR="#cccccc">
        <strong>Piiloutuminen j&auml;senlistalta?</strong><p>
        Kun joku katselee listan j&auml;senluetteloa, normaalisti s&auml;hk&ouml;postiosoitteesi
        n&auml;kyy (in an obscured muoti to est&auml;&auml; roskapostin
        harvesters).  Mik&auml;li et halua s&auml;hk&ouml;postiosoitteesi n&auml;kyv&auml;n
        t&auml;ll&auml; j&auml;senlistalla, valitse arvoksi <em>Ei</em>.
        </td><td bgcolor="#cccccc">
        <MM-Public-Subscription-Button>Ei<br>
        <MM-Hide-Subscription-Button>Kyll&auml;
        </td></tr>

    <tr><TD BGCOLOR="#cccccc">
        <strong>Oletuskieli?</strong><p>
        </td><td bgcolor="#cccccc">
        <MM-list-langs>
        </td></tr>

    <tr><td bgcolor="#cccccc">
        <strong>Mihin aihepiireihin haluaisit
                liitty&auml;?</strong><p>
                Valitsemalla yhden tai useamman aihepiirin, voit filteroida
                postituslistasi liikennett&auml;, eli saat vain osan viesteist&auml;.
                Jos viesti t&auml;ytt&auml;&auml; valitsemasi aihepiirin kriteerit,
                saat viestin, muuten et.

                <p>Mik&auml;li viesti ei sovi mihink&auml;&auml;n valitsemaasi aihepiiriin, postin l&auml;hetys
                riippuu niist&auml; s&auml;&auml;nn&ouml;ist&auml;, joille ylemp&auml;n&auml; asetit arvot. Ellet
                valitse yht&auml;&auml;n aihepiiri&auml; tai mielenkiinnon kohdetta, saat
                kaikki postituslistalle l&auml;hetett&auml;v&auml;t viestit.
        </td><td bgcolor="#cccccc">
        <mm-topics>
        </td></tr>

    <tr><td bgcolor="#cccccc">
        <strong>Haluatko saada viestin, joka ei sovi mihink&auml;&auml;n valitsemaasi 
                aihepiiriin?</strong><p>

                T&auml;ll&auml; arvolla on merkityst&auml; ainoastaan jos liityit
                v&auml;hint&auml;&auml;n yhteen yl&auml;puolella olevaan aihepiiriin. Se luonnehtii
                oletuss&auml;&auml;nn&ouml;t sellaisen viestin l&auml;hetykselle, joka ei 
                sovi mihink&auml;&auml;n valitsemaasi kategoriaan. Mik&auml;li olet valinnut <em>Ei</em> 
		    viesti&auml; ei l&auml;hetet&auml; sinulle, ellei se sovi mihink&auml;&auml;n aihepiirin "ehtoihin".
                Valitsemalla <em>Kyll&auml;</em>
                my&ouml;s ei-sopivat viestit l&auml;hetet&auml;&auml;n sinulle.

                <p>Ellei mit&auml;&auml;n aihepiiri&auml; tai mielenkiinnon kohdetta ole valittu yl&auml;puolella,
                niin kaikki postituslistalle tulevat viestit l&auml;hetet&auml;&auml;n sinulle.
        </td><td bgcolor="#cccccc">
        <mm-suppress-nonmatching-topics>Ei<br>
        <mm-receive-nonmatching-topics>Kyll&auml;
        </td></tr>

    <tr><TD colspan="2">
        <center><MM-options-Submit-button></center>
        </td></tr>

</table>
</center>
<p>
<MM-Form-End>

<MM-Mailman-Footer>
</body>
</html>
