Tento text m&ocirc;že obsahovať <a
href="https://docs.python.org/2/library/stdtypes.html#string-formatting-operations"
">form&aacute;tovacie
pr&iacute;kazy jazyka Python</a>, ktor&eacute; sa nahradia pr&iacute;slu&scaron;n&yacute;mi
hodnotami pri vytv&aacute;ran&iacute; str&aacute;nky.  Nejd&ocirc;ležitej&scaron;ie premenn&eacute; s&uacute;:

<ul>
    <li><b>real_name</b> - `Pekn&eacute;' meno konferencie, 
    bežne n&aacute;zov, ktor&yacute; m&aacute; zachovan&uacute; veľkosť p&iacute;smen (definovan&eacute;
    v nastaveniach).

    <li><b>list_name</b> - Meno konferencie, ako sa použ&iacute;va v URL
    kde z&aacute;lež&iacute; na velikosti p&iacute;smen (v&scaron;etky p&iacute;smen&aacute; s&uacute; preveden&eacute; na mal&eacute;).

    <li><b>host_name</b> - Meno serveru (FQDN), na ktorom bež&iacute;
    konferencia.
    
    <li><b>web_page_url</b> - Z&aacute;kladn&eacute; URL pre Mailman.
    Ak je použit&eacute; napr. v tomto pr&iacute;kaze:
    <em>listinfo/%(list_name)s</em>
    ukazuje na str&aacute;nku s inform&aacute;ciami o konferencii.

    <li><b>description</b> - Kr&aacute;tky, charakteristick&yacute;
    popis konferencie (definovan&yacute; v nastaveniach).

    <li><b>info</b> - Kompletn&yacute;, dlh&yacute; popis konferencie.

    <li><b>cgiext</b> - pr&iacute;pona prid&aacute;van&aacute; ku CGI skriptom.

</ul>
