<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<HTML>
  <HEAD>
    <TITLE>Pagina di informazioni della lista <MM-List-Name></TITLE>
  
  </HEAD>
  <BODY BGCOLOR="#ffffff">

    <P>
      <TABLE BORDER="0" CELLSPACING="4" CELLPADDING="5">
	<TR>
	  <TD COLSPAN="2" WIDTH="100%" BGCOLOR="#99CCFF" ALIGN="CENTER">
	    <B><FONT COLOR="#000000" SIZE="+1"><MM-List-Name> --
	<MM-List-Description></FONT></B>
	  </TD>
	</TR>
	<tr>
	    <td colspan="2">
	      <p>&nbsp;
	    </td>
	  </tr>
	  <tr>
	    <TD COLSPAN="1" WIDTH="100%" BGCOLOR="#FFF0D0">
	      <B><FONT COLOR="#000000">Dettagli su <MM-List-Name></FONT></B>
	    </TD>
	    <TD COLSPAN="1" WIDTH="100%" BGCOLOR="#FFF0D0">
		<MM-lang-form-start><MM-displang-box>
		<MM-list-langs>
		<MM-form-end>
	    </TD>
	  </TR>
	    <tr>
	      <td colspan="2">
		<P><MM-List-Info></P>
	  <p> Per consultare la raccolta dei messaggi precedentemente 
          inviati alla lista, visita gli <MM-Archive>Archivi della lista <MM-List-Name></MM-Archive>.
	      <MM-Restricted-List-Message>
	  </p>
	</TD>
      </TR>
      <TR>
	<TD COLSPAN="2" WIDTH="100%" BGCOLOR="#FFF0D0">
	  <B><FONT COLOR="#000000">Uso di <MM-List-Name></FONT></B>
	</TD>
      </TR>
      <tr>
	<td colspan="2">
	  Per inviare un messaggio a tutti gli iscritti della lista, scrivi
      all'indirizzo
	  <A HREF="mailto:<MM-Posting-Addr>"><MM-Posting-Addr></A>.

	  <p>Puoi iscriverti alla lista, o cambiare la tua iscrizione 
         corrente, nella sezione sottostante.
	    
      </td>
      </tr>
      <TR>
	<TD COLSPAN="2" WIDTH="100%" BGCOLOR="#FFF0D0">
	  <B><FONT COLOR="#000000">Iscrizione a <MM-List-Name></FONT></B>
	</TD>
      </TR>
      <tr>
	<td colspan="2">
	  <P>
	    Iscriviti a <MM-List-Name> completando il seguente modulo.
	  <MM-List-Subscription-Msg>
	  <ul>
    <MM-Subscribe-Form-Start>
	      <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2"
		WIDTH="70%">
		<TR>
		  <TD BGCOLOR="#dddddd" WIDTH="55%">Il tuo indirizzo email:</TD>
		  <TD WIDTH="33%"><MM-Subscribe-Box></TD>
		  <TD WIDTH="12%">&nbsp;</TD>
	  	</TR>
		<tr>
		<td bgcolor="#dddddd" width="55%">Il tuo nome (opzionale):</td>
		  <td width="33%"><mm-fullname-box></td>
		  <TD WIDTH="12%">&nbsp;</TD>
	 	</TR>
      		<TR>
		<TD COLSPAN="3"><FONT SIZE=-1>Devi inserire una password 
		  personale.  Questo ti garantir&agrave; solo una minima 
		  sicurezza, ma impedir&agrave; ad altri di fare scherzi con 
		  la tua iscrizione.
	    	  <b>Non usare una password importante</b> visto che ti 
        	  verr&agrave; periodicamente ricordata via email con testo 
		  non cifrato.
		  <br><br>Se non vuoi scegliere, lascia in bianco la password ed 
		  una verr&agrave; automaticamente generata per te e spedita 
		  al tuo indirizzo quando avrai confermato l'iscrizione.
		  Puoi chiedere in ogni momento che ti venga rispedita
		  la mail contenente la password, semplicemente
		  premendo un pulsante nel pannello delle tue opzioni
		  personali.
	    	  <MM-Reminder>
		  </font>
		</TD>
      		</TR>  
      		<TR>
		  <TD BGCOLOR="#dddddd">Scegli una password:</TD>
		  <TD><MM-New-Password-Box></TD>
		  <TD>&nbsp;</TD>
	  	</TR>
      <TR> 
	<TD BGCOLOR="#dddddd">Conferma la password:</TD>
	<TD><MM-Confirm-Password></TD>
	<TD>&nbsp; </TD></TR>
      <tr>
        <TD BGCOLOR="#dddddd">
	      In quale lingua preferisci vedere i tuoi messaggi?
	</TD> 
	<TD> <MM-list-langs></TD>
	<TD>&nbsp; </TD></TR>
	<mm-digest-question-start>
	<tr>
	<td>Vuoi ricevere i messaggi della lista raggruppati in un 
        digest giornaliero?
	
	  </td>
	<td><MM-Undigest-Radio-Button> No
	<MM-Digest-Radio-Button> S&igrave;
	</TD>
	</tr>
	<mm-digest-question-end>
	<mm-recaptcha-ui>
	<mm-captcha-ui>
      <tr>
	<td colspan="3">
	  <center><MM-Subscribe-Button></center>
    </td>
    </tr>
    </TABLE>
    <MM-Form-End>
    </ul>
    <TR>
      <TD COLSPAN="2" WIDTH="100%" BGCOLOR="#FFF0D0">
	<a name="subscribers">
        <B><FONT COLOR="#000000">Iscritti a <MM-List-Name></FONT></B></a>
      </TD>
    </TR>
    <tr>
      <TD COLSPAN="2" WIDTH="100%">
	<MM-Roster-Form-Start>
	<MM-Roster-Option>
	<MM-Form-End>
	<p>
	<MM-Options-Form-Start>
	<MM-Editing-Options>
	<MM-Form-End>
      </td>
    </tr>
  </table>
<MM-Mailman-Footer>
</BODY>
</HTML>
