<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<!-- $Revision: 2.4 $ -->
<HTML>
  <HEAD>
    <TITLE><MM-List-Name>Trang thông tin</TITLE>
  
  </HEAD>
  <BODY BGCOLOR="#ffffff">

    <P>
      <TABLE BORDER="0" CELLSPACING="4" CELLPADDING="5">
	<TR>
	  <TD COLSPAN="2" WIDTH="100%" BGCOLOR="#99CCFF" ALIGN="CENTER">
	    <B><FONT COLOR="#000000" SIZE="+1"><MM-List-Name> --
	<MM-List-Description></FONT></B>
	  </TD>
	</TR>
	<tr>
	    <td colspan="2">
	      <p>&nbsp;
	    </td>
	  </tr>
	  <tr>
	    <TD COLSPAN="1" WIDTH="100%" BGCOLOR="#FFF0D0">
	      <B><FONT COLOR="#000000">Giới thiệu về <MM-List-Name></FONT></B>
	    </TD>
            <TD COLSPAN="1" WIDTH="100%" BGCOLOR="#FFF0D0">
              <MM-lang-form-start><MM-displang-box> <MM-list-langs>
              <MM-form-end>
            </TD>
	  </TR>
	    <tr>
	      <td colspan="2">
		<P><MM-List-Info></P>
	  <p>Để xem các bài thư được gởi cho hộp thư này trước này, hãy thăm  <MM-Archive>Kho<MM-List-Name></MM-Archive>.
	      <MM-Restricted-List-Message>
	  </p>
	</TD>
      </TR>
      <TR>
	<TD COLSPAN="2" WIDTH="100%" BGCOLOR="#FFF0D0">
	  <B><FONT COLOR="#000000">Cách sử dụng <MM-List-Name></FONT></B>
	</TD>
      </TR>
      <tr>
	<td colspan="2">
	Để gởi thư cho mọi thành viên hộp thư chung, hãy gởi thư cho địa chỉ thư
	  <A HREF="mailto:<MM-Posting-Addr>"><MM-Posting-Addr></A>.

	  <p>Bạn có thể đăng ký với hộp thư chung, hoặc thay đổi sự đăng ký đã có, trong các phần bên dưới.
	</td>
      </tr>
      <TR>
	<TD COLSPAN="2" WIDTH="100%" BGCOLOR="#FFF0D0">
	  <B><FONT COLOR="#000000">Đăng ký với <MM-List-Name></FONT></B>
	</TD>
      </TR>
      <tr>
	<td colspan="2">
	  <P>
	    Hãy đăng ký với hộp thư chung <MM-List-Name> bằng cách điền vào đơn theo đây.
	  <MM-List-Subscription-Msg>
	  <ul>
    <MM-Subscribe-Form-Start>
	      <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2"
		WIDTH="70%">
		<TR>
		  <TD BGCOLOR="#dddddd" WIDTH="55%">Địa chỉ thư của bạn:</TD>
		  <TD WIDTH="33%"><MM-Subscribe-Box>
	</TD>
	<TD WIDTH="12%">&nbsp;</TD></TR>
      <tr>
        <td bgcolor="#dddddd" width="55%">Họ tên bạn (tùy chọn):</td>
        <td width="33%"><mm-fullname-box></td>
	<TD WIDTH="12%">&nbsp;</TD></TR>
      <TR>
	<TD COLSPAN="3"><FONT SIZE=-1>Bạn có thể nhập một mật khẩu riêng bên dưới. Nó cung cấp chỉ ít bảo mật, nhưng mà nên ngăn cản người khác sửa đổi sự đăng ký của bạn.  <b>Đừng nhập mật khẩu quan trọng nào</b> vì thỉng thoảng nó sẽ được gởi cho bạn trong thư không mật mã.

            <br><br>Nếu bạn chọn không nhập mật khẩu, phần mềm này sẽ tạo ra tự động mật khẩu cho bạn, và nó sẽ được gởi cho bạn một khi bạn đã xác nhận đăng ký. Hơn nữa, bạn có thể yêu cầu nhận thư chứa mật khẩu mình, vào lúc nào bạn sửa đổi các tùy chọn cá nhân.
	    <MM-Reminder>
	    </font>
	</TD>
      </TR>  
      <TR>
	<TD BGCOLOR="#dddddd">Chọn mật khẩu :</TD>
	<TD><MM-New-Password-Box></TD>
	<TD>&nbsp;</TD></TR>
      <TR> 
	<TD BGCOLOR="#dddddd">Nhập lại mật khẩu để xác nhân:</TD>
	<TD><MM-Confirm-Password></TD>
	<TD>&nbsp; </TD></TR>
      <tr>
        <TD BGCOLOR="#dddddd">Bạn có muốn hiển thị thư bằng ngôn ngữ nào?</TD> 
        <TD> <MM-list-langs></TD>
        <TD>&nbsp; </TD></TR>
      <mm-digest-question-start>
      <tr>
	<td>Bạn có muốn nhận bó thư không?
	  </td>
	<td><MM-Undigest-Radio-Button> Không
	    <MM-Digest-Radio-Button>  Có
	</TD>
      </tr>
      <mm-digest-question-end>
      <mm-recaptcha-ui>
      <mm-captcha-ui>
      <tr>
	<td colspan="3">
	  <center><MM-Subscribe-Button></center>
    </td>
    </tr>
    </TABLE>
    <MM-Form-End>
    </ul>
    <TR>
      <TD COLSPAN="2" WIDTH="100%" BGCOLOR="#FFF0D0">
	<a name="subscribers">
        <B><FONT COLOR="#000000"><MM-List-Name> Thành viên</FONT></B></a>
      </TD>
    </TR>
    <tr>
      <TD COLSPAN="2" WIDTH="100%">
	<MM-Roster-Form-Start>
	<MM-Roster-Option>
	    <MM-Form-End>
	  <p>
	<MM-Options-Form-Start>
	<MM-Editing-Options>
		<MM-Form-End>
      </td>
    </tr>
  </table>
<MM-Mailman-Footer>
</BODY>
</HTML>
