<html>
<head>
    <title>Autentificaci&oacute;n para los archivos privados de %(realname)s</title>
    <script>function sf(){document.f.username.focus();}</script>
</head>
body bgcolor="#ffffff" onLoad="sf()">
<FORM METHOD=POST ACTION="%(action)s/" name="f">
%(message)s
  <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
    <TR>
      <TD COLSPAN="2" WIDTH="100%%" BGCOLOR="#99CCFF" ALIGN="CENTER">
	<B><FONT COLOR="#000000" SIZE="+1">Autentificaci&oacute;n d'archivos privaos de %(realname)s</FONT></B>
      </TD>
    </TR>
    <tr>
        <TD><div ALIGN="Right">Direici&oacute;n::</div></TD>
        <TD><INPUT TYPE="text" NAME="username" SIZE="30"></TD>
    </tr>
    <tr>
      <TD><div ALIGN="Right">Contrase&ntilde;a:</div></TD>
      <TD><INPUT TYPE="password" NAME="password" SIZE="30"></TD>
    </tr>
    <tr>
      <td colspan=2 align="middle"><INPUT type="SUBMIT"
                                          name="submit"
					  value="Con permisu...">
      </td>
    </tr>
  </TABLE>
      <p><strong><em>Importante:</em></strong> A partir d'agora, tienes de tener habilitaes les cookies nel restolador web, de nun ser asina, los cambeos nun fadr&aacute;n efeutu.
      <p>Les sesiones basaes en cookies &uacute;sense na interface alministrativa de Mailman, de mou que nun necesites identificate de contino con cada operaci&oacute;n alministrativa que faigas. La cookie caducar&aacute; autom&aacute;ticamente cuando salgas del restolador, o puedes facela caducar seleicionando la opci&oacute;n <em>Salida</em> baxo la seici&oacute;n titulada  <em> Otres Actividaes Alministratives</em> (que ver&aacute;s una vegada que consigas entrar  con &eacute;xitu).
      <p>
    <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
    <TR>
      <TD COLSPAN="2" WIDTH="100%%" BGCOLOR="#99CCFF" ALIGN="CENTER">
	<B><FONT COLOR="#000000" SIZE="+1">Password Reminder</FONT></B>
      </TD>
    </TR>
    <tr>
      <td>If you don't remember your password, enter your email address
          above and click the <em>Remind</em> button and your
          password will be emailed to you.</td>
    </tr>
    <tr>
      <td><center><INPUT name="login-remind" type="SUBMIT" value="Remind" ></center></td>
    </tr>
  </TABLE>
</FORM>
</body>
</html>
