  </ul>
  <p>
   <a name="end"><b>Data ostatniej wiadomo&#347;ci:</b></a> <i>%(lastdate)s</i><br>
   <b>Data archiwizacji:</b> <i>%(archivedate)s</i>
  <p>
  <ul>
   <li><b>Wiadomo&#347;ci posortowane wed&#322;ug:</b>
    %(thread_ref)s
    %(subject_ref)s
    %(author_ref)s
    %(date_ref)s
   <li><b><a href="%(listinfo)s">Wi&#281;cej informacji o li&#347;cie...</a></b></li>
  </ul>
  <p><hr><i>Archiwum zosta&#322;o wygenerowane przez program Pipermail %(version)s.</i>
 </body>
</html>
