<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<!-- updated from Revision 1.1  -->
<HTML>
  <HEAD>
    <TITLE><MM-List-Name> Infoseite</TITLE>

  </HEAD>
  <BODY BGCOLOR="#ffffff">

    <P>
      <TABLE BORDER="0" CELLSPACING="4" CELLPADDING="5">
	<TR>
	  <TD COLSPAN="2" WIDTH="100%" BGCOLOR="#99CCFF" ALIGN="CENTER">
	    <B><FONT COLOR="#000000" SIZE="+1"><MM-List-Name> --
	<MM-List-Description></FONT></B>
	  </TD>
	</TR>
	<tr>
	    <td colspan="2">
	      <p>&nbsp;
	    </td>
	  </tr>
	  <tr>
	    <TD COLSPAN="1" WIDTH="100%" BGCOLOR="#FFF0D0">
	      <B><FONT COLOR="#000000">&Uuml;ber <MM-List-Name></FONT></B>
	    </TD>
            <TD COLSPAN="1" WIDTH="100%" BGCOLOR="#FFF0D0">
              <MM-lang-form-start><MM-displang-box> <MM-list-langs>
              <MM-form-end>
            </TD>
	  </TR>
	    <tr>
	      <td colspan="2">
		<P><MM-List-Info></P>
	  <p> Um fr&uuml;here Nachrichten an diese Liste zu sehen,
besuchen Sie bitte das <MM-Archive>Archiv der
Liste <MM-List-Name></MM-Archive>. <MM-Restricted-List-Message>
	  </p>
	</TD>
      </TR>
      <TR>
	<TD COLSPAN="2" WIDTH="100%" BGCOLOR="#FFF0D0">
	  <B><FONT COLOR="#000000">Benutzung von <MM-List-Name></FONT></B>
	</TD>
      </TR>
      <tr>
	<td colspan="2">
	  Um eine Nachricht an alle Listenmitglieder zu senden, schicken Sie
          diese an
	  <A HREF="mailto:<MM-Posting-Addr>"><MM-Posting-Addr></A>.

	  <p>Sie k&ouml;nnen im folgenden Abschnitt diese Liste abonnieren
             oder ein bestehendes Abonnement &auml;ndern.
	</td>
      </tr>
      <TR>
	<TD COLSPAN="2" WIDTH="100%" BGCOLOR="#FFF0D0">
	  <B><FONT COLOR="#000000">Abonnieren von <MM-List-Name></FONT></B>
	</TD>
      </TR>
      <tr>
	<td colspan="2">
	  <P>
	    Abonnieren Sie <MM-List-Name>, indem Sie das folgende Formular
 ausf&uuml;llen:
	  <MM-List-Subscription-Msg>
	  <ul>
    <MM-Subscribe-Form-Start>
	      <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2"
		WIDTH="70%">
		<TR>
		  <TD BGCOLOR="#dddddd" WIDTH="55%">Ihre E-Mail-Adresse:</TD>
		  <TD WIDTH="33%"><MM-Subscribe-Box>
	</TD>
	<TD WIDTH="12%">&nbsp;</TD></TR>
      <tr>
        <td bgcolor="#dddddd" width="55%">Ihr Name (optional):</td>
        <td width="33%"><mm-fullname-box></td>
	<TD WIDTH="12%">&nbsp;</TD></TR>
      <TR>
	<TD COLSPAN="3"><FONT SIZE=-1>Sie k&ouml;nnen weiter unten ein Passwort
	    eingeben. Dieses Passwort bietet nur eine geringe Sicherheit,
            sollte aber verhindern, dass andere Ihr Abonnement
            manipulieren. <b>Verwenden Sie kein wertvolles Passwort</b>,
            da es ab und zu im Klartext an Sie geschickt wird!

            <br><br>Wenn Sie kein Passwort eingeben, wird f&uuml;r Sie ein
            Zufallspasswort generiert und Ihnen zugeschickt, sobald Sie Ihr
            Abonnement best&auml;tigt haben. Sie k&ouml;nnen sich Ihr Passwort
            jederzeit per E-Mail zuschicken lassen, wenn Sie weiter unten
            die Seite zum &Auml;ndern Ihrer pers&ouml;nlichen Einstellungen aufrufen.
	    <MM-Reminder> 	</font></TD>
      </TR>
      <TR>
	<TD BGCOLOR="#dddddd">W&auml;hlen Sie ein Passwort:</TD>
	<TD><MM-New-Password-Box></TD>
	<TD>&nbsp;</TD></TR>
      <TR>
	<TD BGCOLOR="#dddddd">Erneute Eingabe zur Best&auml;tigung:</TD>
	<TD><MM-Confirm-Password></TD>
	<TD>&nbsp; </TD></TR>
      <tr>
        <TD BGCOLOR="#dddddd">Welche Sprache bevorzugen Sie zur
 Benutzerf&uuml;hrung?</TD>
        <TD> <MM-list-langs></TD>
        <TD>&nbsp; </TD></TR>
      <mm-digest-question-start>
      <tr>
	<td>M&ouml;chten Sie die Listenmails geb&uuml;ndelt in Form einer t&auml;glichen
            Zusammenfassung (digest) erhalten?
	  </td>
	<td><MM-Undigest-Radio-Button>Nein
	    <MM-Digest-Radio-Button>Ja
	</TD>
      </tr>
      <mm-digest-question-end>
      <mm-recaptcha-ui>
      <mm-captcha-ui>
      <tr>
	<td colspan="3">
	  <center><MM-Subscribe-Button></center>
    </td>
    </tr>
    </TABLE>
    <MM-Form-End>
    </ul>
    <TR>
      <TD COLSPAN="2" WIDTH="100%" BGCOLOR="#FFF0D0">
	<a name="subscribers">
        <B><FONT COLOR="#000000">Abonnenten der Liste <MM-List-Name></FONT></B></a>
      </TD>
    </TR>
    <tr>
      <TD COLSPAN="2" WIDTH="100%">
	<MM-Roster-Form-Start>
	<MM-Roster-Option>
	    <MM-Form-End>
	</TD>
	</TR>
    <TR>
      <TD COLSPAN="2" WIDTH="100%" BGCOLOR="#FFF0D0">
        <B><FONT COLOR="#000000">Austragen / &Auml;ndern einer Mailadresse</FONT></B>
      </TD>
    </TR>
      <TD COLSPAN="2" WIDTH="100%">
	<MM-Options-Form-Start>
<br>
	<MM-Editing-Options>
<br>
		<MM-Form-End>
      </td>
    </tr>
  </table>
<MM-Mailman-Footer>
</BODY>
</HTML>
