Esta p&aacute;xina cont&eacute;n un subconxunto dos env&iacute;os &aacute; 
rolda de distribuci&oacute;n <em>%(listname)s</em> que requiren 
da s&uacute;a conformidade. Actualmente amosa %(description)s

<p> Para cada solicitude administrativa, seleccione a acci&oacute;n que se debe tomar
ao premer <b>mandar todos os datos</b> despois de rematar.
Pode
achar m&aacute;is informaci&oacute;n <a href="%(detailsurl)s">aqu&iacute;</a>.

<p>Tam&eacute;n pode <a href="%(summaryurl)s">ver un resumo</a> de todas as solicitudes
pendentes.
