<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<!-- $Revision: 7442 $ -->
<HTML>
  <HEAD>
    <TITLE>P&aacute;gina de Informaci&oacute;n de <MM-List-Name></TITLE>
  
  </HEAD>
  <BODY BGCOLOR="#ffffff">

    <P>
      <TABLE BORDER="0" CELLSPACING="4" CELLPADDING="5">
	<TR>
	  <TD COLSPAN="2" WIDTH="100%" BGCOLOR="#99CCFF" ALIGN="CENTER">
	    <B><FONT COLOR="#000000" SIZE="+1"><MM-List-Name> --
	<MM-List-Description></FONT></B>
	  </TD>
	</TR>
	<tr>
	    <td colspan="2">
	      <p>&nbsp;
	    </td>
	  </tr>
	  <tr>
	    <TD COLSPAN="1" WIDTH="100%" BGCOLOR="#FFF0D0">
	      <B><FONT COLOR="#000000">Sobre <MM-List-Name></FONT></B>
	    </TD>
            <TD COLSPAN="1" WIDTH="100%" BGCOLOR="#FFF0D0">
              <MM-lang-form-start><MM-displang-box> <MM-list-langs>
              <MM-form-end>
            </TD>
	  </TR>
	    <tr>
	      <td colspan="2">
		<P><MM-List-Info></P>
	  <p>  Para ver env&iacute;os anteriores a la lista,
	       puede visitar los archivos de <MM-Archive><MM-List-Name>
		  </MM-Archive>.
	      <MM-Restricted-List-Message>
	  </p>
	</TD>
      </TR>
      <TR>
	<TD COLSPAN="2" WIDTH="100%" BGCOLOR="#FFF0D0">
	  <B><FONT COLOR="#000000">Como usar la lista  <MM-List-Name></FONT></B>
	</TD>
      </TR>
      <tr>
	<td colspan="2">
	  Para enviar un mensaje a todos los miembros de la lista,
	  env&iacute;elo a la direcci&oacute;n
	  <A HREF="mailto:<MM-Posting-Addr>"><MM-Posting-Addr></A>.

	  <p>Puede usted subscribirse a la lista, o cambiar su
	    subscripci&oacute;n, en las siguientes secciones.
	</td>
      </tr>
      <TR>
	<TD COLSPAN="2" WIDTH="100%" BGCOLOR="#FFF0D0">
	  <B><FONT COLOR="#000000">Subscribirse a <MM-List-Name></FONT></B>
	</TD>
      </TR>
      <tr>
	<td colspan="2">
	  <P>
	    Suscr&iacute;base a <MM-List-Name> rellenando los datos del
	    siguiente formulario
	  <MM-List-Subscription-Msg>
	  <ul>
    <MM-Subscribe-Form-Start>
	      <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2"
		WIDTH="70%">
		<TR>
		  <TD BGCOLOR="#dddddd" WIDTH="55%">Direcci&oacute;n de                                           correo electr&oacute;nico:</TD>
		  <TD WIDTH="33%"><MM-Subscribe-Box>
	          </TD>
	          <TD WIDTH="12%">&nbsp;</TD></TR>
                 <tr>
                  <td bgcolor="#dddddd" width="55%">Su nombre (opcional):</td>
                  <td width="33%"><mm-fullname-box></td>
                 <TD WIDTH="12%">&nbsp;</TD></TR>
                <TR>
	          <TD COLSPAN="3"><FONT SIZE=-1> Debe introducir una clave de
		protecci&oacute;n. Esto le da un bajo nivel de seguridad,
		pero deber&iacute;a evitar que otros enreden con su
		subscripci&oacute;n.  <b>No utilice claves valiosas</b> porque
		puede que se le mande alguna vez sin cifrar por correo
		electr&oacute;nico.

		<br><br>Si decide no escribir ninguna clave, se le generar&aacute;
		una autom&aacute;ticamente y se le enviar&aacute; una vez que
		confirme su subscripci&oacute;n. Siempre podr&aacute; pedir
		que se le env&iacute;e por correo su clave cuando edite sus
		opciones personales
	        <MM-Reminder>
	    </font>
                  </TD>
                </TR>  
      <TR>
	<TD BGCOLOR="#dddddd">Elija una clave:</TD>
	<TD><MM-New-Password-Box></TD>
	<TD>&nbsp;</TD></TR>
      <TR> 
	<TD BGCOLOR="#dddddd">Confirme la clave:</TD>
	<TD><MM-Confirm-Password></TD>
	<TD>&nbsp; </TD></TR>
      <tr>
	<TD BGCOLOR="#dddddd">&iquest;En qu&eacute; idioma desea visualizar sus mensajes?</TD> 
	<TD> <MM-list-langs></TD>
	<TD>&nbsp; </TD></TR>
      <mm-digest-question-start>
      <tr>
	<td>&iquest;Desea recibir los mensaje de cada d&iacute;a reunidos
            en un &uacute;nico mensaje (digest)?
	  </td>
	<td><MM-Undigest-Radio-Button> No
	    <MM-Digest-Radio-Button>  S&iacute;
	</TD>
      </tr>
      <mm-digest-question-end>
      <mm-recaptcha-ui>
      <mm-captcha-ui>
      <tr>
	<td colspan="3">
	  <center><MM-Subscribe-Button></center>
    </td>
    </tr>
    </TABLE>
    <MM-Form-End>
    </ul>
    <TR>
      <TD COLSPAN="2" WIDTH="100%" BGCOLOR="#FFF0D0">
	<a name="subscribers">
        <B><FONT COLOR="#000000">Suscriptores de <MM-List-Name></FONT></B></a>
      </TD>
    </TR>
    <tr>
      <TD COLSPAN="2" WIDTH="100%">
	<MM-Roster-Form-Start>
	<MM-Roster-Option>
	    <MM-Form-End>
	  <p>
	<MM-Options-Form-Start>
	<MM-Editing-Options>
		<MM-Form-End>
      </td>
    </tr>
  </table>
<MM-Mailman-Footer>
</BODY>
</HTML>
