<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<HTML>
  <HEAD>
     <title>L'arxiu de %(archive)s de la llista %(listname)s per %(archtype)s</title>
     <META NAME="robots" CONTENT="noindex,follow">
     %(encoding)s
  </HEAD>
  <BODY BGCOLOR="#ffffff">
      <a name="start"></A>
      <h1>Arxius de %(archive)s per %(archtype)s</h1>
      <ul>
         <li> <b>Missatges ordenats per:</b> 
                %(thread_ref)s 
                %(subject_ref)s 
                %(author_ref)s 
                %(date_ref)s 

	     <li><b><a href="%(listinfo)s">M&eacute;s informaci&oacute; sobre aquesta llista... 
                 </a></b></li>    
      </ul>
      <p><b>Inici:</b> <i>%(firstdate)s</i><br>
         <b>Final:</b> <i>%(lastdate)s</i><br>
         <b>Missatges:</b> %(size)s<p>
     <ul>
