<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<HTML>
  <HEAD>
     <title>Arquivos de %(listname)s</title>
     <META NAME="robots" CONTENT="noindex,follow">
  </HEAD>
  <BODY BGCOLOR="#ffffff">
     <h1>Arquivos de %(listname)s </h1>
     <p>
      Ainda n&atilde;o foram enviadas mensagens para esta lista, por isso
      os arquivos est&atilde;o vazios. Pode ter mais <a href="%(listinfo)s">
	informa&ccedil;&otilde;es sobre 
      esta lista</a>.
     </p>
  </BODY>
  </HTML>
