Den h&auml;r texten kan inneh&aring;lla formateringskoder som byts ut mot v&auml;rden fr&aring;n listans upps&auml;ttning. F&ouml;r detaljer, se <a href="https://docs.python.org/2/library/stdtypes.html#string-formatting-operations">Pythons formateringsregler (engelska)</a>. Giltiga koder &auml;r:
<ul>
    <li><b>real_name</b> - Listans formaterade namn, vanligtvis listnamnet med stor initial eller stora bokst&auml;ver rakt igenom.
    <li><b>list_name</b> - Listens namn, s&aring;som det anv&auml;nds i URL:er, d&auml;r det har betydelse om namnet stavas med stora eller sm&aring; bokst&auml;ver.
    <li><b>host_name</b> - Internetadressen (fully qualified domain name) till maskinen som listservern k&ouml;rs p&aring;.
    <li><b>web_page_url</b> - Bas-URL f&ouml;r Mailman. Denna kan l&auml;ggas tillsammans med till exempel  <em>listinfo/%(list_name)s</em> f&ouml;r att skapa URL:en till en listas informationssida.
    <li><b>description</b> - En kort beskrivning av listan.
    <li><b>info</b> - Fullst&auml;ndig beskrivning av listan.
    <li><b>cgiext</b> - Till&auml;gg som l&auml;ggs till CGI-skript.</ul>
