<html>
<head>
    <link rel="SHORTCUT ICON" href="<mm-favicon>">
    <title><MM-Presentable-User> תצורת מנוי עבור <MM-List-Name>
    </title>
</head>
<BODY BGCOLOR="#ffffff" dir="rtl">
    <TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="5">
    <TR><TD WIDTH="100%" BGCOLOR="#99CCFF"><B>
        <FONT COLOR="#000000" SIZE=+1>
        <MM-List-Name> תצורת מנוי רשימת דיוור עבור
        <MM-Presentable-User>
        </FONT></B></TD></TR>
    </TABLE>
<p>
<table width="100%" border="0" cellspacing="5" cellpadding="5">
    <tr><td>
        סטטוס המנוי, הסיסמה וההגדרות של 
<b><MM-Presentable-User></b>
         ברשימת הדיוור <MM-List-Name>.
        </td><td><MM-Form-Start><mm-logout-button><MM-Form-End></td>
    </tr><tr>
        <td colspan="2">
        <MM-Case-Preserved-User>

        <MM-Disabled-Notice>

        <p><mm-results>
        </td>
    </tr>
</table>

<MM-Form-Start>
<p>
<TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="5">
    <TR><TD WIDTH="100%" BGCOLOR="#FFF0D0" colspan="2">
        <FONT COLOR="#000000">
        <B>שינוי מידע אודות המנוי שלך ב- <MM-List-Name></B>
        </FONT></TD></TR>
		<tr><td colspan="2">
		ניתן לשנות את הכתובת בה אתה מנוי לרשימת הדיוור   
		על ידי הקלדת הכתובת החדשה בשדות למטה.  שים לב:
		תישלח אליך הודעת אישור, ואליך לאשר את השינוי לפני
		שהוא תתבצע.


        <p>פג תוקפם של אישורים לאחר בערך <mm-pending-days> ימים.

        <p>מותר לך לקבוע או לשנות את השם האמיתי שלך (לא חובה)
        (למשל <em>יוסי כהן</em>).

        <p>אם ברצונך לבצע שינוי מנוי לגבי כל הרשימות בהן
		אתה מנוי ב-<mm-host>, סמן את תיבת הסימון <em>שינוי גלובלי</em>.

        </td></tr>
    <tr><td><center>
        <table border="0" cellspacing="2" cellpadding="2" width="80%" cols="2">
        <tr><td bgcolor="#dddddd"><div align="right">כתובת חדשה:</div></td>
            <td><mm-new-address-box></td>
            </tr>
        <tr><td bgcolor="#dddddd"><div align="right">ושוב, לאישור:</div></td> 
            <td><mm-confirm-address-box></td>
            </tr>
        </tr></table></center>
        </td>
        <td><center>
        <table border="0" cellspacing="2" cellpadding="2" width="80%" cols="2">
            <tr><td bgcolor="#dddddd"><div align="right">שמך
            (לא חובה):</div></td>
            <td><mm-fullname-box></td>
            </tr>
        </table></center>
        </td>
        </tr>
    <tr><td colspan="2"><center><mm-change-address-button>
        <p><mm-global-change-of-address>שינוי גלובלי</center></td>
    </tr>
</table>

<p>
<TABLE WIDTH="100%" BORDER="0" CELLSPACING="5" CELLPADDING="5">
    <TR><TD WIDTH="50%" BGCOLOR="#FFF0D0"><FONT COLOR="#000000">
        <B>עוזב את <MM-List-Name></B></td>

        <TD WIDTH="50%" BGCOLOR="#FFF0D0"><FONT COLOR="#000000">
        <B>המינוים הנוספים שלך ב- <MM-Host></B>
        </FONT></TD></TR>

    <tr><td>
		סמן את תיבת הסימן האישור ולחץ על לחצן זה כדי לעזוב
		רשימה זו.  <strong>אזהרה:</strong> פעולה זו תתבצע
		מיד!
        <p>
        <center><MM-Unsubscribe-Button></center></td>
    <td>
		ניתן לצפות ברשימה של כל רשימות הדיוור ב-<mm-host>
		בהן אתה מנוי.  השתמש בזה באם ברצונך לבצע את אותם
		השינויים בהגדרות המנוי שלך גם במנוים הנוספים שלך.

        <p>
        <center><MM-Other-Subscriptions-Submit></center>
        </TD></TR>
</table>

<TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="5">
    <TR><TD COLSPAN=2 WIDTH="100%" BGCOLOR="#FFF0D0"><FONT COLOR="#000000">
        <B>הסיסמא שלך ב- <MM-List-Name></B>
        </FONT></TD></TR>

    <tr valign="TOP"><td WIDTH="50%">
        <a name=reminder>
        <center>
        <h3>שכחת את הסיסמא שלך?</h3>
        </center>
        לחץ על לחצן זה כדי שהסיסמא שלך תישלח אל כתובת המנוי שלך.
        <p><MM-Umbrella-Notice>
        <center>
        <MM-Email-My-Pw>
        </center>
        </td>

    <td WIDTH="50%">
        <a name=changepw>
        <center>
        <h3>שינוי הסיסמא שלך</h3>
        <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2" WIDTH="70%" COLS=2>
            <TR><TD BGCOLOR="#dddddd"><div align="right">סיסמא חדשה:</div></TD>
                <TD><MM-New-Pass-Box></TD>
                </TR>
            <TR>
                <TD BGCOLOR="#dddddd"><div align="right">ושוב, לאישור:</div></TD>
                <TD><MM-Confirm-Pass-Box></TD>
            </TR>
        </table>

        <MM-Change-Pass-Button>
        <p><center><mm-global-pw-changes-button>שנוי גלובלי.
        </center>
</TABLE>

<p>
<TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="5">
    <TR><TD WIDTH="100%" BGCOLOR="#FFF0D0"><FONT COLOR="#000000">
        <B>אפשריות המנוי שלך ב- <MM-List-Name></B>
        </FONT></TD></TR>
</table>

<p>
<i><strong>הערכים הנוכחיים מסומנים.</strong></i>

<p>שים לב שלחלק מהאפשריות יש תיבת סימון <em>שינוי גלובלי</em>.
שינוי שדה זה יגרום לשינויים המתבצעים כאן להתבצע בכל
רשימות הדיוור בהן אתה מנוי ב-<mm-host>. לחץ על <em>הצג
מינויים נוספים שלי</em> למעלה כדי לראות בעוד אלו רשימות
דיוור אתה מנוי.

<p>
<TABLE BORDER="0" CELLSPACING="3" CELLPADDING="4" WIDTH="100%">
    <tr><TD BGCOLOR="#cccccc">
        <a name="disable">
        <strong>קבלת דואר</strong></a><p>
		קבע אפשרות זו ל-<em>פעיל</em> כדי לקבל מסרים שנשלחים
		לרשימת דיוור זו. קבע <em>לא פעיל</em> אם אתה רוצה להשאר
		מנוי, אבל לא רוצה שיישלח אליך דואר לתקופה (למשל, אם
		אתה יותא לחופשה).  אם אתה הופך אותו ללא פעיל, אל תשכח
		להחזיר אותו לפעיל כשתחזור; הוא לא יהפוך לפעיל באופן
		אוטומטי.
        </td><td bgcolor="#cccccc">
        <mm-delivery-enable-button>פעיל<br>
        <mm-delivery-disable-button>לא פעיל<p>
        <mm-global-deliver-button><i>שינוי גלובלי</i>
        </td></tr>

<!--Start-Digests-Delete-->
    <tr><TD BGCOLOR="#cccccc">
        <strong>קבע מצב תקצירים</strong><p>
		אם תדליק את מצב תקצירים, אתה תקבל את המסרים בחבילה
		אחת (כד"כ אחת ליום אך יכול להיות יותר ברשימות עמוסות),
		במקום בבודדת כאשר הם נשלחים.  אם מצב תקצירים משתנה מדלוק
		לכבוי, יתכן שתקבל תקציר אחד אחרון.
        </td><td bgcolor="#cccccc">
        <MM-Undigest-Radio-Button>כבוי<br>
        <MM-Digest-Radio-Button>דלוק
        </td></tr>
        
    <tr><TD BGCOLOR="#cccccc">
        <strong>לקבל תקצירים ב-MIME או בטקסט פשוט?</strong><p>
		תוכנת הדואר שלך יכולה לתמוך או לא לתמוך בתקצירי MIME.
		באופן כללי, עדיף תקצירי MIME, אבל אם מתעוררת בעיה
		בקריאה, בחר בטקסט פשוט.
                </td><td bgcolor="#cccccc">
        <MM-Mime-Digests-Button>MIME<br>
        <MM-Plain-Digests-Button>טקסט פשוט<p>
        <mm-global-mime-button><i>שינוי גלובלי</i>
        </td></tr>
<!--End-Digests-Delete-->
        
    <tr><TD BGCOLOR="#cccccc">
        <strong>לקבל את המסרים של עצמך לרשימה?</strong><p>
		כרגיל, אתה תקבל העתק של כל מסר שאתה שולח אל
		הרשימה.  אם אינך רוצה לקבל העתק זה, קבע אפשרות
		זו ל-<em>לא</em>.
        </td><td bgcolor="#cccccc">
        <mm-dont-receive-own-mail-button>לא<br>
        <mm-receive-own-mail-button>כן
        </td></tr>

    <tr><TD BGCOLOR="#cccccc">
        <strong>לקבל הודעת אישור על כך ששלחת מסר לרשימה?</strong><p>
        </td><td bgcolor="#cccccc">
        <mm-dont-ack-posts-button>לא<br>
        <mm-ack-posts-button>כן
        </td></tr>

    <tr><td bgcolor="#cccccc">
        <strong>קבל תזכורת סיסמא בדוא"ל עבור רשימה זו?</strong><p>
		פעם בחודש, תקבל דוא"ל המכיל תזכורת סיסמא עבור
		כל רשימה בשרת זה אליה אתה מנוי.  אתה יכול לכבות
		את זה ברמה של הרשימה על ידי בחירת <em>לא</em> עבור
		אפשרות זו.  אם תכבה תזכורות סיסמא עבור כל הרשימות
		בהן אתה מנוי, לא יישלח אליך כל דוא"ל עם תזכורת.
        </td><td bgcolor="#cccccc">
        <mm-dont-get-password-reminder-button>לא<br>
        <mm-get-password-reminder-button>כן<p>
        <mm-global-remind-button><i>שינוי גלובלי</i>
        </td></tr>

    <tr><TD BGCOLOR="#cccccc">
        <strong>להסתיר את עצמך מרשימת המנוים?</strong><p>
		כאשר מישהו צופה במנויי הרשימה, כתובת הדוא"ל שלך
		בד"כ מוצגת (בצורה מטושטשת כדי להכשיל קוצרי כתובות של
		שולחי דואר זבל).  אם ברצונך שכתובת הדוא"ל שלך בכלל
		לא תופיע ברשימת המנוים, בחר <enm>כן</em> לאפשרות זו.
        </td><td bgcolor="#cccccc">
        <MM-Public-Subscription-Button>לא<br>
        <MM-Hide-Subscription-Button>כן
        </td></tr>

    <tr><TD BGCOLOR="#cccccc">
        <strong>איזו שפה מועדפת עליך?</strong><p>
        </td><td bgcolor="#cccccc">
        <MM-list-langs>
        </td></tr>

    <tr><td bgcolor="#cccccc">
        <strong>אל איזה סיווגי נושא אתה מעוניין להרשם?</strong><p>
		על ידי בחירת נושא אחד או יותר, ניתן לסנן את
		התעבורה ברשימת הדיוור, כך שתקבל רק תת-קבוצה
		של המסרים.  אם מסר מתאים לאחד הנושאים שבחרת,
		אזי תקבל את המסר, אחרת לא.


<p>אם מסר אינו מתאים לאף נושא, כלל המסירה תלוי בהגדרת
		האפשרות למטה.  אם לא תבחר כלל נושאים שמעניינים אותך,
		תקבל את כל המסרים שנשלחים אל רשימת הדיוור.
        </td><td bgcolor="#cccccc">
        <mm-topics>
        </td></tr>

    <tr><td bgcolor="#cccccc">
        <strong>האם אתה מעונין לקבל מסרים שלא מתאימים לאף מסנן נושאים?</strong><p>

		אפשרות זו נכנסת לפעולה רק אם בחרת לפחות נושא
		אחד למעלה.  היא מתארת את כלל ברירת המחדל עבור
		מסרים שלא מתאימים לאף מסנן נושאים.  בחירת <em>לא</em>
		אומר שאם המסר אינו מתאים לאף מסנן נושאים,
		אזי לא תקבל את המסר, ובחירת <em>כן</em> אומר
		לשלוח מסרים ללא התאמה אליך.

<p>אם לא נבחרו נושאים מעניינים למעלה, אזי תקבל
		כל מסר שנשלח אל רשימת הדיוור.
        </td><td bgcolor="#cccccc">
        <mm-suppress-nonmatching-topics>לא<br>
        <mm-receive-nonmatching-topics>כן
        </td></tr>

    <tr><td bgcolor="#cccccc">
        <strong>המנע מהעתקים כפולים של מסרים?</strong><p>


		כאשר אתה מופיע במפורש בכותרת <tt>אל:</tt> 
		או <tt>העתק:</tt> של מסר ברשימה, אתה יכול לבחור
		שלא לקבל עוד העתק מהרשימה.  בחר <em>כן</em> כדי
		להמנע מקבלת העתקים מהרשימה; בחר <em>לא</em> כדי
		לקבל העתקים.

<p>אם לרשימה מסרים הניתנים להתאמה אישית על ידי המנוים
		פעיל, ואתה בוחר לקבל העתקים, לכל מסר תתווסף
		כותרת <tt>X-Mailman-Copy: yes</tt>.

        </td><td bgcolor="#cccccc">
        <mm-receive-duplicates-button>לא<br>
        <mm-dont-receive-duplicates-button>כן<p>
        <mm-global-nodupes-button><i>שינוי גלובלי</i>
        </td></tr>

    <tr><TD colspan="2">
        <center><MM-options-Submit-button></center>
        </td></tr>

</table>
</center>
<p>
<MM-Form-End>

<MM-Mailman-Footer>
</body>
</html>
