<!-- $Revision: 2.7 $ -->
<html>
<head>
    <link rel="SHORTCUT ICON" href="<mm-favicon>">
    <title><MM-Presentable-User> configuraci&oacute;n do subscritor para <MM-List-Name>
    </title>
</head>
<BODY BGCOLOR="#ffffff">
    <TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="5">
    <TR>
    <TD WIDTH="100%" BGCOLOR="#99CCFF"><B>
        <FONT COLOR="#000000" SIZE=+1>
        <MM-List-Name> Configuraci&oacute;n do usuario 
        <MM-Presentable-User>
	</FONT></B></TD>
    </TR>
    </TABLE>
<p>
<table width="100%" border="0" cellspacing="5" cellpadding="5">
    <tr>
    <td>
        Opci&oacute;ns de subscrici&oacute;n  de <b><MM-Presentable-User></b>
        na rolda de distribuci&oacute;n <MM-List-Name>.
      </td>
    <td><MM-Form-Start><mm-logout-button><MM-Form-End></td>
    </tr><tr>
        <td colspan="2">
        <MM-Case-Preserved-User>

        <MM-Disabled-Notice>

        <p><mm-results>
        </td>
    </tr>
</table>

<MM-Form-Start>
<p>
<TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="5">
    <TR>
    <TD WIDTH="100%" BGCOLOR="#FFF0D0" colspan="2">
        <FONT COLOR="#000000">
        <B>Para mudar a informaci&oacute;n con que est&aacute; subscrito
        a <MM-List-Name></B>
	</FONT></TD>
    </TR>
    <tr>
    <td colspan="2"> Pode cambiar o enderezo con que
        est&aacute; subscrito &aacute; rolda de distribuci&oacute;n
        se introduce un enderezo novo no campo que aparece
        m&aacute;is abaixo. Enviar&aacute;selle unha mensaxe
        de confirmaci&oacute;n
        ao enderezo que especificar xa que os cambios
        non ter&aacute;n os seus efectos at&eacute; que o confirmar.

        <p>As confirmaci&oacute;ns caducan despois de <mm-pending-days>.
 
        <p>Opcionalmente, pode p&oacute;r ou cambiar o seu nome e apelidos
         (por exemplo <em>Pepe P&eacute;rez</em>).

        <p>Se desexa aplicar as modificaci&oacute;ns de subscrici&oacute;n
          a todas as roldas en que est&aacute;  subscrito
          en <mm-host>,
        marque a cela de verificaci&oacute;n <em>Cambiar globalmente</em>.

 
      </td></tr>
     <tr><td><center>
         <table border="0" cellspacing="2" cellpadding="2" width="80%" cols="2">
        <tr><td bgcolor="#dddddd"><div align="right">Enderezo novo:</div></td>
            <td><mm-new-address-box></td>
           </tr>
        <tr><td bgcolor="#dddddd"><div align="right">Unha outra vez para confirmar:</div></td> 
            <td><mm-confirm-address-box></td>
           </tr>
        </tr></table></center>
        </td>
        <td><center>
        <table border="0" cellspacing="2" cellpadding="2" width="80%" cols="2">
             <tr><td bgcolor="#dddddd"><div align="right">O seu nome
             (opcional):</div></td>
             <td><mm-fullname-box></td>
             </tr>
        </table></center>
        </td>
        </tr>
     <tr><td colspan="2"><center><mm-change-address-button>
         <p><mm-global-change-of-address>Cambiar globalmente
     </center></td>
     </tr>
</table>

<p>
<TABLE WIDTH="100%" BORDER="0" CELLSPACING="5" CELLPADDING="5">
    <TR>
    <TD WIDTH="50%" BGCOLOR="#FFF0D0"><FONT COLOR="#000000">
        <B>Para anular a subscrici&oacute;n de <MM-List-Name></B></td>

	<TD WIDTH="50%" BGCOLOR="#FFF0D0"><FONT COLOR="#000000">
        <B>O resto das subscrici&oacute;ns que ten en <MM-Host></B>
	</FONT></TD>
    </TR>

    <tr>
    <td>
        Marque a cela de verificaci&oacute;n e prema este bot&oacute;n
        para anular a subscrici&oacute;n desta rolda de distribuci&oacute;n.
        <strong>Aviso:</strong>
        esta acci&oacute;n ter&aacute; un efecto inmediato
        <p>
        <center><MM-Unsubscribe-Button></center></td>
    <td>
        Pode ver un informe do resto das roldas de distribuci&oacute;n
        de
        <mm-host> en que est&aacute; subscrito. Empregue esta parte se
        desexa aplicar os cambios de xeito global ao resto das subscrici&oacute;ns
        <p>
        <center><MM-Other-Subscriptions-Submit></center>
	</TD></TR>
</table>

<TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="5">
    <TR>
    <TD COLSPAN=2 WIDTH="100%" BGCOLOR="#FFF0D0"><FONT COLOR="#000000">
        <B>O seu contrasinal para <MM-List-Name></B>
	</FONT></TD>
    </TR>

    <tr valign="TOP"><td WIDTH="50%">
        <a name=reminder>
        <center>
        <h3>Esqueceu o seu contrasinal?</h3>
        </center>
        Prema este bot&oacute;n para que se lle env&iacute;e por correo
        electr&oacute;nico ao enderezo con que
        est&aacute;
        subscrito.
        <p><MM-Umbrella-Notice>
        <center>
        <MM-Email-My-Pw>
        </center>
        </td>

    <td WIDTH="50%">
        <a name=changepw>
        <center>
        <h3>Para cambiar o seu contrasinal</h3>
        <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2" WIDTH="70%" COLS=2>
            <TR><TD BGCOLOR="#dddddd"><div align="right">Contrasinal
                novo:</div></TD>
                <TD><MM-New-Pass-Box></TD>
          </TR>
            <TR>
                <TD BGCOLOR="#dddddd"><div align="right">Unha outra vez para
                confirmar:</div></TD>
                <TD><MM-Confirm-Pass-Box></TD>
            </TR>
        </table>

        <MM-Change-Pass-Button>
        <p><center>
        <mm-global-pw-changes-button>Cambiar globalmente.
        </center>
</TABLE>

<p>
<TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="5">
    <TR>
    <TD WIDTH="100%" BGCOLOR="#FFF0D0"><FONT COLOR="#000000">
        <B>As s&uacute;as opci&oacute;ns de subscrici&oacute;n para a rolda <MM-List-Name></B>
	</FONT></TD>
    </TR>
</table>

<p>
<i><strong>Comprob&aacute;ronse os valores actuais.</strong></i>

<p>C&oacute;mpre salientar que algunha das opci&oacute;ns ten unha cela denominada
<em>Cambiar globalmente</em>.
Ao activar esta cela, os cambios aplicararanse a cada unha
das roldas de distribuci&oacute;n de <mm-host> en que est&aacute;
subscrito. Prema <em>Relacionar o resto das subscrici&oacute;ns</em>
 m&aacute;is arriba para ver cales son.

<p>
<TABLE BORDER="0" CELLSPACING="3" CELLPADDING="4" WIDTH="100%">
    <tr><TD BGCOLOR="#cccccc">
        <a name="disable">
        <strong>Entrega de correo</strong></a>
        <p>
        Se selecciona <em>Activar</em> recibir&aacute; as mensaxes que se
        env&iacute;en a esta rolda de distribuci&oacute;n. Se selecciona
        <em>Desactivar</em> non recibir&aacute; o correo
        que se enviar &aacute; rolda de distribuci&oacute;n durante un tempo (por
        exemplo, se marcha de vacaci&oacute;ns). Se desactiva a recepci&oacute;n
        das mensaxes de correo, non esqueza volver a activar a recepci&oacute;n
        cando proceder.
        </td><td bgcolor="#cccccc">
        <mm-delivery-enable-button>Activar<br>
        <mm-delivery-disable-button>Desactivar<p>
        <mm-global-deliver-button><i>Aplicar globalmente</i>
        </td></tr>

<!--Start-Digests-Delete-->
    <tr><TD BGCOLOR="#cccccc">
        <strong>Activar o modo de compilaci&oacute;n</strong>
        <p>
        Se activa o modo de compilaci&oacute;n, recibir&aacute; diariamente as mensaxes
        que se enviaren &aacute; rolda recompiladas nunha &uacute;nica mensaxe,
        en lugar de as recibir a medida que se env&iacute;an. Se cambia o
        modo de compilaci&oacute;n de Activar a Desactivar, &eacute; pos&iacute;bel que reciba unha &uacute;ltima compilaci&oacute;n.
        </td><td bgcolor="#cccccc">
        <MM-Undigest-Radio-Button>Desativar<br>
        <MM-Digest-Radio-Button>Activar
        </td></tr>
        
    <tr>
    <TD BGCOLOR="#cccccc">
        <strong>Desexa recibir as recompilaci&oacute;ns en texto plano
        ou con codificaci&oacute;n MIME?</strong>
        <p>
        Talvez o seu programa de xesti&oacute;n de correo electr&oacute;nico non &eacute; compat&iacute;bel coas recompilaci&oacute;ns
          MIME. En xeral pref&iacute;rense as recompilaci&oacute;ns MIME, mais se
          ten problemas
        &aacute; hora de as ler, seleccione as recompilaci&oacute;ns en texto plano.
        </td><td bgcolor="#cccccc">
        <MM-Mime-Digests-Button>MIME<br>
        <MM-Plain-Digests-Button>Texto plano<p>
        <mm-global-mime-button><i>Aplicar globalmente</i>
        </td></tr>
<!--End-Digests-Delete-->
        
    <tr>
    <TD BGCOLOR="#cccccc">
        <strong>Quere recibir as mensaxes que vostede mesmo 
        enviar a esta rolda?</strong>
        <p>
        Polo xeral, recibir&aacute; unha copia de cada mensaxe que env&iacute;e
        &aacute; rolda. Se non desexa recibir a dita copia, po&ntilde;a esta opci&oacute;n
        como
        <em>Non</em>.
      </td>
    <td bgcolor="#cccccc">
        <mm-dont-receive-own-mail-button>Non<br>
        <mm-receive-own-mail-button>Si</td>
    </tr>

    <tr>
    <TD BGCOLOR="#cccccc">
        <strong>Desexa recibir unha confirmaci&oacute;n cando enviar correo
        a esta rolda?</strong>
        <p>
        </td>
    <td bgcolor="#cccccc">
        <mm-dont-ack-posts-button>Non<br>
        <mm-ack-posts-button>Si
        </td></tr>

    <tr>
    <td bgcolor="#cccccc">
        <strong>Desexa recibir as lembranzas desta rolda?</strong>
        <p>
        Mensualmente, recibir&aacute; unha mensaxe de correo co contrasinal
        de cada unha das roldas en que est&aacute; subscrito. Pode
        desactivar este env&iacute;o por cada rolda con s&oacute; seleccionar
        <em>Non</em> nesta opci&oacute;n. Se decide desactivar a lembranza
        dos contrasinais en todas as roldas a que est&aacute; subscrito,
        non se lle enviar&aacute; ningunha mensaxe.
      </td>
    <td bgcolor="#cccccc">
        <mm-dont-get-password-reminder-button>Non<br>
        <mm-get-password-reminder-button>Si<p>
        <mm-global-remind-button><i>Aplicar globalmente</i>
        </td></tr>

    <tr>
    <TD BGCOLOR="#cccccc">
        <strong>Desexa ocultarse da listaxe de subscritores?</strong>
        <p>
        Cando algu&eacute;n vexa a listaxe de subscritores, o seu enderezo
        de correo electr&oacute;nico aparecer&aacute; relacionado 
        (dun xeito escuro para evitar os correos lixo). Se non
        desexar que o seu enderezo apareza, seleccione <em>Si</em>.
      </td>
    <td bgcolor="#cccccc">
        <MM-Public-Subscription-Button>Non<br>
        <MM-Hide-Subscription-Button>Si
        </td></tr>

    <tr>
    <TD BGCOLOR="#cccccc">
        <strong>En que idioma desexa ver as mensaxes da rolda?</strong>
        <p>
        </td><td bgcolor="#cccccc">
        <MM-list-langs>
         </td></tr>
 
     <tr>
     <td bgcolor="#cccccc">
         <strong>A que tipo de temas lle gustar&iacute;a subscribirse?  </strong>
         <p>
                  Ao seleccionar un ou m&aacute;is temas, pode filtrar
                  o tr&aacute;fico da rolda de distribuci&oacute;n de
		  xeito que s&oacute; reciba un subconxunto das
		  mensaxes. Unicamente chegaranlle as mensaxes que
		  coincidiren con alg&uacute;n dos temas seleccionados.

		  <p>Se unha mensaxe non coincide co tema, a regra que
		  decide se se entrega a mensaxe depende da
		  configuraci&oacute;n da opci&oacute;n de abaixo. Se
		  non selecciona ning&uacute;n tema de interese,
		  recibir&aacute; todas as  mensaxes que se dirixiren &aacute; rolda.
         </td><td bgcolor="#cccccc">
         <mm-topics>
         </td></tr>
 
     <tr>
     <td bgcolor="#cccccc">
         <strong>Quere recibir as mensaxes que non coincidan con
                  ning&uacute;n tema?</strong>
         <p>
                  Esta opci&oacute;n s&oacute; ten o seu efecto se est&aacute;
		  subscrito a alg&uacute;n tema dos de enriba. Esta
		  opci&oacute;n describe cal ser&aacute; a regra de
		  entrega por defecto para as mensaxes que non coincidiren
		  con ning&uacute;n tema. Se selecciona que <em>Non</em>
		  indica o seu desexo de non recibir as mensaxes que non
		  coincidan con ning&uacute;n tema, mentres que se
		  selecciona que <em>Si</em> significa que recibir&aacute;
		  todas as mensaxes que non coincidiren con ning&uacute;n
		  tema.

		  <p>Se
		  non selecciona ning&uacute;n tema de interese na parte superior,
		  ent&oacute;n recibir&aacute; todas as mensaxes
		 que se enviaren &aacute; rolda.
         </td>
     <td bgcolor="#cccccc">
         <mm-suppress-nonmatching-topics>Non<br>
         <mm-receive-nonmatching-topics>Si
        </td></tr>

    <tr>
    <td bgcolor="#cccccc">
        <strong>Desexa evitar as copias duplicadas das s&uacute;as propias
        mensaxes?</strong>
        <p>
		Cando estea inclu&iacute;do explicitamente nas cabeceiras
		<tt>To:</tt> ou <tt>Cc:</tt> dunha mensaxe dirixida &aacute; rolda, pode optar
		por non recibir outra copia da	rolda de distribuci&oacute;n. Seleccione <em>Si</em> para
		evitar recibir copias da rolda de distribuci&oacute;n e
		<em>Non</em> para as recibir.

		<p>Se a rolda ten subscritores coas mensaxes
		personalizadas e  elixe que si	desexa recibir copias,
		cada copia ter&aacute; unha cabeceira <tt>X-Mailman-Copy:
		yes</tt> inclu&iacute;da nela.

      </td>
    <td bgcolor="#cccccc">
        <mm-receive-duplicates-button>Non<br>
        <mm-dont-receive-duplicates-button>Si<p>
        <mm-global-nodupes-button><i>Aplicar globalmente</i>
        </td></tr>

    <tr><TD colspan="2">
        <center><MM-options-Submit-button></center>
        </td></tr>

</table>
</center>
<p>
<MM-Form-End>

<MM-Mailman-Footer>
</body>
</html>
