Iste pagina contine un subcollection del messages al lista
<em>%(listname)s</em> que attende le approbation tue.
Actualmente illo monstra %(description)s

<p>Pro omne requesta administrative, selige le action a exequer
e clicca sur <b>Confirmar tote le datos</b> quando tu ha finite.
<a href="%(detailsurl)s">Instructiones plus detaliate</a> es disponibile.

<p>Tu pote etiam <a href="%(summaryurl)s">vider un summario</a>de tote
le requestas attendente.
