Este texto pode incluir
<a href="https://docs.python.org/2/library/stdtypes.html#string-formatting-operations">strings 
de formata&ccedil;&atilde;o em Python</a> as quais s&atilde;o resolvidas em rela&ccedil;&atilde;o &agrave; lista de
atributos ??????? atributos da lista.
As substitui&ccedil;&otilde;es permitidas s&atilde;o:

<ul>
    <li><b>real_name</b> - O nome `bonito' da lista; normalmente
    &eacute; o nome da lista com alguma capitaliza&ccedil;&atilde;o.

    <li><b>list_name</b> - O nome pelo qual a lista &eacute;
    identificada em URLs, as quais s&atilde;o sens&iacute;veis &agrave; capitaliza&ccedil;&atilde;o.

    <li><b>host_name</b> - O nome completo do servidor onde 
    corre o servidor da lista.

    <li><b>web_page_url</b> - A URL base do Mailman. A ela
    pode-se acrescentar, por exemplo,
    <em>listinfo/%(list_name)s</em> para obter a p&aacute;gina de
    informa&ccedil;&otilde;es da lista.

    <li><b>description</b> - Uma breve descri&ccedil;&atilde;o da lista
    de discuss&atilde;o.

    <li><b>info</b> - A descril&ccedil;&atilde;o completa.

    <li><b>cgiext</b> - A extens&atilde;o utilizada em scripts CGI.
</ul>
