Auf dieser Seite finden Sie die aktuellen administrativen Anfragen der
Liste <em>%(listname)s</em>, die Ihre Aufmerksamkeit ben&ouml;tigen. Derzeit
finden sich hier %(description)s

<p>W&auml;hlen Sie bitte f&uuml;r jede Anfrage eine L&ouml;sung aus und klicken Sie
dann auf <b>&Auml;nderungen speichern</b>, um Ihre &Auml;nderungen zu &uuml;bernehmen.
Eine detailierte Anleitung finden Sie <a href="%(detailsurl)s">hier</a>.

<p>Sie k&ouml;nnen auch eine <a href="%(summaryurl)s">&Uuml;bersicht aller
offenen Anfragen</a> aufrufen.
