<html>
<head>
    <title>Konference %(realname)s - přihl&aacute;&scaron;en&iacute; pro př&iacute;stup do priv&aacute;tn&iacute;ho archivu </title>
<script>function sf(){document.f.username.focus();}</script>
</head>
<body bgcolor="#ffffff" onLoad="sf()">
<FORM METHOD=POST ACTION="%(action)s" name="f">
%(message)s
  <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
    <TR>
      <TD COLSPAN="2" WIDTH="100%%" BGCOLOR="#99CCFF" ALIGN="CENTER">
	<B><FONT COLOR="#000000" SIZE="+1">Konference %(realname)s - 
	    přihl&aacute;&scaron;en&iacute; pro př&iacute;stup do priv&aacute;tn&iacute;ho archivu</FONT></B>
      </TD>
    </TR>
    <tr>
        <TD><div ALIGN="Right">Emailov&aacute; adresa:</div></TD>
        <TD><INPUT TYPE="text" NAME="username" SIZE="30"></TD>
    </tr>
    <tr>
      <TD><div ALIGN="Right">Heslo:</div></TD>
      <TD><INPUT TYPE="password" NAME="password" SIZE="30"></TD>
    </tr>
    <tr>
      <td colspan=2 align="middle"><INPUT type="SUBMIT"
                                          name="submit"
					  value="Pusť mě dovnitř...">
      </td>
    </tr>
  </TABLE>
      <p><strong><em>Pozor:</em></strong> Aby syst&eacute;m fungoval 
      spr&aacute;vně mus&iacute;te m&iacute;t povolen&eacute; cookie ve Va&scaron;em prohl&iacute;žeči.

      <p>Cookies se použ&iacute;vaj&iacute; na to, abyste nemuseli jeden
      každ&yacute; požadavek znovu potvrzovat heslem. Zaniknou
      pokud ukonč&iacute;te prohl&iacute;žeč a nebo když se odhl&aacute;s&iacute;te.
      Odhl&aacute;sit se můžete kliknut&iacute;m na <em>Odhl&aacute;sit</em>. 
      Tento odkaz uvid&iacute;te až po &uacute;spě&scaron;n&eacute;m přihl&aacute;&scaron;en&iacute;.

      <p>
    <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
    <TR>
      <TD COLSPAN="2" WIDTH="100%%" BGCOLOR="#99CCFF" ALIGN="CENTER">
	<B><FONT COLOR="#000000" SIZE="+1">Password Reminder</FONT></B>
      </TD>
    </TR>
    <tr>
      <td>If you don't remember your password, enter your email address
          above and click the <em>Remind</em> button and your
          password will be emailed to you.</td>
    </tr>
    <tr>
      <td><center><INPUT name="login-remind" type="SUBMIT" value="Remind" ></center></td>
    </tr>
  </TABLE>
</FORM>
</body>
</html>
