<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<HTML>
  <HEAD>
     <title>Forumo %(listname)s archyvai</title>
     <META NAME="robots" CONTENT="noindex,follow">
  </HEAD>
  <BODY BGCOLOR="#ffffff">
     <h1>Forumo %(listname)s archyvai</h1>
     <p>
      Į &scaron;į forumą dar neatsiųstas nė vienas lai&scaron;kas.
      <a href="%(listinfo)s">Paspaudę čia galite sužinoti daugiau apie forumą</a>.
     </p>
  </BODY>
  </HTML>
