Τα διαχειριστικά αιτήματα απεικονίζονται με ένα από τους δύο τρόπους, σε μια <a
href="%(summaryurl)s">περιληπτική σελίδα</a>, και σε μια σελίδα με <em>λεπτομερή 
περιγραφή</em>. 
Η περιληπτική σελίδα περιέχει εκκρεμή αιτήματα εγγραφής ή διαγραφής, όπως και μηνύματα 
τα οποία φυλάσσονται περιμένοντας την έγκρισή σας, ταξινομημένα με βάση την ηλεκτρονική διεύθυνση 
του αποστολέα.  Η λεπτομερής σελίδα περιέχει μια πιο λεπτομερή επισκόπηση κάθε μήνυματος, 
συμπεριλαμβανομένων και όλων των τίτλων των μηνυμάτων, καθώς και ένα απόσπασμα του κυρίως κειμένου 
του μηνύματος.

<p>Σε όλες τις σελίδες, οι παρακάτω δυνατότητες είναι διαθέσιμες:

<ul> <li><b>Αναβολή</b> -- Αναβάλετε την απόφασή σας για αργότερα.  Καμία ενέργεια 
δεν γίνεται αυτή τη στιγμή για το συγκεκριμένο εκκρεμές διαχειριστικό αίτημα, αλλά για τα μηνύματα 
που κρατούνται περιμένοντας την έγκρισή σας, παραμένει η δυνατότητα να τα προωθήσετε 
ή να τα αφήσετε ως έχουν (δείτε παρακάτω).

<li><b>Έγκριση</b> -- Εγκρίνετε το μήνυμα, sστέλνοντάς το στη λίστα.
Για αιτήματα που αφορούν την εγγραφή χρήστη εγκρίνετε την αλλαγή στην κατάσταση της 
εγγραφής.

<li><b>Απόρριψη</b> -- Απορρίψτε το μήνυμα, στέλνοντας μία ειδοποίηση απόρριψης στον αποστολέα, 
και διαγράφοντας το αρχικό μήνυμα. Για αιτήματα που αφορούν την εγγραφή χρήστη, 
απορρίψτε την αλλαγή στην κατάσταση της εγγραφής.  Σε κάθε περίπτωση, θα πρέπει να προσθέσετε την 
αιτιολογία για την απόρριψη στο συνοδευτικό πλαίσιο κειμένου.

<li><b>Διαγραφή</b> -- Διαγράψτε το αρχικό μήνυμα, χωρίς να στείλετε ειδοποίηση για τη διαγραφή.  
Για αιτήματα που αφορούν την εγγραφή χρήστη, αυτή η λειτουργία απλά διαγράφει το αίτημα χωρίς ειδοποίηση 
στο χρήστη που έστειλε το αίτημα. Αυτή συνήθως η ενέργεια εφαρμόζεται για τη διαγραφή των γνωστών 
μηνυμάτων μαζικής αποστολής. </ul>

<p>Για μηνύματα που κρατούνται περιμένοντας την έγκρισή σας, ενεργοποιήστε την επιλογή <b>Διατήρηση</b> 
εάν θέλετε να κρατήσετε ένα αντίγραφο του μηνύματος για το διαχειριστή της ιστοσελίδας.  
Αυτή η λειτουργία είναι χρήσιμη για τα καταχρηστικά μηνύματα που θέλετε να διαγράψετε από 
τη λίστα, αλλά και να κρατήσετε στο αρχείο για μελλοντική επιθεώρηση.

<p>Ενεργοποιήστε την επιλογή <b>Προώθηση σε</b>, και γράψτε τη διεύθυνση 
στο πεδίο "προς" εάν θέλετε να προωθήσετε το μήνυμα σε κάποιο χρήστη που δεν είναι 
στη λίστα. Για να επεξεργαστείτε ένα μήνυμα που κρατείται, πριν σταλεί στη λίστα, 
πρέπει να προωθήσετε το μήνυμα στον εαυτό σας (ή στους δημιουργούς της λίστας) 
και να διαγράψετε το αρχικό μήνυμα. Ύστερα, όταν το μήνυμα φτάσει σε εσάς, 
κάντε τις αλλαγές που θέλετε και στείλτε το πάλι στη λίστα, βάζοντας σαν τίτλο: <i>Εγκρίθηκε</i> 
και συμπληρώνοντας τον κωδικό της λίστας. Σε αυτή την περίπτωση θα πρέπει να συμπεριλάβατε και ένα σημείωμα 
στο μήνυμα αυτό, στο οποίο να εξηγείτε ότι έχετε τροποποιήσει το κείμενο.

<p>Εάν ο αποστολέας είναι μέλος της λίστας, ο οποίος είναι σε διαδικασία τροποποίησης, 
μπορείτε προαιρετικά να σβήσετε την σημαία τροποποίησής του. Αυτό είναι χρήσιμο 
όταν η λίστα σας είναι ρυθμισμένη να θέτει τα νέα μέλη υπό επιτήρηση και εσείς 
έχετε αποφασίσει ότι αυτό το μέλος μπορεί να αποστέλλει μηνύματα στη λίστα χωρίς 
να χρειάζεται έγκριση.

<p>Εάν ο αποστολέας δεν είναι μέλος της λίστας, μπορείτε να προσθέσετε την ηλ. διεύθυνση του 
σε ένα <em>φίλτρο αποστολέων</em>. Τα φίλτρα αποστολέων περιγράφονται στην <a
href="%(filterurl)s">προσωπική σελίδα ορισμού φίλτρων αποστολέων</a>, και μπορεί να είναι
<b>αυτόματης έγκρισης</b> (Εγκρίσεις), <b>αυτόματης κράτησης</b> (Κρατήσεις),
<b>αυτόματης απόρριψης</b> (Απορρίψεις), ή <b>αυτόματης διαγραφής</b> (Διαγραφές). Αυτή η επιλογή 
δεν θα είναι διαθέσιμη εάν η διεύθυνση είναι ήδη σε ένα από τα φίλτρα αποστολέων.

<p>Όταν τελειώσετε, ενεργοποιήστε την <em>Υποβολή όλων των Δεδομένων</em>, επιλογή που βρίσκεται 
στην αρχή ή στο τέλος της σελίδας. Αυτή η επιλογή θα υποβάλει όλες τις επιλεγμένες ενέργειες για 
όλα τα διαχειριστικά αιτήματα για τα οποία λάβατε απόφαση.

<p><a href="%(summaryurl)s">Επιστροφή στην περιληπτική σελίδα</a>.
