<html>
<head>
  <title>האימות של %(listname)s %(who)s</title>
  <script>function sf(){document.f.adminpw.focus();}</script>
</head>
<body bgcolor="#ffffff" dir="rtl" onLoad="sf()">
<FORM METHOD=POST ACTION="%(path)s" name="f">
%(message)s
  <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
    <TR>
      <TD COLSPAN="2" WIDTH="100%%" BGCOLOR="#99CCFF" ALIGN="CENTER">
	<B><FONT COLOR="#000000" SIZE="+1">האימות של %(listname)s %(who)s
	    </FONT></B>
      </TD>
    </TR>
    <tr>
      <TD><div ALIGN="left">סיסמת הרשימה %(who)s:</div></TD>
      <TD><INPUT TYPE="password" NAME="adminpw" SIZE="30"></TD>
    </tr>
    <tr>
      <td colspan=2 align=middle><INPUT type="SUBMIT"
                                        name="admlogin"
					value="הכנס אותי...">
      </td>
    </tr>
  </TABLE>
      <p><strong><em>חשוב:</em></strong> מנקודה זו ואילך, חייבים
שעוגיות יהיו פעילות בדפדפן שלך, אחרת
לא יתבצעו שינויים מנהלתיים.

	<p>משתמשים בעוגיות מושב בממשק הניהולי של דוור
	כדי שלא תצטריך לבצע אימות מחדש עם כל פעולה
	מנהלתית.  תוקף עוגיה זו יפוג אוטומטית כאשר
	תצא מהדפדפן, או שאפשר לגרום לתוקף העוגיה
	לפוג במפורש על ידי לחיצה על הקישור <em>יציאה</em>
	מתחת ל-<em>פעולות ניהול נוספות</em> (שתוכל
	לראות לאחר כניסה מוצלחת למערכת).

</FORM>
</body>
</html>
