Administrative foresp&oslash;rsler kan vises p&aring; to m&aring;ter, enten som en <a
href="%(summaryurl)s">oversikt</a>, eller med <em>alle detaljer</em>.
P&aring; oversiktsiden vises b&aring;de ventende p&aring;meldinger/utmeldinger og
epost som venter p&aring; godkjenning for &aring; bli distribuert via listen.
Detaljsiden viser i tillegg epostenes meldingshoder og et utdrag av
innholdet i dem.

<p>P&aring; begge sidene kan du angi f&oslash;lgende tiltak:

<ul>
<li><b>Avvent</b> -- Utsett avgj&oslash;relsen. Ingenting blir gjort med
    denne foresp&oslash;rselen n&aring;, men epost som venter p&aring; godkjenning kan du
    ta vare p&aring; eller videresende (se nedenfor).

<li><b>Godkjenne</b> -- Godta meldingen slik den er og distribuere den
    til listen. For foresp&oslash;rsler om medlemskap, iverksette utmelding eller
    p&aring;melding.

<li><b>Avsl&aring;</b> -- Slette meldingen og gi beskjed tilbake til
    avsenderen om at meldingen ikke ble godkjent. For foresp&oslash;rsler om
    medlemskap, avsl&aring; utmelding eller p&aring;melding. I alle tilfeller b&oslash;r
    du ogs&aring; oppgi en grunn i den tilh&oslash;rende tekstboksen.

<li><b>Kaste</b> -- Slette meldingen uten at noe beskjed sendes
    til avsender. Nyttig for s&oslash;ppel-epost og reklame-epost (spam).
    For foresp&oslash;rsler om medlemskap, avsl&aring; utmelding eller p&aring;melding, uten
    at den som pr&oslash;vde &aring; melde seg ut av eller p&aring; listen f&aring;r vite noe
    om det.

</ul>

<p>Kryss av for <b>Ta vare p&aring; meldingen</b> dersom du &oslash;nsker &aring; lagre en kopi for
systemets administrator. Dette kan v&aelig;re nyttig for meldinger som er
knyttet til misbruk av systemet og som du egentlig vil slette, men som kan
v&aelig;re nyttig &aring; ta en titt p&aring; senere.

<p>Kryss av for <b>Videresend denne meldingen</b> og oppgi en epostadresse
hvis du vil videresende meldingen til noen andre. For &aring; redigere en epost
som holdes tilbake f&oslash;r den sendes til listen, b&oslash;r du sende den til deg selv
(eller evt. listens eiere), og slette den opprinnelige eposten.
Deretter, n&aring;r eposten kommer i innboksen din, rediger den og gj&oslash;r de endringer
du &oslash;nsker, og send den s&aring; til listen p&aring; nytt, med et <tt>Approved:</tt> felt
i meldingshodet etterfulgt av listens passord. Husk at det er vanlig netiquette
i et slikt tilfelle &aring; oppgi at du har redigert innholdet.

<p>Hvis avsenderen er medlem av listen men er moderert, kan du fjerne
moderasjonsflagget hvis du &oslash;nsker det. Dette er nyttig n&aring;r du har satt
opp listen slik at nye medlemmer har en pr&oslash;vetid p&aring; listen, og du har bestemt
at n&aring; er pr&oslash;vetiden over for dette medlemmet.

<p>Hvis avsenderen ikke er medlem av listen, kan du f&aring; epostadressen lagt inn
i et av <em>avsenderfiltrene</em>. Avsenderfiltre er forklart p&aring; <a
href="%(filterurl)s">Filtrering p&aring; avsender</a>-siden, og kan v&aelig;re
<b>auto-godkjenne</b>, <b>auto-holdetilbake</b>, <b>auto-avsl&aring;</b>, eller
<b>auto-forkast</b>. Dette valget vil ikke v&aelig;re tilgjengelig dersom denne adressen
allerede er lagt inn i et slikt filter.

<p>Etter du har foretatt dine valg, klikk p&aring; <em>Utf&oslash;re</em>
knappen p&aring; toppen eller bunnen av siden. Det vil iverksette dine
avgj&oslash;relser.

<p><a href="%(summaryurl)s">Tilbake til oversiktsiden</a>.
