管理申請には、
<a href="%(summaryurl)s">要約ページ</a>と
<em>詳細</em>ページとの2つの表示の方法があります。
要約ページには、保留になっている入会と退会処理に加え、
送信者のメールアドレスでグループ分けされた保留投稿が表示されます。
詳細ページでは、それぞれの保留メールの詳細つまり、
メールのヘッダの全部と本文の抜書きが表示されます。

<p>どちらのページにも次の処理メニューがあります:

<ul>
<li><b>延期</b> -- 決定を先に延ばすために保留します。
    この時点では管理申請の処理は行いませんが、
    保留されているメールの転送や保存ができます(下を参照)。

<li><b>承認</b> -- 投稿を承認し、リストに配送します。
    入退会の申請は、会員権の変更を承認します。

<li><b>拒否</b> -- 投稿を拒否し、そのことを送信者に通知します。
    また、オリジナルの投稿は破棄されます。入退会の申請に関しては、
    会員権の変更を拒否します。どちらの場合も、
    テキストボックスに拒否の理由を書き加えるとよいでしょう。

<li><b>破棄</b> -- 投稿メールを捨て、拒否の通知も送りません。
    入退会申請に関しては、単に申請を破棄し、
    申請を出した人への通知は行いません。
    迷惑メールに対してはこれを使うとよいでしょう。
</ul>

<p>保留投稿について、サイト管理者のためにメールのコピーを保存したい場合は、
<b>保存</b>をチェックしてください。
これは、リストを悪用しようとするメールを破棄したいけれども、
後の調査のために記録を残す必要がある場合に有効です。

<p><b>転送</b>をチェックして、転送先メールアドレスを記入すると、
メーリングリストの関係者以外の人に転送することができます。
保留メールをリストに送る前に編集するには、
メールを自分 (リスト管理者)に転送し、元のメールを破棄するとよいでしょう。
自分宛に届いたメールを編集し、(必要なら)
<tt>Approved:</tt>ヘッダとリストのパスワードを付けて、リスト宛に再送します。
このとき、本文に手を加えたと再送メールに記しておくのがネチケット上よいでしょう。

<p>送信者が制限付きのリスト会員の場合、
その会員の制限フラグをリセットすることもできます。この機能は、
新入会員はすべて制限付きで登録しているメーリングリストで、
以後の投稿は承認せずに投稿できるようにするときに使います。

<p>送信者が非会員の場合、そのアドレスを <em>送信者フィルタ</em>
に追加することもできます。送信者フィルタは
<a href="%(filterurl)s">送信者フィルタ・プライバシーページ</a>
で説明している通り、<b>auto-accept</b> (承認) または、
<b>auto-hold</b> (保留)、<b>auto-reject</b> (拒否)、
<b>auto-discard</b> (破棄) のいずれか一つです。
送信者が既に送信者フィルタに登録されていれば、
このオプションは表示されません。

<p>設定を終了したら、このページの最初または最後にある、
<em>全部送信</em>をクリックしてください。
このボタンで、あなたが決定した全ての管理申請について、
選択した動作が送信されます。

<p><a href="%(summaryurl)s">要約ページへ戻る</a>。
