Na t&eacute;to str&aacute;nce naleznete v&scaron;echny př&iacute;spěvky do konference <em>%(listname)s</em>,
kter&eacute; nebyly z nějak&eacute;ho důvodu rozesl&aacute;ny a čekaj&iacute; na Va&scaron;e rozhodnut&iacute;.
Moment&aacute;lně jsou zobrazeny %(description)s

<p>U každ&eacute;ho administrativn&iacute;ho požadavku mus&iacute;te vybrat akci, kter&aacute; se
s n&iacute;m m&aacute; prov&eacute;st a nakonec vybran&eacute; akce provedete kliknut&iacute;m na 
<b>Potvrdit v&scaron;echny změny</b>. Podrobněj&scaron;&iacute; informace o tom, jak
zach&aacute;zet s administrativn&iacute;m rozhran&iacute;m naleznete 
<a href="%(detailsurl)s">zde</a>.

<p>Takt&eacute;ž si můžete prohl&eacute;dnout přehled v&scaron;ech
<a href="%(summaryurl)s">čekaj&iacute;c&iacute;ch požadavků</a> zobrazen&yacute; tak, že
př&iacute;spěvky od jednoho přispěvatele jsou sloučeny dohromady a můžete
o nich rozhodnout současně.
