<html>
<head>
  <title>%(listname)s: Autentificare - %(who)s</title>
  <META HTTP-EQUIV="Content-Type" CONTENT="text/html; charset=UTF-8">
  <script>function sf(){document.f.adminpw.focus();}</script>
</head>
<body bgcolor="#ffffff" onLoad="sf()">
<FORM METHOD=POST ACTION="%(path)s" name="f">
%(message)s
  <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
    <TR>
      <TD COLSPAN="2" WIDTH="100%%" BGCOLOR="#99CCFF" ALIGN="CENTER">
	<B><FONT COLOR="#000000" SIZE="+1">%(listname)s: Autentificare - %(who)s</FONT></B>
      </TD>
    </TR>
    <tr>
      <TD><div ALIGN="Right"><b>%(who)s</b>: parola de acces</div></TD>
      <TD><INPUT TYPE="password" NAME="adminpw" SIZE="30"></TD>
    </tr>
    <tr>
      <td colspan=2 align=middle><INPUT type="SUBMIT"
                                        name="admlogin"
					value="Vreau să intru...">
      </td>
    </tr>
  </TABLE>
      <p><strong><em>Important!</em></strong><br>
      De aici &icirc;nainte trebuie să aveţi activate cookie-urile &icirc;n browser, altfel nici o
      modificare administrativă nu va avea efect.

      <p>Interfaţa de administrare Mailman foloseşte cookie-urile de sesiune,
      astfel &icirc;nc&acirc;t nu trebuie să vă re-autentificaţi la fiecare operaţiune
      administrativă.  Acest cookie va expira automat la ieşire, sau
      explicit, la apăsarea linkului <em>Logout</em>, sub linkul <em>Alte activităţi
      administrative</em> (care va apare de &icirc;ndată ce vă autentificaţi cu succes).
</FORM>
</body>
</html>
