Į &scaron;į tekstą gali būti įtrauktos
<a href="https://docs.python.org/2/library/stdtypes.html#string-formatting-operations">Python
formato eilutės</a> kurios yra apdorojamos pagal požymius. 
Čia pateikiame pakeitimų sąra&scaron;ą:

<ul>
    <li><b>real_name</b> - Sąra&scaron;o pavadinimas; dažniausiai
    i&scaron; didžiosios raidės.

    <li><b>list_name</b> - The name by which the list is
    identified in URLs, where case is significant.

    <li><b>host_name</b> - The fully qualified domain name
    that the list server runs on.

    <li><b>web_page_url</b> - The base URL for Mailman.  This
    can be appended with,
    e.g. <em>listinfo/%(list_name)s</em> to yield the
    listinfo page for the mailing list.

    <li><b>description</b> - Trumpas forumo apra&scaron;ymas.

    <li><b>info</b> - Pilnas forumo apra&scaron;ymas.

    <li><b>cgiext</b> - The extension added to CGI scripts.
</ul>
