<html>
<head>
    <title>%(realname)s Inloggning till Privata Arkiv</title>
	<script>function sf(){document.f.username.focus();}</script>
</head>
<body bgcolor="#ffffff" onLoad="sf()">
<FORM METHOD=POST ACTION="%(action)s" name="f">
%(message)s
  <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
    <TR>
      <TD COLSPAN="2" WIDTH="100%%" BGCOLOR="#99CCFF" ALIGN="CENTER">
	<B><FONT COLOR="#000000" SIZE="+1">%(realname)s Inloggning till Privata Arkiv</FONT></B>
      </TD>
    </TR>
    <tr>
        <TD><div ALIGN="Right">E-postadress:</div></TD>
        <TD><INPUT TYPE="text" NAME="username" SIZE="30"></TD>
    </tr>
    <tr>
      <TD><div ALIGN="Right">L&ouml;senord:</div></TD>
      <TD><INPUT TYPE="password" NAME="password" SIZE="30"></TD>
    </tr>
    <tr>
      <td colspan=2 align="middle"><INPUT type="SUBMIT"
                                          name="submit"
					  value="Logga in mig...">
      </td>
    </tr>
  </TABLE>
      <p><strong><em>Viktigt:</em></strong> Fr&aring;n och med nu m&aring;ste du ha alternativet cookies aktiverat i din browser, annars kommer inga administrativa &auml;ndringar att sparas. 
      <p><i>Session cookies</i> anv&auml;nds p&aring; Mailmans administrativa sidor, f&ouml;r att du inte ska beh&ouml;va uppge l&ouml;senord f&ouml;r varje &auml;ndring som du g&ouml;r. Dessa cookies kommer att f&ouml;rsvinna automatiskt n&auml;r du st&auml;nger din browser.&nbsp;Du kan ocks&aring; ta bort dem manuellt genom att klicka p&aring; l&auml;nken       <em>Logga ut</em> under <em>Andra administrativa aktiviteter</em> (som du f&aring;r upp efter att ha loggat in).      <p>
    <TABLE WIDTH="100%%" BORDER="0" CELLSPACING="4" CELLPADDING="5">
    <TR>
      <TD COLSPAN="2" WIDTH="100%%" BGCOLOR="#99CCFF" ALIGN="CENTER">
	<B><FONT COLOR="#000000" SIZE="+1">Password Reminder</FONT></B>
      </TD>
    </TR>
    <tr>
      <td>If you don't remember your password, enter your email address
          above and click the <em>Remind</em> button and your
          password will be emailed to you.</td>
    </tr>
    <tr>
      <td><center><INPUT name="login-remind" type="SUBMIT" value="Remind" ></center></td>
    </tr>
  </TABLE>
</FORM>
</body>
</html>
