<!-- $Revision: 7202 $ -->
<html>
<head>
    <link rel="SHORTCUT ICON" href="<mm-favicon>">
    <title><MM-Presentable-User> <MM-List-Name> tellimuse profiil
    </title>
</head>
<BODY BGCOLOR="#ffffff">
    <TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="5">
    <TR><TD WIDTH="100%" BGCOLOR="#99CCFF"><B>
        <FONT COLOR="#000000" SIZE=+1>
        <MM-List-Name> tellimuse profiil kasutajale
        <MM-Presentable-User>
        </FONT></B></TD></TR>
    </TABLE>
<p>
<table width="100%" border="0" cellspacing="5" cellpadding="5">
    <tr><td>
        <b><MM-Presentable-User></b> tellimuse staatus,
        parool, ja listi <MM-List-Name> seadistused.
        </td><td><MM-Form-Start><mm-logout-button><MM-Form-End></td>
    </tr><tr>
        <td colspan="2">
        <MM-Case-Preserved-User>

        <MM-Disabled-Notice>

        <p><mm-results>
        </td>
    </tr>
</table>

<MM-Form-Start>
<p>
<TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="5">
    <TR><TD WIDTH="100%" BGCOLOR="#FFF0D0" colspan="2">
        <FONT COLOR="#000000">
        <B><MM-List-Name> tellimuse profiili muutmine</B>
        </FONT></TD></TR>
    <tr><td colspan="2">Tellimuse aadressi saab muuta sisestades uue
    	aadressi allpool asuvatesse vormi v&auml;ljadesse. Enne kui muudatus
	j&otilde;ustuda saab, saadetakse uuele aadressile veel t&auml;iendav kiri, millele
	peab vastama, et aadressi muutus kinnitada.

        <p>Kinnitus kaotab kehtivuse <mm-pending-days> p&auml;rast.

        <p>V&otilde;id sisestada ka oma p&auml;risnime (n&auml;iteks <em>Einar Kootikum</em>).

        <p>Kui soovid tehtud muudatusi rakendada muudatusi korraga k&otilde;igile serveri <mm-host>
	listide tellimustele, siis m&auml;rgista ruuduke <em>Muuda k&otilde;iki</em>.

        </td></tr>
    <tr><td><center>
        <table border="0" cellspacing="2" cellpadding="2" width="80%" cols="2">
        <tr><td bgcolor="#dddddd"><div align="right">Uus aadress:</div></td>
            <td><mm-new-address-box></td>
            </tr>
        <tr><td bgcolor="#dddddd"><div align="right">Uus aadress
            (2x):</div></td> 
            <td><mm-confirm-address-box></td>
            </tr>
        </tr></table></center>
        </td>
        <td><center>
        <table border="0" cellspacing="2" cellpadding="2" width="80%" cols="2">
            <tr><td bgcolor="#dddddd"><div align="right">Sinu nimi
            (v&otilde;ib t&uuml;hjaks j&auml;tta):</div></td>
            <td><mm-fullname-box></td>
            </tr>
        </table></center>
        </td>
        </tr>
    <tr><td colspan="2"><center><mm-change-address-button>
        <p><mm-global-change-of-address>Muuda k&otilde;iki</center></td>
    </tr>
</table>

<p>
<TABLE WIDTH="100%" BORDER="0" CELLSPACING="5" CELLPADDING="5">
    <TR><TD WIDTH="50%" BGCOLOR="#FFF0D0"><FONT COLOR="#000000">
        <B><MM-List-Name> listi tellimuse l&otilde;petamine</B></td>

        <TD WIDTH="50%" BGCOLOR="#FFF0D0"><FONT COLOR="#000000">
        <B>Teiste <MM-Host> listide tellimused</B>
        </FONT></TD></TR>

    <tr><td>
    	M&auml;rgista ruuduke "N&otilde;ua kinnitust" ja kliki seda nuppu
	listi tellimuse l&otilde;petamiseks.
        <strong>NB:</strong>
        This action will be taken immediately!
        <p>
        <center><MM-Unsubscribe-Button></center></td>
    <td>
    	Siit saad vaadata k&otilde;igi oma &uuml;lej&auml;&auml;nud <mm-host> listide tellimusi.
	Kliki siia, kui soovid muudatusi rakendada ka teiste tellimuste
	profiilidele.

        <p>
        <center><MM-Other-Subscriptions-Submit></center>
        </TD></TR>
</table>

<TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="5">
    <TR><TD COLSPAN=2 WIDTH="100%" BGCOLOR="#FFF0D0"><FONT COLOR="#000000">
        <B>Teie <MM-List-Name> listi parool</B>
        </FONT></TD></TR>

    <tr valign="TOP"><td WIDTH="50%">
        <a name=reminder>
        <center>
        <h3>Unustasid parooli?</h3>
        </center>
	Kliki seda nuppu parooli saatmiseks aadressile, millele
	listi tellisid
        <p><MM-Umbrella-Notice>
        <center>
        <MM-Email-My-Pw>
        </center>
        </td>

    <td WIDTH="50%">
        <a name=changepw>
        <center>
        <h3>Vaheta parooli</h3>
        <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2" WIDTH="70%" COLS=2>
            <TR><TD BGCOLOR="#dddddd"><div align="right">Uus
                parool:</div></TD>
                <TD><MM-New-Pass-Box></TD>
                </TR>
            <TR>
                <TD BGCOLOR="#dddddd"><div align="right">Korda
                parooli:</div></TD>
                <TD><MM-Confirm-Pass-Box></TD>
            </TR>
        </table>

        <MM-Change-Pass-Button>
        <p><center><mm-global-pw-changes-button>Muuda k&otilde;iki.
        </center>
</TABLE>

<p>
<TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="5">
    <TR><TD WIDTH="100%" BGCOLOR="#FFF0D0"><FONT COLOR="#000000">
        <B>Listi <MM-List-Name> tellimuse profiil</B>
        </FONT></TD></TR>
</table>

<p>
<i><strong>Hetkel kehtivad valikud on m&auml;rgistatud.</strong></i>

<p>Osade valikute juures on ka valikukast <em>rakenda k&otilde;igile</em>,
seda m&auml;rgistades saab muudatusi rakendada k&otilde;igi sinu tellimuste
profiilidele servers <mm-host>.
Klikkige nupule <em>teised tellimused</em> &uuml;lal, et n&auml;ha millised
listid teie aadressile veel tellitud on.
<p>
<TABLE BORDER="0" CELLSPACING="3" CELLPADDING="4" WIDTH="100%">
    <tr><TD BGCOLOR="#cccccc">
        <a name="disable">
        <strong>Tellimuse staatus</strong></a><p>
        Vali <em>aktiivne</em> kui soovid listi kirju saada.
        Vali <em>peatatud</em> kui soovid kirjade k&auml;tte toimetamise
	ajutiselt katkestada (n&auml;iteks puhkusel oleku ajaks). Viisakas oleks
	ka tellimus uuesti aktiveerida, kui (puhkuselt) tagasi oled.
        
	</td><td bgcolor="#cccccc">
        <mm-delivery-enable-button>aktiivne<br>
        <mm-delivery-disable-button>peatatud<p>
        <mm-global-deliver-button><i>rakenda k&otilde;igile</i>
        </td></tr>

<!--Start-Digests-Delete-->
    <tr><TD BGCOLOR="#cccccc">
        <strong>Kirjade k&auml;ttetoimetusviis</strong><p>
	Kui soovid listi kirju saada kokkuv&otilde;tetena (tavaliselt
	kord p&auml;evas, suurema liiklusega listides ka sagedamini), siis
	vali "Kokkuv&otilde;tted". 
        </td><td bgcolor="#cccccc">
        <MM-Undigest-Radio-Button>&uuml;ksikkirjad<br>
        <MM-Digest-Radio-Button>kokkuv&otilde;tted
        </td></tr>
        
    <tr><TD BGCOLOR="#cccccc">
        <strong>Kokkuv&otilde;tete vorming?</strong><p>
	Kui sa mingil p&otilde;hjusel ei saa v&otilde;i ei taha lugeda MIME vormingus
	kokkuv&otilde;tteid, siis on v&otilde;imalik kasutada lihttekst vormingut.
        </td><td bgcolor="#cccccc">
        <MM-Mime-Digests-Button>MIME<br>
        <MM-Plain-Digests-Button>Lihttekst
        </td></tr>
<!--End-Digests-Delete-->
        
    <tr><TD BGCOLOR="#cccccc">
        <strong>Oma kirjad l&auml;bi listi?</strong><p>
	Vaikimisi saad listist ka koopiad enda listi saadetud kirjadest.
	Kui sa seda ei soovi, siis vali <em>Ei</em>
        </td><td bgcolor="#cccccc">
        <mm-dont-receive-own-mail-button>Ei<br>
        <mm-receive-own-mail-button>Jah
        </td></tr>

    <tr><TD BGCOLOR="#cccccc">
        <strong>Kinnitus listi saadetud kirja laiali toimetamise kohta?</strong><p>
        </td><td bgcolor="#cccccc">
        <mm-dont-ack-posts-button>Ei<br>
        <mm-ack-posts-button>Jah
        </td></tr>

    <tr><td bgcolor="#cccccc">
        <strong>Automaatne paroolide meeldetuletus?</strong><p>
	Kord kuus saate meili teel meeldetuletuse sellest serverist
	tellitud listite kohta. Selles automaatselt saadetavas
	meilis on muu hulgas kirjas ka tellimus(te) paroolid. 
	Kui sa ei soovi selliseid meeldetuletusi, siis vali <em>Ei</em>
        </td><td bgcolor="#cccccc">
        <mm-dont-get-password-reminder-button>Ei<br>
        <mm-get-password-reminder-button>Jah<p>
        <mm-global-remind-button><i>rakenda k&otilde;igile</i>
        </td></tr>

    <tr><TD BGCOLOR="#cccccc">
        <strong>N&auml;ita minu aadressi tellijate nimekirjas?</strong><p>
	Vaikimsi n&auml;idatakse k&otilde;igi tellijate aadresse listi tellijate
	nimekirjas (k&uuml;ll veidi muudetud kujul, et kaitsta aadresse
	sp&auml;mmijate eest). Kui sa ei taha, et sinu aadress oleks
	selles nimekirjas siis vali <em>Ei</em>
        </td><td bgcolor="#cccccc">
        <MM-Public-Subscription-Button>Ei<br>
        <MM-Hide-Subscription-Button>Jah
        </td></tr>

    <tr><TD BGCOLOR="#cccccc">
        <strong>Millist keelt eelistad listserveriga suhtlemisel?</strong><p>
        </td><td bgcolor="#cccccc">
        <MM-list-langs>
        </td></tr>

    <tr><td bgcolor="#cccccc">
        <strong>Millised teemad sind huvitavad?
                </strong><p>
		Sul on v&otilde;imalik lasta listserveril filtreerida sulle
		toimetatavaid kirju, valides allpool tootud nimekirjas
		&uuml;he v&otilde;i enam huvi pakkuvat teemat.

		<p>Kui sa &uuml;htegi valikut ei tee, saadetakse sulle k&otilde;ik kirjad</p>
        </td><td bgcolor="#cccccc">
        <mm-topics>
        </td></tr>

    <tr><td bgcolor="#cccccc">
        <strong>Mida teha teemav&auml;liste kirjadega?
                </strong><p>

		See valik kehtib ainult siis, kui oled valinud v&auml;hemalt
		&uuml;he teema sellest nimekirjast. See seadistus m&auml;&auml;rab 
		teemav&auml;liste kirjade saatuse.

		<em>&Auml;ra saada</em> - kirju ei saadeta sulle
		<em>Saada</em> - kirjad saadetakse sulle
		
		<p>Kui sa &uuml;htegi teemat ei vali, saad k&auml;tte k&otilde;ik kirjad</p>

        </td><td bgcolor="#cccccc">
        <mm-suppress-nonmatching-topics>&Auml;ra saada<br>
        <mm-receive-nonmatching-topics>Saada
        </td></tr>

    <tr><td bgcolor="#cccccc">
        <strong>V&auml;ldi duplikaate?</strong><p>

		Kui sinu aadress on listi saadetud kirjade <tt>To:</tt>
		ja/v&otilde;i <tt>Cc:</tt> p&auml;istes, siis selle valiku abil 
		saad listserverile &ouml;elda, et ei taha koopiat
		kirjast l&auml;bi listi (Cc-ga saadetud kiri on sul ju olemas).
		Vali <em>Jah</em> kui sa ei taha koopiaid, v&otilde;i <em>Ei</em>
		kui tahad.

                <p>Kui list kasutab personaliseeritud kirju ja sul on duplikaatide
		kontroll sisse l&uuml;litatud, siis lisatakse igale listserveri
		kaudu saadetud kirjale <tt>X-Mailman-Copy: yes</tt> p&auml;is.

        </td><td bgcolor="#cccccc">
        <mm-receive-duplicates-button>Ei<br>
        <mm-dont-receive-duplicates-button>Jah<p>
        <mm-global-nodupes-button><i>rakenda k&otilde;igile</i>
        </td></tr>

    <tr><TD colspan="2">
        <center><MM-options-Submit-button></center>
        </td></tr>

</table>
</center>
<p>
<MM-Form-End>

<MM-Mailman-Footer>
</body>
</html>
