Ова  страница садржи листу порука које су задржане за одобрење. Тренутно показује 
%(description)s

<p>За сваки административни захтјев, молимо вас да изаберете одговарајућу опцију, те након извршених промјена кликнете на одговарајући тастер,обично при врху екрана.  Детаљније инструкције су доступне <a href="%(detailsurl)s">овдје</a>.

<p>Можете такође <a href="%(summaryurl)s">видјети преглед</a> чекајућих захтјева.
