<!-- $Revision: 6800 $ -->
<html>
<head>
    <link rel="SHORTCUT ICON" href="<mm-favicon>">
    <title>Konfiguracja <MM-Presentable-User> na li&#347;cie <MM-List-Name>
    </title>
<meta http-equiv="content-type" content="text/html; charset=iso-8859-2">
</head>
<BODY BGCOLOR="#ffffff">
    <TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="5">
    <TR><TD WIDTH="100%" BGCOLOR="#99CCFF"><B>
        <FONT COLOR="#000000" SIZE=+1>
        Konfiguracja subskrybcji <MM-Presentable-User> na li&#347;cie
        <MM-List-Name>
        </FONT></B></TD></TR>
    </TABLE>
<p>
<table width="100%" border="0" cellspacing="5" cellpadding="5">
    <tr><td>
        <b><MM-Presentable-User></b> -- aktualny stan subskrypcji,
        has&#322;o i zmiana opcji na li&#347;cie <MM-List-Name>.
        </td><td><MM-Form-Start><mm-logout-button><MM-Form-End></td>
    </tr><tr>
        <td colspan="2">
        <MM-Case-Preserved-User>

        <MM-Disabled-Notice>

        <p><mm-results>
        </td>
    </tr>
</table>

<MM-Form-Start>
<p>
<TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="5">
    <TR><TD WIDTH="100%" BGCOLOR="#FFF0D0" colspan="2">
        <FONT COLOR="#000000">
        <B>Zmiana ustawie&#324; <MM-List-Name> </B>
        </FONT></TD></TR>
    <tr><td colspan="2">
        Mo&#380;esz zmieni&#263; adres u&#380;ywany do prenumeraty listy
        wype&#322;niaj&#261;c po prostu poni&#380;sze pola. Na nowy adres zostanie wys&#322;ana 
        wiadomo&#347;&#263;, kt&oacute;ra b&#281;dzie jeszcze wymaga&#322;a Twojego potwierdzenia.

        <p>Potwierdzenie nale&#380;y odes&#322;a&#263; w ci&#261;gu <mm-pending-days>.

        <p>Mo&#380;esz r&oacute;wnie&#380; doda&#263; lub zmieni&#263; swoje Imi&#281; i Nazwisko
        (np.. <em>Jan Kowalski</em>).

        <p>Zaznaczenie opcji <em>Zmiana globalna</em> spowoduje, &#380;e zmiany
        te b&#281;d&#261; dotyczy&#263; wszystkich list na serwerze <mm-host>, na kt&oacute;re jeste&#347; zapisany.

        </td></tr>
    <tr><td><center>
        <table border="0" cellspacing="2" cellpadding="2" width="80%" cols="2">
        <tr><td bgcolor="#dddddd"><div align="right">Nowy adres:</div></td>
            <td><mm-new-address-box></td>
            </tr>
        <tr><td bgcolor="#dddddd"><div align="right">Podaj ponownie:</div></td> 
            <td><mm-confirm-address-box></td>
            </tr>
        </tr></table></center>
        </td>
        <td><center>
        <table border="0" cellspacing="2" cellpadding="2" width="80%" cols="2">
            <tr><td bgcolor="#dddddd"><div align="right">Imi&#281; i Nazwisko
            (opcjonalnie):</div></td>
            <td><mm-fullname-box></td>
            </tr>
        </table></center>
        </td>
        </tr>
    <tr><td colspan="2"><center><mm-change-address-button>
        <p><mm-global-change-of-address>Zmiana globalna</center></td>
    </tr>
</table>

<p>
<TABLE WIDTH="100%" BORDER="0" CELLSPACING="5" CELLPADDING="5">
    <TR><TD WIDTH="50%" BGCOLOR="#FFF0D0"><FONT COLOR="#000000">
        <B>Wypisanie si&#281; z listy <MM-List-Name></B></td>

        <TD WIDTH="50%" BGCOLOR="#FFF0D0"><FONT COLOR="#000000">
        <B>Pozosta&#322;e listy, kt&oacute;re subskrybujesz na serwerze <MM-Host></B>
        </FONT></TD></TR>

    <tr><td>
        Zaznacz opcje potwierdzenia i naci&#347;nij przycisk, aby wypisa&#263; si&#281;
        z listy. <strong>Uwaga:</strong> wypisanie jest
        realizowane natychmiast.
        <p>
        <center><MM-Unsubscribe-Button></center></td>
    <td>
        Mo&#380;esz zobaczy&#263; list&#281; wszystkich list na serwerze
        <mm-host>, na kt&oacute;re jeste&#347; zapisany. 
        Zaloguj si&#281;, je&#347;li chcesz zmieni&#263; co&#347; w opcjach dotycz&#261;cych innej
        listy.

        <p>
        <center><MM-Other-Subscriptions-Submit></center>
        </TD></TR>
</table>

<TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="5">
    <TR><TD COLSPAN=2 WIDTH="100%" BGCOLOR="#FFF0D0"><FONT COLOR="#000000">
        <B>Twoje has&#322;o na li&#347;cie <MM-List-Name></B>
        </FONT></TD></TR>

    <tr valign="TOP"><td WIDTH="50%">
        <a name=reminder>
        <center>
        <h3>Zapomnia&#322;e&#347; has&#322;a?</h3>
        </center>
        Kliknij poni&#380;szy przycisk, a has&#322;o zostanie wys&#322;ane na Tw&oacute;j adres
        email.
        <p><MM-Umbrella-Notice>
        <center>
        <MM-Email-My-Pw>
        </center>
        </td>

    <td WIDTH="50%">
        <a name=changepw>
        <center>
        <h3>Zmiana has&#322;a</h3>
        <TABLE BORDER="0" CELLSPACING="2" CELLPADDING="2" WIDTH="70%" COLS=2>
            <TR><TD BGCOLOR="#dddddd"><div align="right">Nowe
                has&#322;o:</div></TD>
                <TD><MM-New-Pass-Box></TD>
                </TR>
            <TR>
                <TD BGCOLOR="#dddddd"><div align="right">Podaj ponownie:
                 </div></TD>
                <TD><MM-Confirm-Pass-Box></TD>
            </TR>
        </table>

        <MM-Change-Pass-Button>
        <p><center><mm-global-pw-changes-button>Zmiana globalna
        </center>
</TABLE>

<p>
<TABLE WIDTH="100%" BORDER="0" CELLSPACING="0" CELLPADDING="5">
    <TR><TD WIDTH="100%" BGCOLOR="#FFF0D0"><FONT COLOR="#000000">
        <B>Opcje subskrypcji listy <MM-List-Name></B>
        </FONT></TD></TR>
</table>

<p>
<i><strong>Warto&#347;ci zaznaczone to aktualne ustawienia prenumeraty.</strong></i>

<p>Zauwa&#380;, &#380;e niekt&oacute;re opcje maj&#261; znacznik <em>Zmiana globalna</em>.
Jego zaznaczenie spowoduje, &#380;e zmiana danej opcji odnosi&#263; si&#281; b&#281;dzie do 
wszystkich list na serwerze <mm-host>, kt&oacute;re prenumerujesz.
Kliknij przycisk <em>Poka&#380; moje pozosta&#322;e subskrypcje</em>, je&#347;li 
nie jeste&#347; pewien na jakie listy jeste&#347; zapisany.
<p>
<TABLE BORDER="0" CELLSPACING="3" CELLPADDING="4" WIDTH="100%">
    <tr><TD BGCOLOR="#cccccc">
        <a name="disable">
        <strong>Dostarczanie wiadomo&#347;ci</strong></a><p>
        Ustaw t&#281; opcj&#281; na <em>W&#322;&#261;czone</em>, &#380;eby dostawa&#263; wszystkie 
        wiadomo&#347;ci z listy. Ustawienie <em>Wy&#322;&#261;czone</em>, spowoduje, 
        &#380;e nadal b&#281;dziesz zapisany na list&#281;, ale nie b&#281;dziesz dostawa&#322; wiadomo&#347;ci (przydatne je&#347;li np. wyje&#380;d&#380;asz na wakacje). Je&#347;li
        wy&#322;&#261;czy&#322;e&#347; dostarczanie, nie zapomnij w&#322;&#261;czy&#263; je po powrocie; nie
        w&#322;&#261;czy si&#281; ono automatycznie. 
        </td><td bgcolor="#cccccc">
        <mm-delivery-enable-button>W&#322;&#261;czone<br>
        <mm-delivery-disable-button>Wy&#322;&#261;czone<p>
        <mm-global-deliver-button><i>Zmiana&nbsp;globalna</i>
        </td></tr>

    <tr><TD BGCOLOR="#cccccc">
        <strong>Tryb Paczek</strong><p>

        Je&#347;li tryb paczek jest wy&#322;&#261;czony, wiadomo&#347;ci dostarczane s&#261; 
        natychmiast. Po jego w&#322;&#261;czeniu, wiadomo&#347;ci z listy b&#281;dziesz dostawa&#322;
        tylko raz dziennie w formie paczki (b&#261;d&#378; cz&#281;&#347;ciej, je&#347;li ruch
        na li&#347;cie jest bardzo du&#380;y). Zmiana tej opcji mo&#380;e spowodowa&#263;, &#380;e 
        nie dostaniesz ostatniej wys&#322;anej paczki (tylko kolejne).
        </td><td bgcolor="#cccccc">
        <MM-Undigest-Radio-Button>Wy&#322;&#261;czony<br>
        <MM-Digest-Radio-Button>W&#322;&#261;czony
        </td></tr>
        
    <tr><TD BGCOLOR="#cccccc">
        <strong>Paczki w formie MIME czy Czystego Tekstu?</strong><p>
        Okre&#347;l, w jakiej formie maj&#261; by&#263; dostarczane wiadomo&#347;ci w trybie 
        paczek. Najcz&#281;stszym wyborem jest MIME. 
        Stare programy pocztowe mog&#261; nie obs&#322;ugiwa&#263; za&#322;&#261;cznik&oacute;w MIME, wtedy 
        wybierz opcj&#281; na Czysty Tekst.
        </td><td bgcolor="#cccccc">
        <MM-Mime-Digests-Button>MIME<br>
        <MM-Plain-Digests-Button>Czysty Tekst<p>
        <mm-global-mime-button><i>Zmiana&nbsp;globalna</i>
        </td></tr>
        
    <tr><TD BGCOLOR="#cccccc">
        <strong>Czy chcesz otrzymywa&#263; wys&#322;ane przez siebie wiadomo&#347;ci?</strong><p>
        Mo&#380;esz dostawa&#263; kopi&#281; ka&#380;dej wiadomo&#347;ci, kt&oacute;r&#261; wysy&#322;asz na list&#281;. 
        Je&#347;li tego nie chcesz, ustaw t&#261; opcj&#281; na <em>Nie</em>.
        </td><td bgcolor="#cccccc">
        <mm-dont-receive-own-mail-button>Nie<br>
        <mm-receive-own-mail-button>Tak
        </td></tr>

    <tr><TD BGCOLOR="#cccccc">
        <strong>Czy chcesz dostawa&#263; potwierdzenie, &#380;e wys&#322;any list doszed&#322; 
        na list&#281;?
        </strong><p>
        </td><td bgcolor="#cccccc">
        <mm-dont-ack-posts-button>Nie<br>
        <mm-ack-posts-button>Tak
        </td></tr>

    <tr><td bgcolor="#cccccc">
        <strong>Czy chcesz dostawa&#263; przypomnienia has&#322;a?</strong><p>
        Raz w miesi&#261;cu rozsy&#322;ane s&#261; przypomnienia do wszystkich 
        subskrybent&oacute;w. Przypomnienie zawiera has&#322;a i podstawowe informacje o
        wszystkich listach, na kt&oacute;re jeste&#347; zapisany na tym serwerze. 
        Mo&#380;esz wy&#322;&#261;czy&#263;
        przypomnienie has&#322;a dla ka&#380;dej z list osobno, zaznaczaj&#261;c opcje
        <em>Nie</em>. Zrezygnowanie z przypomnienia dla wszystkich list
        spowoduje, &#380;e w og&oacute;le nie dostaniesz wiadomo&#347;ci z przypomnieniem.
        </td><td bgcolor="#cccccc">
        <mm-dont-get-password-reminder-button>Nie<br>
        <mm-get-password-reminder-button>Tak<p>
        <mm-global-remind-button><i>Zmiana&nbsp;globalna</i>
        </td></tr>

    <tr><TD BGCOLOR="#cccccc">
        <strong>Czy chcesz by&#263; niewidocznym cz&#322;onkiem listy?</strong><p>
        Normalnie Tw&oacute;j adres jest widoczny dla ogl&#261;daj&#261;cych list&#281;
        sybskrybent&oacute;w (adres jest dodatkowo zniekszta&#322;cony, &#380;eby utrudni&#263; 
        &#380;ycie spamerom). Je&#347;li nie chcesz, &#380;eby Tw&oacute;j adres pojawia&#322; si&#281; na
        li&#347;cie os&oacute;b zapisanych, zaznacz <em>Tak</em>.
        </td><td bgcolor="#cccccc">
        <MM-Public-Subscription-Button>Nie<br>
        <MM-Hide-Subscription-Button>Tak
        </td></tr>

    <tr><TD BGCOLOR="#cccccc">
        <strong>W jakim j&#281;zyku chcesz si&#281; komunikowa&#263;?</strong><p>
        </td><td bgcolor="#cccccc">
        <MM-list-langs>
        </td></tr>

    <tr><td bgcolor="#cccccc">
        <strong>Jakie kategorie tematyczne Ci&#281; interesuj&#261;?
                </strong><p>
                Zaznaczaj&#261;c jeden lub wi&#281;cej temat&oacute;w, mo&#380;esz filtrowa&#263;
                wiadomo&#347;ci z listy, a wi&#281;c otrzymywa&#263; tylko cz&#281;&#347;&#263; 
                ruchu. B&#281;dziesz dostawa&#263; tylko wiadomo&#347;ci, kt&oacute;re pasuj&#261;
                do kt&oacute;rego&#347; z temat&oacute;w.
               
                <p>Je&#347;li wiadomo&#347;&#263; nie pasuje do &#380;adnego z temat&oacute;w, to
                czy j&#261; dostaniesz zale&#380;y od nast&#281;pnej opcji. Je&#380;eli nie 
                zaznaczysz &#380;adnego tematu, b&#281;dziesz otrzymywa&#263; wszystkie
                wiadomo&#347;ci wysy&#322;ane na list&#281; dyskusyjn&#261;.
        </td><td bgcolor="#cccccc">
        <mm-topics>
        </td></tr>

    <tr><td bgcolor="#cccccc">
        <strong>Czy chcesz dostawa&#263; wiadomo&#347;ci, kt&oacute;re nie pasuj&#261;
                do &#380;adnej kategorii tematycznej?
                </strong><p>

                Ta opcja ma znaczenie tylko, je&#347;li wybra&#322;e&#347; co najmniej 
                jedn&#261; kategori&#281; tematyczn&#261; z poprzedniej opcji. Opisuje
                na zachowanie w przypadku, gdy wiadomo&#347;&#263; nie pasuje
                do &#380;adnego ze zdefiniowanych temat&oacute;w. Wybranie 
                <em>Nie</em> oznacza, &#380;e nie b&#281;dziesz dostawa&#263; wiadomo&#347;ci 
                nie pasuj&#261;cych do &#380;adnego tematu, a <em>Tak</em>, &#380;e
                b&#281;dziesz dostawa&#263; te pozosta&#322;e wiadomo&#347;ci.

                <p>Nie wybranie &#380;adnego z temat&oacute;w z poprzedniej opcji
                oznacza, &#380;e b&#281;dziesz otrzymywa&#263; wszystkie wiadomo&#347;ci.
        </td><td bgcolor="#cccccc">
        <mm-suppress-nonmatching-topics>Nie<br>
        <mm-receive-nonmatching-topics>Tak
        </td></tr>

    <tr><td bgcolor="#cccccc">
        <strong>Unika&#263; podw&oacute;jnych kopii wiadomo&#347;ci?</strong><p>

                Po zaznaczeniu tej opcji Mailman b&#281;dzie analizowa&#322;
                pola <tt>To:</tt> i <tt>Cc:</tt> i na tej podstawie nie
                b&#281;dzie wysy&#322;a&#322; do Ciebie kopii, je&#347;li jeste&#347; ju&#380; jej
                adresatem.
                Odpowied&#378; <em>Tak</em> oznacza, &#380;e chcesz unika&#263; 
                dostawania tego samego listu w dw&oacute;ch kopiach. 
                Przy <em>Nie</em> mo&#380;esz dostawa&#263; wielokrotne kopie.

                <p>Je&#380;eli lista ma w&#322;&#261;czon&#261; personalizacj&#281;
                wiadomo&#347;ci, a ty wybierzesz dostawanie kopii, Mailman 
                doda pole <tt>X-Mailman-Copy: yes</tt> do nag&#322;&oacute;wka ka&#380;dej
                kopii.

        </td><td bgcolor="#cccccc">
        <mm-receive-duplicates-button>Nie<br>
        <mm-dont-receive-duplicates-button>Tak<p>
        <mm-global-nodupes-button><i>Zmiana&nbsp;globalna</i>
        </td></tr>

    <tr><TD colspan="2">
        <center><MM-options-Submit-button></center>
        </td></tr>

</table>
</center>
<p>
<MM-Form-End>

<MM-Mailman-Footer>
</body>
</html>
