Questa pagina contiene tutti i messaggi sospesi che richiedono 
la tua approvazione per la lista <em>%(listname)s</em>.
Attualmente mostra %(description)s

<p>Per ogni richiesta amministrativa, scegli l'azione da eseguire
e clicca su <b>Manda Tutto</b> quando hai finito.  Istruzioni 
pi&ugrave; dettagliate sono disponibili <a href="%(detailsurl)s">qui</a>.

<p>Puoi anche <a href="%(summaryurl)s">vedere un sommario</a> di
tutte le richieste pendenti.

